#
# spec file for package salt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global debug_package %{nil}

%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif
%if 0%{?sle_version} >= 150400 || 0%{?suse_version} >= 1600
%define _alternatives 1
%endif

%global flavor %{nil}
%if "%{flavor}" == "testsuite"
%define psuffix -test
%else
%define psuffix %{nil}
%endif

%if 0%{?suse_version} > 1210 || 0%{?rhel} >= 7 || 0%{?fedora} >= 28
%bcond_without systemd
%else
%bcond_with    systemd
%endif
%if 0%{?suse_version} > 1110
%bcond_without bash_completion
%bcond_without fish_completion
%bcond_without zsh_completion
%else
%bcond_with    bash_completion
%bcond_with    fish_completion
%bcond_with    zsh_completion
%endif
%bcond_without docs
%bcond_with    builddocs

%if %{without systemd}
%define service_del_preun echo %{*}
%endif

%{?sle15allpythons}
%define skip_python2 1
%if 0%{?rhel} == 8 || (0%{?suse_version} == 1500 && 0%{?sle_version} < 150400)
%define singlespec_compat 1
%define __python3_bin_suffix 3.6
%if 0%{?rhel} == 8
%define __python3 /usr/libexec/platform-python
%else
%define __python3 /usr/bin/python3
%endif
%define python_module() python3-%**
%define python_files() -n python3-%1
%define python_subpackages %{nil}
%define python_sitelib %python3_sitelib
%define python_expand(+abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-=) %{lua: \
local args = rpm.expand("%**")\
local python_bin = rpm.expand("%__python3")\
local python_bin_suffix = rpm.expand("%__python3_bin_suffix")\
args = args:gsub("$python_bin_suffix", python_bin_suffix)\
args = args:gsub("$python_sitelib", "python3_sitelib")\
args = args:gsub("$python", python_bin)\
print(rpm.expand(args .. "\\n"))\
}
%endif
Name:           salt%{psuffix}
Version:        3006.0
Release:        32.1
Summary:        A parallel remote execution system
License:        Apache-2.0
Group:          System/Management
URL:            https://saltproject.io/
Source:         v%{version}.tar.gz
Source1:        README.SUSE
Source2:        salt-tmpfiles.d
Source3:        html.tar.bz2
Source4:        update-documentation.sh
Source5:        travis.yml
Source6:        transactional_update.conf

### SALT PATCHES LIST BEGIN
### IMPORTANT: The line above is used as a snippet marker. Do not touch it.

# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/88f40fff3b81edaa55f37949f56c67112ca2dcad
Patch1:         run-salt-master-as-dedicated-salt-user.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/cdecbbdf5db3f1cb6b603916fecd80738f5fae9a
Patch2:         run-salt-api-as-user-salt-bsc-1064520.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/c44b897eb1305c6b9c341fc16f729d2293ab24e4
Patch3:         activate-all-beacons-sources-config-pillar-grains.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/3c83bab3da101223c99af1f9ee2f3bf5e97be3f8
Patch4:         avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/1b9a160f578cf446f5ae622a450d23022e7e3ca5
Patch5:         fix-bsc-1065792.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/fec7f65b4debede8cf0eef335182fce2206e200d
Patch6:         enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/90
Patch7:         add-environment-variable-to-know-if-yum-is-invoked-f.patch

#### SUSE CAPABILITIES - unified ####
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/713ccfdc5c6733495d3ce7f26a8cfeddb8e9e9c4
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/b713d0b3031faadc17cd9cf09977ccc19e50bef7
Patch8:         add-custom-suse-capabilities-as-grains.patch
###########

#### SUSE SLES-ES SUPPORT ####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/57166
Patch9:         fix-for-suse-expanded-support-detection.patch
############

#### ADLER - unified ####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/48812
# (closed upstream in favor of different solution - might affect server_id)
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/159
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/73e357d7eee19a73cade22becb30d9689cae27ba
Patch10:        use-adler32-algorithm-to-compute-string-checksums.patch
###########

#### X509 - unified ####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/56819
Patch11:        x509-fixes-111.patch
###########

# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/58054
Patch12:        do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch

#### SALT SUPPORT - unified ####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/57054
Patch13:        early-feature-support-config.patch
###########

# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/57071
Patch14:        make-aptpkg.list_repos-compatible-on-enabled-disable.patch

### DEBIAN INFO_INSTALLED - unified ###
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/50453
# (master PR not yet created - codejam)
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/50453
#                     https://github.com/saltstack/salt/commit/e20362f6f053eaa4144583604e6aac3d62838419
# Can be dropped one pull/50453 is in released version.
Patch15:        debian-info_installed-compatibility-50453.patch
###########

# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/pull/116 (missing upstream PR to master)
Patch16:        return-the-expected-powerpc-os-arch-bsc-1117995.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/51119 (master PR not yet created)
Patch17:        fix-issue-2068-test.patch
# PATCH_FIX_OPENSUSE Temporary fix allowing "id_" and "force" params while upstrem figures it out
Patch18:        temporary-fix-extend-the-whitelist-of-allowed-comman.patch

### FQDNS ####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/51384 (master PR not yet created)
Patch19:        include-aliases-in-the-fqdns-grains.patch
###########

#### BATCH ASYNC - unified #####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/60269
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/50546
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/51863
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/139
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/141
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/144
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/52855
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/6af07030a502c427781991fc9a2b994fa04ef32e
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/002543df392f65d95dbc127dc058ac897f2035ed
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/55d8a777d6a9b19c959e14a4060e5579e92cd106
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/8378bb24a5a53973e8dba7658b8b3465d967329f
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/pull/182
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/pull/190
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/pull/217
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/8a23030d347b7487328c0395f5e30ef29daf1455
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/a38adfa2efe40c2b1508b685af0b5d28a6bbcfc8
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/b4c401cfe6031b61e27f7795bfa1aca6e8341e52
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/320
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/commit/25b4e3ea983b2606b2fb3d3c0e42f9840208bf84 (cleanup local code)
Patch20:        async-batch-implementation.patch
###########

# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/52743
Patch21:        switch-firewalld-state-to-use-change_interface.patch

### STANDALONE FORMULA CONFIGURATION ###
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/8ad65d6fa39edc7fc1967e2df1f3db0aa7df4d11
Patch22:        add-standalone-configuration-file-for-enabling-packa.patch
#############

# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/177
# (deviation from upstream - we should probably port this)
Patch23:        restore-default-behaviour-of-pkg-list-return.patch
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/pull/186 (missing upstream PR to master)
Patch24:        read-repo-info-without-using-interpolation-bsc-11356.patch
# PATCH_FIX_OPENSUSE https://github.com/openSUSE/salt/pull/191 (missing upstream PR to master)
Patch25:        let-salt-ssh-use-platform-python-binary-in-rhel8-191.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/a18ac47b75550bd55f4ca91dc221ed408881984c
Patch26:        make-setup.py-script-to-not-require-setuptools-9.1.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/228 (missing upstream PR)
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/da936daeebd701e147707ad814c07bfc259d4be (not yet upstream PR)
Patch27:        add-publish_batch-to-clearfuncs-exposed-methods.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/57779
Patch28:        info_installed-works-without-status-attr-now.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/58552
Patch29:        zypperpkg-ignore-retcode-104-for-search-bsc-1176697-.patch

# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/275 (missing upstream PR)
Patch30:        bsc-1176024-fix-file-directory-user-and-group-owners.patch

#### NO VENDOR CHANGE ####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/60421
Patch31:        allow-vendor-change-option-with-zypper.patch
###########

# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/58784
Patch32:        add-migrated-state-and-gpg-key-management-functions-.patch

### BEACON CONFIG ###
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/5ea2f10b15684dd417bad858642faafc92cd382
# (revert https://github.com/saltstack/salt/pull/58655)
Patch33:        revert-fixing-a-use-case-when-multiple-inotify-beaco.patch
###########

# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/298 (missing upstream PR)
Patch34:        fix-salt.utils.stringutils.to_str-calls-to-make-it-w.patch

# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/307 (missing upstream PR)
Patch35:        add-sleep-on-exception-handling-on-minion-connection.patch

### SALT-SSH PROCESSING TARGETS ###
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/336 (missing upstream PR)
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/353 (missing upstream PR)
Patch36:        update-target-fix-for-salt-ssh-to-process-targets-li.patch
############

# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/58503
Patch37:        fix-missing-minion-returns-in-batch-mode-360.patch

#### OPENSCAP ENHANCE ####
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/59756
Patch38:        enhance-openscap-module-add-xccdf_eval-call-386.patch
###############

# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/413 (missing upstream PR)
Patch39:        don-t-use-shell-sbin-nologin-in-requisites.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/432 (missing upstream PR)
Patch40:        fix-traceback.print_exc-calls-for-test_pip_state-432.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/415 (missing upstream PR)
Patch41:        prevent-pkg-plugins-errors-on-missing-cookie-path-bs.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/61180
Patch42:        dnfnotify-pkgset-plugin-implementation-3002.2-450.patch
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/pull/456 (missing upstream PR)
Patch43:        fix-the-regression-for-yumnotify-plugin-456.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/482
Patch44:        drop-serial-from-event.unpack-in-cli.batch_async.patch

### SALT-SSH WITH SALT BUNDLE ###
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/61715 (ssh_pre_flight_args)
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/493
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/497
Patch45:        add-salt-ssh-support-with-venv-salt-minion-3004-493.patch
Patch46:        prevent-shell-injection-via-pre_flight_script_args-4.patch
###############

# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/501
Patch47:        fix-salt-ssh-opts-poisoning-bsc-1197637-3004-501.patch

# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/505
Patch48:        prevent-affection-of-ssh.opts-with-lazyloader-bsc-11.patch

# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/506
Patch49:        fix-regression-with-depending-client.ssh-on-psutil-b.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/62109
Patch50:        use-salt-bundle-in-dockermod.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/61984
Patch51:        save-log-to-logfile-with-docker.build.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/534
Patch52:        fix-ownership-of-salt-thin-directory-when-using-the-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/62209
Patch53:        add-support-for-gpgautoimport-539.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/62519
Patch54:        change-the-delimeters-to-prevent-possible-tracebacks.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/62898
Patch55:        pass-the-context-to-pillar-ext-modules.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/commit/c6be36eeea49ee0d0641da272087305f79c32c99 (not yet upstream)
# Fix problem caused by: https://github.com/openSUSE/salt/pull/493 (Patch47) affecting only 3005.1.
Patch56:        use-rlock-to-avoid-deadlocks-in-salt-ssh.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/61064
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/commit/5e3ff4d662321c237ddd5b2c5c83f35a84af594c (not PR to master yet)
Patch57:        fixes-for-python-3.10-502.patch
# PATCH-FIX-OPENSUSE: https://github.com/openSUSE/salt/pull/571
Patch58:        control-the-collection-of-lvm-grains-via-config.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/63460
Patch59:        3005.1-implement-zypper-removeptf-573.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/63460
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/578
Patch60:        skip-package-names-without-colon-bsc-1208691-578.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/commit/c0fae09e5a4f6997a60007d970c7c6a5614d9102
Patch61:        fix-version-detection-and-avoid-building-and-testing.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64113
Patch62:        make-sure-the-file-client-is-destroyed-upon-used.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/581
Patch63:        avoid-conflicts-with-dependencies-versions-bsc-12116.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64369
Patch64:        define-__virtualname__-for-transactional_update-modu.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/587
Patch65:        make-master_tops-compatible-with-salt-3000-and-older.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/583
Patch66:        tornado-fix-an-open-redirect-in-staticfilehandler-cv.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/580
Patch67:        fix-some-issues-detected-in-salt-support-cli-module-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64510
Patch68:        3006.0-prevent-_pygit2.giterror-error-loading-known_.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64300
Patch69:        fix-utf8-handling-in-pass-renderer-and-make-it-more-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/63403
Patch70:        zypper-pkgrepo-alreadyconfigured-585.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64530
Patch71:        fix-the-regression-of-user.present-state-when-group-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64179
Patch72:        fix-regression-multiple-values-for-keyword-argument-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64554
Patch73:        mark-salt-3006-as-released-586.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64599
Patch74:        prevent-possible-exceptions-on-salt.utils.user.get_g.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/592
Patch75:        fix-tests-to-make-them-running-with-salt-testsuite.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/commit/f82860b8ad3ee786762fa02fa1a6eaf6e24dc8d4
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/65020
Patch76:        do-not-fail-on-bad-message-pack-message-bsc-1213441-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64510 (dropped at patch 91)
Patch77:        make-sure-configured-user-is-properly-set-by-salt-bs.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64959
Patch78:        fixed-gitfs-cachedir_basename-to-avoid-hash-collisio.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/600
Patch79:        revert-usage-of-long-running-req-channel-bsc-1213960.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/65238
Patch80:        write-salt-version-before-building-when-using-with-s.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/65036
Patch81:        fix-calculation-of-sls-context-vars-when-trailing-do.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/594
Patch82:        implement-the-calling-for-batch-async-from-the-salt-.patch
# PATCH-FIX_UPSTREAM: https://github.com/tornadoweb/tornado/pull/2277
Patch83:        only-call-native_str-on-curl_debug-message-in-tornad.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/65204
Patch84:        use-salt-call-from-salt-bundle-with-transactional_up.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/65181
Patch85:        improve-salt.utils.json.find_json-bsc-1213293.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/65266
Patch86:        fix-optimization_order-opt-to-prevent-test-fails.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65232
Patch87:        allow-all-primitive-grain-types-for-autosign_grains-.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65482
Patch88:        fix-cve-2023-34049-bsc-1215157.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65017
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65136
Patch89:        fix-gitfs-__env__-and-improve-cache-cleaning-bsc-119.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65435
Patch90:        dereference-symlinks-to-set-proper-__cli-opt-bsc-121.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/614 (revert patch 77)
Patch91:        revert-make-sure-configured-user-is-properly-set-by-.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65488
Patch92:        enable-keepalive-probes-for-salt-ssh-executions-bsc-.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65644
Patch93:        prefer-unittest.mock-for-python-versions-that-are-su.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/620
Patch94:        fix-the-aptpkg.py-unit-test-failure.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65092
Patch95:        update-__pillar__-during-pillar_refresh.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65969
Patch96:        fix-cve-2024-22231-and-cve-2024-22232-bsc-1219430-bs.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65009
Patch97:        fixed-keyerror-in-logs-when-running-a-state-that-fai.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65562
Patch98:        improve-pip-target-override-condition-with-venv_pip_.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65819
Patch99:        allow-kwargs-for-fileserver-roots-update-bsc-1218482.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66048
Patch100:       discover-both-.yml-and-.yaml-playbooks-bsc-1211888.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66130
Patch101:       fix-problematic-tests-and-allow-smooth-tests-executi.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/628
Patch102:       make-importing-seco.range-thread-safe-bsc-1211649.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66130
Patch103:       fix-tests-failures-and-errors-when-detected-on-vm-ex.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66234 (modified at Patch106)
Patch104:       decode-oscap-byte-stream-to-string-bsc-1219001.patch
### Commits to make Salt compatible with Python 3.11 (and 3.6)
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/commit/d92b5423464f93da6e3feb47d05a9acef8da75f9
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/commit/60b36489225f958772b6a2f99d8fe6ae33ee9d73
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/commit/eee0eca5e48922e5e404f812ced08ca7484bb568
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/commit/991f7cf0a7baf08a31194ce52f4ec08290db8e52
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/commit/2688c86f45eea9f8a6b916fcdf8eb94b3f5e185b
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/commit/a1873a1d6d50d1769ddef528d7442e38aba9de23
# PATCH-FIX_OPENSUSE https://github.com/openSUSE/salt/commit/c7ecccb0a080ca9cca097f760ef0992ab34f82df
Patch105:       fix-salt-warnings-and-testuite-for-python-3.11-635.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/639
Patch106:       switch-oscap-encoding-to-utf-8-639.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65982
Patch107:       remove-unused-import-causing-delays-on-starting-salt.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66024
Patch108:       make-logging-calls-lighter.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66034
Patch109:       improve-broken-events-catching-and-reporting.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/633
Patch110:       make-salt-master-self-recoverable-on-killing-eventpu.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66158
Patch111:       make-reactor-engine-less-blocking-the-eventpublisher.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/638
Patch112:       prevent-possible-exception-in-tornado.concurrent.fut.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66455
Patch113:       remove-redundant-_file_find-call-to-the-master.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/646
Patch114:       skip-tests-for-unsupported-algorithm-on-old-openssl-.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/652
Patch115:       add-missing-contextvars-dependency-in-salt.version.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/640
Patch116:       prevent-oom-with-high-amount-of-batch-async-calls-bs.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65983
Patch117:       do-not-call-the-async-wrapper-calls-with-the-separat.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66494
Patch118:       speed-up-salt.matcher.confirm_top-by-using-__context.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66593
Patch119:       several-fixes-for-tests-to-avoid-errors-and-failures.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/656
Patch120:       provide-systemd-timer-unit.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66630
Patch121:       skip-certain-tests-if-necessary-and-mark-some-flaky-.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66647
Patch122:       fix-status.diskusage-and-exclude-some-tests-to-run-w.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/65077
Patch123:       fix-user.list_groups-omits-remote-groups.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66695
Patch124:       some-more-small-tests-fixes-enhancements-661.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/666
Patch125:       test_vultrpy-adjust-test-expectation-to-prevent-fail.patch
# PATCH-FIX_UPSTREAM https://github.com/saltstack/salt/pull/66698
Patch126:       firewalld-normalize-new-rich-rules-before-comparing-.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/669
Patch127:       skip-more-tests-related-to-old-openssl-algorithms.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/662
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66730
Patch128:       make-tests-compatible-with-venv-bundle.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66743
Patch129:       replace-use-of-pygit2-deprecated-and-removed-1.15.0-.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/671
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/64173
Patch130:       join-masters-if-it-is-a-list-671.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66509
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/commit/0c3ebc0795f9c2adec90118281343cae3070e0f6
Patch131:       remove-redundant-run_func-from-salt.master.mworker._.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66818
Patch132:       improve-error-handling-with-different-openssl-versio.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66856
Patch133:       avoid-crash-on-wrong-output-of-systemctl-version-bsc.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66861
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/675
Patch134:       fix-test_system-flaky-setup_teardown-fn.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/676
Patch135:       fix-test_debian-to-work-in-our-infrastructure-676.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/677
Patch136:       fix-deprecated-code-677.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66780
Patch137:       fix-the-selinux-context-for-salt-minion-service-bsc-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66510
Patch138:       prevent-using-syncwrapper-with-no-reason.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66742
Patch139:       use-cachedir-for-extension_modules-in-salt-call-bsc-.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/680
Patch140:       revert-the-change-making-reactor-less-blocking-bsc-1.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66649
Patch141:       allow-namedloadercontexts-to-be-returned-from-loader.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/commit/d54407ba6dc664e5e5f3f613e27ae24f828c9648
Patch142:       avoid-explicit-reading-of-etc-salt-minion-bsc-122035.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/682
Patch143:       fix-x509-test-fails-on-old-openssl-systems-682.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/684
Patch144:       fix-x509-private-key-tests-and-test_suse-on-sle12-68.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/685
Patch145:       enhance-cleanup-mechanism-after-salt-bundle-upgrade-.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/commit/9683260d61668da8559ecde6caf63a52fedd8790
Patch146:       handle-logger-flushing-already-closed-file-686.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66422
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66757
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66760
Patch147:       make-minion-reconnecting-on-changing-master-ip-bsc-1.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/690
Patch148:       revert-setting-selinux-context-for-minion-service-bs.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/66899
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/698
Patch149:       fix-issues-that-break-salt-in-python-3.12-and-3.13-6.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67181
Patch150:       fix-virtual-grains-for-vms-running-on-nutanix-ahv-bs.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67023
Patch151:       enhance-find_json-garbage-filtering-bsc-1231605-688.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67105
Patch152:       update-for-deprecation-of-hex-in-pygit2-1.15.0-and-a.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67186
Patch153:       fix-failed-to-stat-root-.gitconfig-issue-on-gitfs-bs.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/commit/58f448405b7f46505b2047ecda72abb42b6df9d1
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/commit/79d4ff772a162b5b8e602e3437c13b90a25bc190
Patch154:       fix-tests-failures-after-repo.saltproject.io-depreca.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/60269
Patch155:       backport-batch-async-fixes-and-improvements-701.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/commit/560ab52ccf94c7974d5a418dfbba7409e0493066
Patch156:       fixed-file-client-private-attribute-reference-on-sal.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67734
Patch157:       set-virtual-grain-in-podman-systemd-container-703.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67066
Patch158:       repair-fstab_present-test-mode-702.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67746
Patch159:       make-_auth-calls-visible-with-master-stats-696.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/65843
Patch160:       repair-virt_query-outputter-655.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67754
Patch161:       remove-password-from-shell-after-functional-text-mat.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/692
Patch162:       add-deb822-apt-source-format-support-692.patch
# PATCH-FIX_OPENSUSE: https://github.com/openSUSE/salt/pull/678
Patch163:       remove-deprecated-code-from-x509.certificate_managed.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67782
Patch164:       make-x509-module-compatible-with-m2crypto-0.44.0.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67776
Patch165:       implement-multiple-inventory-for-ansible.targets.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67797
Patch166:       ensure-the-correct-crypt-module-is-loaded.patch
# PATCH-FIX_UPSTREAM: https://github.com/saltstack/salt/pull/67796
Patch167:       detect-openeuler-as-redhat-family-os.patch

### IMPORTANT: The line below is used as a snippet marker. Do not touch it.
### SALT PATCHES LIST END

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  logrotate
%if 0%{?suse_version} > 1020
BuildRequires:  fdupes
%endif

%if 0%{?_alternatives}
Requires:       %{name}-call = %{version}-%{release}
%else
Requires:       python3-%{name} = %{version}-%{release}
%endif
Obsoletes:      python2-%{name}

Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
Provides:       user(salt)
Provides:       group(salt)

%if 0%{?suse_version}
Requires(pre):  shadow
%endif

%if 0%{?suse_version}
Requires(pre):  dbus-1
%else
Requires(pre):  dbus
%endif

Requires:       logrotate
Requires:       procps

%if 0%{?suse_version} >= 1500
Requires:       iproute2
%else
%if 0%{?suse_version}
Requires:       net-tools
%else
Requires:       iproute
%endif
%endif

%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
%endif

%if %{with fish_completion}
%define fish_dir %{_datadir}/fish/
%define fish_completions_dir %{_datadir}/fish/completions/
%endif

%if %{with bash_completion}
%if 0%{?suse_version} >= 1140
BuildRequires:  bash-completion
%else
BuildRequires:  bash
%endif
%endif

%if %{with zsh_completion}
BuildRequires:  zsh
%endif

%define python_subpackage_only 1
%python_subpackages

%description
Salt is a distributed remote execution system used to execute commands and
query data. It was developed in order to bring the best solutions found in
the world of remote execution together and make them better, faster and more
malleable. Salt accomplishes this via its ability to handle larger loads of
information, and not just dozens, but hundreds or even thousands of individual
servers, handle them quickly and through a simple and manageable interface.

%if "%{flavor}" != "testsuite"

%if 0%{?singlespec_compat}
%package -n python3-salt
%else
%package -n python-salt
%endif
Summary:        python3 library for salt
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
BuildRequires:  python-rpm-macros
%if 0%{?rhel} == 8
BuildRequires:  platform-python
%else
BuildRequires:  %{python_module base}
%endif
BuildRequires:  %{python_module setuptools}
# requirements/base.txt
%if 0%{?rhel} || 0%{?fedora}
BuildRequires:  python3-jinja2
BuildRequires:  python3-m2crypto
BuildRequires:  python3-markupsafe
BuildRequires:  python3-msgpack > 0.3
BuildRequires:  python3-zmq >= 2.2.0
%else
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module MarkupSafe}
BuildRequires:  %{python_module msgpack-python > 0.3}
BuildRequires:  %{python_module pyzmq > 2.2.0}
%if 0%{?suse_version} >= 1500
BuildRequires:  %{python_module M2Crypto}
%else
BuildRequires:  %{python_module pycrypto >= 2.6.1}
%endif
%endif
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module requests >= 1.0.0}
BuildRequires:  %{python_module distro}
BuildRequires:  %{python_module looseversion}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module contextvars}

# requirements/zeromq.txt
%if %{with test}
BuildRequires:  %{python_module boto >= 2.32.1}
BuildRequires:  %{python_module mock if %python-base < 3.8}
BuildRequires:  %{python_module moto >= 0.3.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module salt-testing >= 2015.2.16}
BuildRequires:  %{python_module unittest2}
BuildRequires:  %{python_module xml}
%endif
%if %{with builddocs}
BuildRequires:  %{python_module sphinx}
%endif
%if 0%{?rhel} == 8
Requires:       platform-python
%else
%if 0%{?singlespec_compat}
Requires:       %{python_module base}
%else
Requires:       python-base
%endif
%endif

%if 0%{?_alternatives}
%if %{with libalternatives}
Requires:       alts
BuildRequires:  alts
%else
Requires(post): update-alternatives
Requires(postun):update-alternatives
%endif
%endif

# requirements/base.txt
%if 0%{?rhel} || 0%{?fedora}
Requires:       python3-jinja2
Requires:       python3-m2crypto
Requires:       python3-markupsafe
Requires:       python3-msgpack > 0.3
Requires:       python3-zmq >= 2.2.0

%if 0%{?rhel} >= 8 || 0%{?fedora} >= 30
Requires:       dnf
Requires:       python3-dnf-plugins-core
%endif
%else # SUSE
%if 0%{?singlespec_compat}
Requires:       %{python_module Jinja2}
Requires:       %{python_module MarkupSafe}
Requires:       %{python_module msgpack-python > 0.3}
%if 0%{?suse_version} >= 1500
Requires:       %{python_module M2Crypto}
%else
Requires:       %{python_module pycrypto >= 2.6.1}
%endif
Requires:       %{python_module pyzmq >= 2.2.0}
%else
Requires:       python-Jinja2
Requires:       python-MarkupSafe
Requires:       python-msgpack-python > 0.3
%if 0%{?suse_version} >= 1500
Requires:       python-M2Crypto
%else
Requires:       python-pycrypto >= 2.6.1
%endif
Requires:       python-pyzmq >= 2.2.0
%endif
%endif # end of RHEL / SUSE specific section
%if 0%{?singlespec_compat}
Recommends:     %{python_module jmespath}
Requires:       %{python_module PyYAML}
Requires:       %{python_module psutil}
Requires:       %{python_module requests >= 1.0.0}
Requires:       %{python_module distro}
Requires:       %{python_module looseversion}
Requires:       %{python_module packaging}
Requires:       %{python_module contextvars}
%if 0%{?suse_version}
# required for zypper.py
Requires:       %{python_module rpm}
# requirements/opt.txt (not all)
# Suggests:     python-MySQL-python  ## Disabled for now, originally Recommended
Suggests:       %{python_module timelib}
Suggests:       %{python_module gnupg}
%endif
%else
Recommends:     python-jmespath
Requires:       python-PyYAML
Requires:       python-psutil
Requires:       python-requests >= 1.0.0
Requires:       python-distro
Requires:       python-looseversion
Requires:       python-packaging
Requires:       python-contextvars
%if 0%{?suse_version}
# required for zypper.py
Requires:       python-rpm
# requirements/opt.txt (not all)
# Suggests:     python-MySQL-python  ## Disabled for now, originally Recommended
Suggests:       python-timelib
Suggests:       python-gnupg
# requirements/zeromq.txt
%endif
%endif
#
%if 0%{?suse_version}
# python-xml is part of python-base in all rhel versions
%if 0%{?singlespec_compat}
Requires:       %{python_module xml}
Requires:       %{python_module zypp-plugin}
Suggests:       %{python_module Mako}
Recommends:     %{python_module netaddr}
Recommends:     %{python_module pyinotify}
%else
Requires:       python-xml
Requires:       python-zypp-plugin
Suggests:       python-Mako
Recommends:     python-netaddr
Recommends:     python-pyinotify
%endif
Requires(pre):  libzypp(plugin:system) >= 0
%endif

# Required by Salt modules
Requires:       iputils
Requires:       sudo
Requires:       file
Recommends:     man
Recommends:     python3-passlib

%if 0%{?singlespec_compat}
Provides:       bundled(%{python_module tornado}) = 4.5.3
%else
Provides:       bundled(python-tornado) = 4.5.3
%endif

Provides:       %{name}-call = %{version}-%{release}

%if 0%{?singlespec_compat}
%description -n python3-salt
%else
%description -n python-salt
%endif
Python3 specific files for salt

%package api
Summary:        The api for Salt a parallel remote execution system
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-master = %{version}-%{release}
%if 0%{?suse_version}
%if 0%{?sle_version} >= 150400
Requires:       %{python_module CherryPy >= 3.2.2 if %python-salt}
%else
Requires:       python3-CherryPy >= 3.2.2
%endif
%else
Requires:       python3-cherrypy >= 3.2.2
%endif

%description api
salt-api is a modular interface on top of Salt that can provide a variety of entry points into a running Salt system.

%package cloud
Summary:        Generic cloud provisioning tool for Saltstack
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-master = %{version}-%{release}
%if 0%{?suse_version}
%if 0%{?sle_version} >= 150400
Requires:       %{python_module apache-libcloud if %python-salt}
Recommends:     %{python_module botocore if %python-salt}
Recommends:     %{python_module netaddr if %python-salt}
%else
Requires:       python3-apache-libcloud
Recommends:     python3-botocore
Recommends:     python3-netaddr
%endif
%else
Requires:       python3-apache-libcloud
%endif

%description cloud
public cloud VM management system
provision virtual machines on various public clouds via a cleanly
controlled profile and mapping system.

%if %{with docs}
%package doc
Summary:        Documentation for salt, a parallel remote execution system
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
This contains the documentation of salt, it is an offline version of http://docs.saltstack.com.
%endif

%package master
Summary:        The management component of Saltstack with zmq protocol supported
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
%if 0%{?suse_version}
%if 0%{?sle_version} >= 150400
Recommends:     %{python_module pygit2 >= 0.20.3 if %python-salt}
%else
Recommends:     python3-pygit2 >= 0.20.3
%endif
%endif
%ifarch %{ix86} x86_64
%if 0%{?suse_version}
%if 0%{?suse_version} > 1110
Requires:       dmidecode
%else
Requires:       pmtools
%endif
%endif
%endif
%if %{with systemd}
%{?systemd_requires}
BuildRequires:  systemd
%endif

%description master
The Salt master is the central server to which all minions connect.
Enabled commands to remote systems to be called in parallel rather
than serially.

%package minion
Summary:        The client component for Saltstack
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150000
Requires:       (%{name}-transactional-update = %{version}-%{release} if read-only-root-fs)
%endif

%if %{with systemd}
%{?systemd_requires}
%endif

%description minion
Salt minion is queried and controlled from the master.
Listens to the salt master and execute the commands.

%package proxy
Summary:        Component for salt that enables controlling arbitrary devices
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
%if %{with systemd}
%{?systemd_requires}
%endif

%description proxy
Proxy minions are a developing Salt feature that enables controlling devices that,
for whatever reason, cannot run a standard salt-minion.
Examples include network gear that has an API but runs a proprietary OS,
devices with limited CPU or memory, or devices that could run a minion, but for
security reasons, will not.

%package syndic
Summary:        The syndic component for saltstack
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-master = %{version}-%{release}
%if %{with systemd}
%{?systemd_requires}
%endif

%description syndic
Salt syndic is the master-of-masters for salt
The master of masters for salt-- it enables
the management of multiple masters at a time..

%package ssh
Summary:        Management component for Saltstack with ssh protocol
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-master = %{version}-%{release}
%if 0%{?suse_version}
Recommends:     sshpass
%endif
%if %{with systemd}
%{?systemd_requires}
%endif

%description ssh
Salt ssh is a master running without zmq.
it enables the management of minions over a ssh connection.

%if %{with bash_completion}
%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       bash-completion
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description bash-completion
Bash command line completion support for %{name}.

%endif

%if %{with fish_completion}
%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}

%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description fish-completion
Fish command line completion support for %{name}.
%endif

%if %{with zsh_completion}
%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       zsh
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description zsh-completion
Zsh command line completion support for %{name}.

%endif

%package standalone-formulas-configuration
Summary:        Standalone Salt configuration to make the packaged formulas available for the Salt master
Group:          System/Management
Requires:       %{name}
Provides:       salt-formulas-configuration
Conflicts:      otherproviders(salt-formulas-configuration)

%description standalone-formulas-configuration
This package adds the standalone configuration for the Salt master in order to make the packaged Salt formulas available on the Salt master

%package transactional-update
Summary:        Transactional update executor configuration
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-minion = %{version}-%{release}
Requires:       tar

%description transactional-update
For transactional systems, like MicroOS, Salt can operate
transparently if the executor "transactional-update" is registered in
list of active executors.  This package add the configuration file.

%endif

%if "%{flavor}" == "testsuite"

%if 0%{?singlespec_compat}
%package -n python3-salt-testsuite
%else
%package -n python-salt-testsuite
%endif
Summary:        Unit and integration tests for Salt

%if 0%{?rhel} == 8
BuildRequires:  platform-python
%else
BuildRequires:  %{python_module base}
%endif
BuildRequires:  %{python_module setuptools}

Requires:       salt = %{version}
%if 0%{?singlespec_compat}
Recommends:     %{python_module CherryPy}
Requires:       %{python_module Genshi}
Requires:       %{python_module Mako}
%if !0%{?suse_version} > 1600 || 0%{?centos}
Requires:       %{python_module boto}
%endif
Requires:       %{python_module boto3}
Requires:       %{python_module docker}
%if 0%{?suse_version} < 1600
Requires:       %{python_module mock}
%endif
Requires:       %{python_module pygit2}
Requires:       %{python_module pytest >= 7.0.1}
Requires:       %{python_module pytest-httpserver}
Requires:       %{python_module pytest-salt-factories >= 1.0.0~rc21}
Requires:       %{python_module pytest-subtests}
Requires:       %{python_module testinfra}
Requires:       %{python_module yamllint}
Requires:       %{python_module pip}
%else
Recommends:     python-CherryPy
Requires:       python-Genshi
Requires:       python-Mako
%if !0%{?suse_version} > 1600 || 0%{?centos}
Requires:       python-boto
%endif
Requires:       python-boto3
Requires:       python-docker
%if 0%{?suse_version} < 1600
Requires:       python-mock
%endif
Requires:       python-pygit2
Requires:       python-pytest >= 7.0.1
Requires:       python-pytest-httpserver
Requires:       python-pytest-salt-factories >= 1.0.0~rc21
Requires:       python-pytest-subtests
Requires:       python-testinfra
Requires:       python-yamllint
Requires:       python-pip
%endif
Requires:       docker
Requires:       openssh
Requires:       git

Obsoletes:      %{name}-tests

%if 0%{?singlespec_compat}
%description -n python3-salt-testsuite
%else
%description -n python-salt-testsuite
%endif
Collection of unit, functional, and integration tests for %{name}.

%endif

%prep
%setup -q -n salt-%{version}-suse
cp %{S:1} .
cp %{S:5} ./.travis.yml
cp %{S:6} .
%autopatch -p1

%build
%if "%{flavor}" != "testsuite"

# Putting /usr/bin at the front of $PATH is needed for RHEL/RES 7. Without this
# change, the RPM will require /bin/python, which is not provided by any package
# on RHEL/RES 7.
%if 0%{?fedora} || 0%{?rhel}
export PATH=/usr/bin:$PATH
%endif
%{python_expand #
$python setup.py --with-salt-version=%{version} --salt-transport=both build
mv build _build.%{$python_bin_suffix}
}

%if %{with docs} && %{without builddocs}
# extract docs from the tarball
mkdir -p doc/_build
pushd doc/_build/
tar xfv %{S:3}
popd
%endif

%if %{with docs} && %{with builddocs}
## documentation
cd doc && make html && rm _build/html/.buildinfo && rm _build/html/_images/proxy_minions.png && cd _build/html && chmod -R -x+X *
%endif

%endif

%install
%if "%{flavor}" != "testsuite"

%{python_expand #
mv _build.%{$python_bin_suffix} build
$python setup.py --salt-transport=both install --prefix=%{_prefix} --root=%{buildroot}
mv build _build.%{$python_bin_suffix}

DEF_PYPATH=_build.%{$python_bin_suffix}/scripts-*/

rm -f %{buildroot}%{_bindir}/*
for script in $DEF_PYPATH/*; do
  install -m 0755 $script %{buildroot}%{_bindir}
done
}

## create missing directories
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/cloud
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/master
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/master/jobs
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/master/proc
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/master/queues
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/master/roots
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/master/syndics
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/master/tokens
install -Dd -m 0750 %{buildroot}%{_localstatedir}/cache/salt/minion/extmod
install -Dd -m 0750 %{buildroot}%{_localstatedir}/log/salt
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/cloud.maps.d
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/cloud.profiles.d
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/cloud.providers.d
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/master.d
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/minion.d
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki/master
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki/master/minions
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki/master/minions_autosign
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki/master/minions_denied
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki/master/minions_pre
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki/master/minions_rejected
install -Dd -m 0750 %{buildroot}%{_sysconfdir}/salt/pki/minion
install -Dd -m 0750 %{buildroot}/srv/pillar
install -Dd -m 0750 %{buildroot}/srv/salt
install -Dd -m 0750 %{buildroot}/srv/spm
install -Dd -m 0750 %{buildroot}/var/lib/salt
install -Dd -m 0755 %{buildroot}%{_docdir}/salt
install -Dd -m 0755 %{buildroot}%{_sbindir}
%if 0%{?suse_version} > 1500
install -Dd -m 0755 %{buildroot}%{_distconfdir}/logrotate.d
%else
install -Dd -m 0755 %{buildroot}%{_sysconfdir}/logrotate.d
%endif

# Install salt-support profiles
%{python_expand #
install -Dpm 0644 salt/cli/support/profiles/* %{buildroot}%{$python_sitelib}/salt/cli/support/profiles
}

%endif

%if "%{flavor}" == "testsuite"
# Install Salt tests
%{python_expand #
install -Dd %{buildroot}%{$python_sitelib}/salt-testsuite
cp -a tests %{buildroot}%{$python_sitelib}/salt-testsuite/
# Remove runtests.py which is not used as deprecated method of running the tests
rm %{buildroot}%{$python_sitelib}/salt-testsuite/tests/runtests.py
# Copy conf files to the testsuite as they are used by the tests
cp -a conf %{buildroot}%{$python_sitelib}/salt-testsuite/
}
%endif

%if "%{flavor}" != "testsuite"

## Install Zypper plugins only on SUSE machines
%if 0%{?suse_version}
install -Dd -m 0750 %{buildroot}%{_prefix}/lib/zypp/plugins/commit
%{__install} scripts/suse/zypper/plugins/commit/zyppnotify %{buildroot}%{_prefix}/lib/zypp/plugins/commit/zyppnotify
%endif

# Install DNF plugin only on RH machines
%if 0%{?fedora} >= 22 || 0%{?rhel} >= 8
install -Dd %{buildroot}%{python3_sitelib}/dnf-plugins
install -Dd %{buildroot}%{python3_sitelib}/dnf-plugins/__pycache__
install -Dd %{buildroot}%{_sysconfdir}/dnf/plugins
%{__install} scripts/suse/dnf/plugins/dnfnotify.py %{buildroot}%{python3_sitelib}/dnf-plugins
%{__install} scripts/suse/dnf/plugins/dnfnotify.conf %{buildroot}%{_sysconfdir}/dnf/plugins
%{__python3} -m compileall -d %{python3_sitelib}/dnf-plugins %{buildroot}%{python3_sitelib}/dnf-plugins/dnfnotify.py
%{__python3} -O -m compileall -d %{python3_sitelib}/dnf-plugins %{buildroot}%{python3_sitelib}/dnf-plugins/dnfnotify.py
%endif

## install init and systemd scripts
%if %{with systemd}
install -Dpm 0644 pkg/old/suse/salt-master.service %{buildroot}%{_unitdir}/salt-master.service
%if 0%{?suse_version}
install -Dpm 0644 pkg/old/suse/salt-minion.service %{buildroot}%{_unitdir}/salt-minion.service
%else
install -Dpm 0644 pkg/old/suse/salt-minion.service.rhel7 %{buildroot}%{_unitdir}/salt-minion.service
%endif
install -Dpm 0644 pkg/common/salt-syndic.service %{buildroot}%{_unitdir}/salt-syndic.service
install -Dpm 0644 pkg/old/suse/salt-api.service    %{buildroot}%{_unitdir}/salt-api.service
install -Dpm 0644 pkg/common/salt-proxy@.service %{buildroot}%{_unitdir}/salt-proxy@.service
ln -s service %{buildroot}%{_sbindir}/rcsalt-master
ln -s service %{buildroot}%{_sbindir}/rcsalt-syndic
ln -s service %{buildroot}%{_sbindir}/rcsalt-minion
ln -s service %{buildroot}%{_sbindir}/rcsalt-api
install -Dpm 644 %{S:2}                   %{buildroot}/usr/lib/tmpfiles.d/salt.conf
%endif

#
## install config files
install -Dpm 0640 conf/minion %{buildroot}%{_sysconfdir}/salt/minion
touch  -m 0640 -r conf/minion %{buildroot}%{_sysconfdir}/salt/minion_id # ghost file
install -Dpm 0640 conf/master %{buildroot}%{_sysconfdir}/salt/master
install -Dpm 0640 conf/roster %{buildroot}%{_sysconfdir}/salt/roster
install -Dpm 0640 conf/cloud %{buildroot}%{_sysconfdir}/salt/cloud
install -Dpm 0640 conf/cloud.profiles %{buildroot}%{_sysconfdir}/salt/cloud.profiles
install -Dpm 0640 conf/cloud.providers %{buildroot}%{_sysconfdir}/salt/cloud.providers
install -Dpm 0640 transactional_update.conf %{buildroot}%{_sysconfdir}/salt/minion.d/transactional_update.conf
#
%if 0%{?suse_version} > 1500
install -Dpm 0644  pkg/old/suse/salt-common.logrotate %{buildroot}%{_distconfdir}/logrotate.d/salt
%else
install -Dpm 0644  pkg/old/suse/salt-common.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/salt
%endif
#
%if 0%{?suse_version} <= 1500
## install SuSEfirewall2 rules
install -Dpm 0644  pkg/old/suse/salt.SuSEfirewall2 %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/salt
%endif
#
## install completion scripts
%if %{with bash_completion}
install -Dpm 0644 pkg/common/salt.bash %{buildroot}%{_sysconfdir}/bash_completion.d/salt
%endif
%if %{with zsh_completion}
install -Dpm 0644 pkg/common/salt.zsh %{buildroot}%{_sysconfdir}/zsh_completion.d/salt
%endif

%if %{with fish_completion}
mkdir -p %{buildroot}%{fish_completions_dir}
install -Dpm 0644 pkg/common/fish-completions/* %{buildroot}%{fish_completions_dir}
%endif

# Standalone Salt formulas configuration
install -Dd -m 0750 %{buildroot}%{_prefix}/share/salt-formulas
install -Dd -m 0750 %{buildroot}%{_prefix}/share/salt-formulas/states
install -Dd -m 0750 %{buildroot}%{_prefix}/share/salt-formulas/metadata
install -Dpm 0640 conf/suse/standalone-formulas-configuration.conf %{buildroot}%{_sysconfdir}/salt/master.d
install -Dpm 0640 conf/suse/standalone-formulas-configuration.conf %{buildroot}%{_sysconfdir}/salt/minion.d

%if 0%{?suse_version} > 1020
%fdupes %{buildroot}%{_docdir}
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if 0%{?_alternatives}
%python_clone -a %{buildroot}%{_bindir}/salt-call
%python_clone -a %{buildroot}%{_bindir}/salt-support
%python_clone -a %{buildroot}%{_bindir}/spm
install -Dd -m 0750 %{buildroot}%{_exec_prefix}/libexec/salt
for SALT_SCRIPT in salt salt-api salt-cloud salt-cp salt-key salt-master salt-minion salt-proxy salt-run salt-ssh salt-syndic; do
    mv "%{buildroot}%{_bindir}/${SALT_SCRIPT}" "%{buildroot}%{_exec_prefix}/libexec/salt/"
%python_clone -a %{buildroot}%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}
    ln -s "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}" "%{buildroot}%{_bindir}/${SALT_SCRIPT}"
done
mv "%{buildroot}%{_prefix}/lib/zypp/plugins/commit/zyppnotify" "%{buildroot}%{_exec_prefix}/libexec/salt/"
%python_clone -a %{buildroot}%{_exec_prefix}/libexec/salt/zyppnotify
ln -s "%{_exec_prefix}/libexec/salt/zyppnotify" "%{buildroot}%{_prefix}/lib/zypp/plugins/commit/zyppnotify"
%endif

%endif

%check
%if %{with test}
%{python_expand #
$python setup.py test --runtests-opts=-u
}
%endif

%if "%{flavor}" != "testsuite"

%pre
S_HOME="/var/lib/salt"
S_PHOME="/srv/salt"
getent passwd salt | grep $S_PHOME >/dev/null && usermod -d $S_HOME salt
getent group salt >/dev/null || %{_sbindir}/groupadd -r salt
getent passwd salt >/dev/null || %{_sbindir}/useradd -r -g salt -d $S_HOME -s /bin/false -c "salt-master daemon" salt
if [[ -d "$S_PHOME/.ssh" ]]; then
    mv $S_PHOME/.ssh $S_HOME
fi
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/etc; save any old .rpmsave
test -f %{_sysconfdir}/logrotate.d/salt.rpmsave && mv -v %{_sysconfdir}/logrotate.d/salt.rpmsave %{_sysconfdir}/logrotate.d/salt.rpmsave.old ||:
%endif

%post
%if %{with systemd}
systemd-tmpfiles --create /usr/lib/tmpfiles.d/salt.conf || true
%else
dbus-uuidgen --ensure
%endif

%if 0%{?suse_version} > 1500
%posttrans
# Migration to /usr/etc, restore just created .rpmsave
test -f %{_sysconfdir}/logrotate.d/salt.rpmsave && mv -v %{_sysconfdir}/logrotate.d/salt.rpmsave %{_sysconfdir}/logrotate.d/salt ||:
test -f %{_sysconfdir}/logrotate.d/salt.rpmsave.old && mv -v %{_sysconfdir}/logrotate.d/salt.rpmsave.old %{_sysconfdir}/logrotate.d/salt.rpmsave ||:
%endif

%preun proxy
%if %{with systemd}
%if 0%{?suse_version}
%service_del_preun salt-proxy@.service
%else
%systemd_preun salt-proxy@.service
%endif
%else
%if 0%{?suse_version}
%stop_on_removal salt-proxy
%endif
%endif

%pre proxy
%if %{with systemd}
%if 0%{?suse_version}
%service_add_pre salt-proxy@.service
%endif
%endif

%post proxy
%if %{with systemd}
%if 0%{?suse_version}
%service_add_post salt-proxy@.service
%else
%systemd_post salt-proxy@.service
%endif
%endif

%postun proxy
%if %{with systemd}
%if 0%{?suse_version}
%service_del_postun salt-proxy@.service
%else
%systemd_postun_with_restart salt-proxy@.service
%endif
%endif

%preun syndic
%if %{with systemd}
%if 0%{?suse_version}
%service_del_preun salt-syndic.service
%else
%systemd_preun salt-syndic.service
%endif
%endif

%pre syndic
%if %{with systemd}
%if 0%{?suse_version}
%service_add_pre salt-syndic.service
%endif
%endif

%post syndic
%if %{with systemd}
%if 0%{?suse_version}
%service_add_post salt-syndic.service
%else
%systemd_post salt-syndic.service
%endif
%endif

%postun syndic
%if %{with systemd}
%if 0%{?suse_version}
%service_del_postun salt-syndic.service
%else
%systemd_postun_with_restart salt-syndic.service
%endif
%endif

%preun master
%if %{with systemd}
%if 0%{?suse_version}
%service_del_preun salt-master.service
%else
%systemd_preun salt-master.service
%endif
%endif

%pre master
%if %{with systemd}
%if 0%{?suse_version}
%service_add_pre salt-master.service
%endif
%endif

%post master
if [ $1 -eq 2 ] ; then
  # Upgrading from an earlier version.  If this is from 2014, where daemons
  # ran as root, we need to chown some stuff to salt in order for the new
  # version to actually work.  It seems a manual restart of salt-master may
  # still be required, but at least this will actually work given the file
  # ownership is correct.
  # Symlinks are excluded to avoid possible user escalation (bsc#1157465) (CVE-2019-18897).
  for file in master.{pem,pub} ; do
    [ -f /etc/salt/pki/master/$file ] && [ ! -L /etc/salt/pki/master/$file ] && chown --no-dereference salt /etc/salt/pki/master/$file
  done
  MASTER_CACHE_DIR="/var/cache/salt/master"
  [ -d $MASTER_CACHE_DIR ] && find $MASTER_CACHE_DIR -type d | xargs -r chown --no-dereference salt:salt
  [ -d $MASTER_CACHE_DIR ] && find $MASTER_CACHE_DIR -type f | xargs -r chown --no-dereference salt:salt
  [ -f $MASTER_CACHE_DIR/.root_key ] && chown --no-dereference root:root $MASTER_CACHE_DIR/.root_key
  true
fi
%if %{with systemd}
systemd_ver=$(rpm -q systemd --queryformat="%%{VERSION}")
if [ "${systemd_ver%%.*}" -lt 228 ]; then
  # On systemd < 228 the 'TasksTask' attribute is not available.
  # Removing TasksMax from salt-master.service on SLE12SP1 LTSS (bsc#985112)
  sed -i '/TasksMax=infinity/d' %{_unitdir}/salt-master.service
fi
%if 0%{?suse_version}
%service_add_post salt-master.service
%else
%systemd_post salt-master.service
%endif
%endif

%postun master
%if %{with systemd}
%if 0%{?suse_version}
%service_del_postun salt-master.service
%else
%systemd_postun_with_restart salt-master.service
%endif
%endif

%preun minion
%if %{with systemd}
%if 0%{?suse_version}
%service_del_preun salt-minion.service
%else
%systemd_preun salt-minion.service
%endif
%endif

%pre minion
%if %{with systemd}
%if 0%{?suse_version}
%service_add_pre salt-minion.service
%endif
%endif

%post minion
%if %{with systemd}
%if 0%{?suse_version}
%service_add_post salt-minion.service
%else
%systemd_post salt-minion.service
%endif
%endif

%postun minion
%if %{with systemd}
%if 0%{?suse_version}
%service_del_postun salt-minion.service
%else
%systemd_postun_with_restart salt-minion.service
%endif
%endif

%preun api
%if %{with systemd}
%if 0%{?suse_version}
%service_del_preun salt-api.service
%else
%systemd_preun salt-api.service
%endif
%else
%stop_on_removal
%endif

%pre api
%if %{with systemd}
%if 0%{?suse_version}
%service_add_pre salt-api.service
%endif
%endif

%post api
%if %{with systemd}
%if 0%{?suse_version}
%service_add_post salt-api.service
%else
%systemd_post salt-api.service
%endif
%endif

%postun api
%if %{with systemd}
%if 0%{?suse_version}
%service_del_postun salt-api.service
%else
%systemd_postun_with_restart salt-api.service
%endif
%endif

%if 0%{?_alternatives}
%pre -n python-salt
for SALT_SCRIPT in salt-call salt-support spm; do
    [ -h "%{_bindir}/${SALT_SCRIPT}" ] || rm -f "%{_bindir}/${SALT_SCRIPT}"
    if [ "$1" -gt 0 ] && [ -f /usr/sbin/update-alternatives ]; then
        update-alternatives --quiet --remove "${SALT_SCRIPT}" "%{_bindir}/${SALT_SCRIPT}-%{python_bin_suffix}"
    fi
done
for SALT_SCRIPT in salt salt-api salt-cloud salt-cp salt-key salt-master salt-minion salt-proxy salt-run salt-ssh salt-syndic zyppnotify; do
    [ -h "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}" ] || rm -f "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}"
    if [ "$1" -gt 0 ] && [ -f /usr/sbin/update-alternatives ]; then
        update-alternatives --quiet --remove "${SALT_SCRIPT}" "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}-%{python_bin_suffix}"
    fi
done

%if ! %{with libalternatives}
%post -n python-salt
if [ -f /usr/sbin/update-alternatives ]; then
    for SALT_SCRIPT in salt-call salt-support spm; do
        update-alternatives --quiet --install "%{_bindir}/${SALT_SCRIPT}" "${SALT_SCRIPT}" \
            "%{_bindir}/${SALT_SCRIPT}-%{python_bin_suffix}" %{python_version_nodots}
    done
    for SALT_SCRIPT in salt salt-api salt-cloud salt-cp salt-key salt-master salt-minion salt-proxy salt-run salt-ssh salt-syndic zyppnotify; do
        update-alternatives --quiet --install "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}" "${SALT_SCRIPT}" \
            "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}-%{python_bin_suffix}" %{python_version_nodots}
    done
fi

%postun -n python-salt
if [ -f /usr/sbin/update-alternatives ]; then
    for SALT_SCRIPT in salt-call salt-support spm; do
        if [ ! -e "%{_bindir}/${SALT_SCRIPT}-%{python_bin_suffix}" ]; then
            update-alternatives --quiet --remove "${SALT_SCRIPT}" "%{_bindir}/${SALT_SCRIPT}-%{python_bin_suffix}"
        fi
    done
    for SALT_SCRIPT in salt salt-api salt-cloud salt-cp salt-key salt-master salt-minion salt-proxy salt-run salt-ssh salt-syndic zyppnotify; do
        if [ ! -e "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}-%{python_bin_suffix}" ]; then
            update-alternatives --quiet --remove "${SALT_SCRIPT}" "%{_exec_prefix}/libexec/salt/${SALT_SCRIPT}-%{python_bin_suffix}"
        fi
    done
fi
%endif
%endif

%if 0%{?singlespec_compat}
%posttrans -n %{python_module salt}
%else
%posttrans -n python-salt
%endif
# force re-generate a new thin.tgz
rm -f %{_localstatedir}/cache/salt/master/thin/version
rm -f %{_localstatedir}/cache/salt/minion/thin/version

%files api
%defattr(-,root,root)
%{_bindir}/salt-api
%if %{with systemd}
%{_sbindir}/rcsalt-api
%{_unitdir}/salt-api.service
%endif
%{_mandir}/man1/salt-api.1.*

%files cloud
%defattr(-,root,root)
%{_bindir}/salt-cloud
%dir               %attr(0750, root, salt) %{_sysconfdir}/salt/cloud.maps.d
%dir               %attr(0750, root, salt) %{_sysconfdir}/salt/cloud.profiles.d
%dir               %attr(0750, root, salt) %{_sysconfdir}/salt/cloud.providers.d
%config(noreplace) %attr(0640, root, salt) %{_sysconfdir}/salt/cloud
%config(noreplace) %attr(0640, root, salt) %{_sysconfdir}/salt/cloud.profiles
%config(noreplace) %attr(0640, root, salt) %{_sysconfdir}/salt/cloud.providers
%dir               %attr(0750, root, salt) %{_localstatedir}/cache/salt/cloud
%attr(755,root,root)%{python3_sitelib}/salt/cloud/deploy/bootstrap-salt.sh
%{_mandir}/man1/salt-cloud.1.*

%files ssh
%defattr(-,root,root)
%{_bindir}/salt-ssh
%{_mandir}/man1/salt-ssh.1.gz

%files syndic
%defattr(-,root,root)
%{_bindir}/salt-syndic
%{_mandir}/man1/salt-syndic.1.gz
%if %{with systemd}
%{_sbindir}/rcsalt-syndic
%{_unitdir}/salt-syndic.service
%endif

%files minion
%defattr(-,root,root)
%{_bindir}/salt-minion
%{_mandir}/man1/salt-minion.1.gz
%config(noreplace) %attr(0640, root, root) %{_sysconfdir}/salt/minion
%config(noreplace) %attr(0640, root, root) %ghost %{_sysconfdir}/salt/minion_id
%dir               %attr(0750, root, root) %{_sysconfdir}/salt/minion.d/
%dir               %attr(0750, root, root) %{_sysconfdir}/salt/pki/minion/
%dir               %attr(0750, root, root) %{_localstatedir}/cache/salt/minion/
%if %{with systemd}
%{_sbindir}/rcsalt-minion
%endif

# Install plugin only on SUSE machines
%if 0%{?suse_version}
%{_prefix}/lib/zypp/plugins/commit/zyppnotify
%endif

# Install DNF plugin only on RH machines
%if 0%{?fedora} >= 22 || 0%{?rhel} >= 8
%{python3_sitelib}/dnf-plugins/dnfnotify.py
%{python3_sitelib}/dnf-plugins/__pycache__/dnfnotify.*
%{_sysconfdir}/dnf/plugins/dnfnotify.conf
%endif

%if %{with systemd}
%{_unitdir}/salt-minion.service
%endif

%files proxy
%defattr(-,root,root)
%{_bindir}/salt-proxy
%{_mandir}/man1/salt-proxy.1.gz
%if %{with systemd}
%{_unitdir}/salt-proxy@.service
%endif

%files master
%defattr(-,root,root)
%{_bindir}/salt
%{_bindir}/salt-master
%{_bindir}/salt-cp
%{_bindir}/salt-key
%{_bindir}/salt-run
%{_mandir}/man1/salt-master.1.gz
%{_mandir}/man1/salt-cp.1.gz
%{_mandir}/man1/salt-key.1.gz
%{_mandir}/man1/salt-run.1.gz
%{_mandir}/man7/salt.7.gz
%if 0%{?suse_version} <= 1500
%config(noreplace) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/salt
%endif
%if %{with systemd}
%{_sbindir}/rcsalt-master
%{_unitdir}/salt-master.service
%endif
#
%config(noreplace) %attr(0640, root, salt) %{_sysconfdir}/salt/master
%config(noreplace) %attr(0640, root, salt) %{_sysconfdir}/salt/roster
%dir               %attr(0755, root, salt) %{_sysconfdir}/salt/master.d/
%dir               %attr(0750, salt, salt) %{_sysconfdir}/salt/pki/master/
%dir               %attr(0750, salt, salt) %{_sysconfdir}/salt/pki/master/minions/
%dir               %attr(0750, salt, salt) %{_sysconfdir}/salt/pki/master/minions_autosign/
%dir               %attr(0750, salt, salt) %{_sysconfdir}/salt/pki/master/minions_denied/
%dir               %attr(0750, salt, salt) %{_sysconfdir}/salt/pki/master/minions_pre/
%dir               %attr(0750, salt, salt) %{_sysconfdir}/salt/pki/master/minions_rejected/
%dir               %attr(0755, salt, salt) /var/lib/salt
%dir               %attr(0755, root, salt) /srv/salt
%dir               %attr(0755, root, salt) /srv/pillar
%dir               %attr(0750, salt, salt) %{_localstatedir}/cache/salt/master/
%dir               %attr(0750, salt, salt) %{_localstatedir}/cache/salt/master/jobs/
%dir               %attr(0750, salt, salt) %{_localstatedir}/cache/salt/master/proc/
%dir               %attr(0750, salt, salt) %{_localstatedir}/cache/salt/master/queues/
%dir               %attr(0750, salt, salt) %{_localstatedir}/cache/salt/master/roots/
%dir               %attr(0750, salt, salt) %{_localstatedir}/cache/salt/master/syndics/
%dir               %attr(0750, salt, salt) %{_localstatedir}/cache/salt/master/tokens/

%files
%defattr(-,root,root,-)
%{_bindir}/spm
%if ! 0%{?_alternatives}
%{_bindir}/salt-call
%endif
%{_bindir}/salt-support
%{_mandir}/man1/salt-call.1.gz
%{_mandir}/man1/spm.1.gz
%if 0%{?suse_version} > 1500
%{_distconfdir}/logrotate.d/salt
%else
%config(noreplace) %{_sysconfdir}/logrotate.d/salt
%endif
%{!?_licensedir:%global license %doc}
%license LICENSE
%doc AUTHORS README.rst README.SUSE
#
%dir        %attr(0750, root, salt) %{_sysconfdir}/salt
%dir        %attr(0750, root, salt) %{_sysconfdir}/salt/pki
%dir        %attr(0750, salt, salt) %{_localstatedir}/log/salt
%dir        %attr(0750, root, salt) %{_localstatedir}/cache/salt
%dir        %attr(0750, root, salt) /srv/spm
%if %{with systemd}
/usr/lib/tmpfiles.d/salt.conf
%endif
%{_mandir}/man1/salt.1.*

%files %{python_files salt}
%defattr(-,root,root,-)
%if 0%{?_alternatives}
%python_alternative %{_bindir}/salt-call
%python_alternative %{_bindir}/salt-support
%python_alternative %{_bindir}/spm
%dir %{_exec_prefix}/libexec
%dir %attr(0755, root, root) %{_exec_prefix}/libexec/salt
%python_alternative %{_exec_prefix}/libexec/salt/salt
%python_alternative %{_exec_prefix}/libexec/salt/salt-api
%python_alternative %{_exec_prefix}/libexec/salt/salt-cloud
%python_alternative %{_exec_prefix}/libexec/salt/salt-cp
%python_alternative %{_exec_prefix}/libexec/salt/salt-key
%python_alternative %{_exec_prefix}/libexec/salt/salt-master
%python_alternative %{_exec_prefix}/libexec/salt/salt-minion
%python_alternative %{_exec_prefix}/libexec/salt/salt-proxy
%python_alternative %{_exec_prefix}/libexec/salt/salt-run
%python_alternative %{_exec_prefix}/libexec/salt/salt-ssh
%python_alternative %{_exec_prefix}/libexec/salt/salt-syndic
%python_alternative %{_exec_prefix}/libexec/salt/zyppnotify
%endif

%dir %{python_sitelib}/salt
%dir %{python_sitelib}/salt-*.egg-info
%{python_sitelib}/salt/*
%{python_sitelib}/salt-*.egg-info/*
%exclude %{python_sitelib}/salt/cloud/deploy/*.sh

%if %{with docs}
%files doc
%defattr(-,root,root)
%doc doc/_build/html
%endif

%if %{with bash_completion}
%files bash-completion
%defattr(-,root,root)
%dir %{_sysconfdir}/bash_completion.d/
%config %{_sysconfdir}/bash_completion.d/%{name}
%endif

%if %{with zsh_completion}
%files zsh-completion
%defattr(-,root,root)
%dir %{_sysconfdir}/zsh_completion.d/
%config %{_sysconfdir}/zsh_completion.d/%{name}
%endif

%if %{with fish_completion}
%files fish-completion
%defattr(-,root,root)
%{fish_completions_dir}/salt*
%dir %{fish_completions_dir}
%dir %{fish_dir}
%endif

%files standalone-formulas-configuration
%defattr(-,root,root)
%dir               %attr(0755, root, salt) %{_sysconfdir}/salt/master.d/
%config(noreplace) %attr(0640, root, salt) %{_sysconfdir}/salt/master.d/standalone-formulas-configuration.conf
%dir               %attr(0750, root, root) %{_sysconfdir}/salt/minion.d/
%config(noreplace) %attr(0640, root, root) %{_sysconfdir}/salt/minion.d/standalone-formulas-configuration.conf
%dir               %attr(0755, root, salt) %{_prefix}/share/salt-formulas/
%dir               %attr(0755, root, salt) %{_prefix}/share/salt-formulas/states/
%dir               %attr(0755, root, salt) %{_prefix}/share/salt-formulas/metadata/

%files transactional-update
%defattr(-,root,root)
%config(noreplace) %attr(0640, root, root) %{_sysconfdir}/salt/minion.d/transactional_update.conf

%endif

%if "%{flavor}" == "testsuite"
%files %{python_files salt-testsuite}
%{python_sitelib}/salt-testsuite
%endif

%changelog
* Mon Mar 10 2025 Victor Zhestkov <vzhestkov@suse.com>
- Detect openEuler as RedHat family OS
- Ensure the correct crypt module is loaded
- Implement multiple inventory for ansible.targets
- Make x509 module compatible with M2Crypto 0.44.0
- Remove deprecated code from x509.certificate_managed test mode
- Move logrotate config to /usr/etc/logrotate.d where possible
- Added:
  * detect-openeuler-as-redhat-family-os.patch
  * ensure-the-correct-crypt-module-is-loaded.patch
  * implement-multiple-inventory-for-ansible.targets.patch
  * make-x509-module-compatible-with-m2crypto-0.44.0.patch
  * remove-deprecated-code-from-x509.certificate_managed.patch
* Mon Mar 10 2025 Marek Czernek <marek.czernek@suse.com>
- Add DEB822 apt repository format support
- Make Salt-SSH work with all SSH passwords (bsc#1215484)
- Added:
  * add-deb822-apt-source-format-support-692.patch
  * remove-password-from-shell-after-functional-text-mat.patch
* Mon Feb 24 2025 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Fix issue of using update-alternatives with alts
* Fri Feb 21 2025 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Fix virt_query outputter and add support for block devices
- Make _auth calls visible with master stats
- Repair mount.fstab_present always returning pending changes
- Set virtual grain in Podman systemd container
- Fix crash due wrong client reference on `SaltMakoTemplateLookup`
- Enhace batch async and fix some detected issues
- Added:
  * repair-virt_query-outputter-655.patch
  * make-_auth-calls-visible-with-master-stats-696.patch
  * repair-fstab_present-test-mode-702.patch
  * set-virtual-grain-in-podman-systemd-container-703.patch
  * fixed-file-client-private-attribute-reference-on-sal.patch
  * backport-batch-async-fixes-and-improvements-701.patch
* Wed Feb 19 2025 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Enhacement of Salt packaging
  * Use update-alternatives for all salt scripts
  * Use flexible dependencies for the subpackages
  * Make salt-minion to require flavored zypp-plugin
  * Make zyppnotify to use update-alternatives
  * Drop unused yumnotify plugin
  * Add dependency to python3-dnf-plugins-core for RHEL based
- Fix tests failures after "repo.saltproject.io" deprecation
- Added:
  * fix-tests-failures-after-repo.saltproject.io-depreca.patch
* Wed Jan 29 2025 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Fix error to stat '/root/.gitconfig' on gitfs
  (bsc#1230944) (bsc#1234881) (bsc#1220905)
- Added:
  * fix-failed-to-stat-root-.gitconfig-issue-on-gitfs-bs.patch
* Mon Jan 27 2025 Alexander Graul <alexander.graul@suse.com>
- Adapt to removal of hex attribute in pygit2 v1.15.0 (bsc#1230642)
- Added:
  * update-for-deprecation-of-hex-in-pygit2-1.15.0-and-a.patch
* Thu Jan 23 2025 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Enhance smart JSON parsing when garbage is present (bsc#1231605)
- Added:
  * enhance-find_json-garbage-filtering-bsc-1231605-688.patch
* Wed Jan 22 2025 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Fix virtual grains for VMs running on Nutanix AHV (bsc#1234022)
- Fix issues running on Python 3.12 and 3.13
- Added:
  * fix-virtual-grains-for-vms-running-on-nutanix-ahv-bs.patch
  * fix-issues-that-break-salt-in-python-3.12-and-3.13-6.patch
* Thu Jan  9 2025 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Revert setting SELinux context for minion service (bsc#1233667)
- Remove System V init support
  * Make systemd the only supported init system by removing System V init
    and insserv references
  * Ensure package builds with no init system dependencies if built
    without systemd (for example for use in containers)
  * Apply some spec-cleaner suggestions (update copyright year, sort
    requirements, adjust spacing)
- Added:
  * revert-setting-selinux-context-for-minion-service-bs.patch
* Tue Nov 26 2024 Victor Zhestkov <vzhestkov@suse.com>
- Fix the condition of alternatives for Tumbleweed and Leap 16
- Use update-alternatives for salt-call and fix builing on EL8
- Build all python bindings for all flavors
- Make minion reconnecting on changing master IP (bsc#1228182)
- Added:
  * make-minion-reconnecting-on-changing-master-ip-bsc-1.patch
* Thu Oct 17 2024 Marek Czernek <marek.czernek@suse.com>
- Handle logger exception when flushing already closed file
- Include passlib as a recommended dependency
- Added:
  * handle-logger-flushing-already-closed-file-686.patch
* Thu Oct 10 2024 Pablo Suárez Hernández <psuarezhernandez@suse.com>
- Make Salt Bundle more tolerant to long running jobs (bsc#1228690)
- Added:
  * enhance-cleanup-mechanism-after-salt-bundle-upgrade-.patch
* Thu Oct  3 2024 Marek Czernek <marek.czernek@suse.com>
- Fix additional x509 tests and test_suse tests for SLE12
- Added:
  * fix-x509-private-key-tests-and-test_suse-on-sle12-68.patch
* Wed Oct  2 2024 Marek Czernek <marek.czernek@suse.com>
- Fix failing x509 tests with OpenSSL < 1.1
- Added:
  * fix-x509-test-fails-on-old-openssl-systems-682.patch
* Wed Sep 25 2024 Victor Zhestkov <vzhestkov@suse.com>
- Avoid explicit reading of /etc/salt/minion (bsc#1220357)
- Allow NamedLoaderContexts to be returned from loader
- Revert the change making reactor less blocking (bsc#1230322)
- Use --cachedir for extension_modules in salt-call (bsc#1226141)
- Prevent using SyncWrapper with no reason
- Added:
  * avoid-explicit-reading-of-etc-salt-minion-bsc-122035.patch
  * allow-namedloadercontexts-to-be-returned-from-loader.patch
  * revert-the-change-making-reactor-less-blocking-bsc-1.patch
  * use-cachedir-for-extension_modules-in-salt-call-bsc-.patch
  * prevent-using-syncwrapper-with-no-reason.patch
* Tue Sep 10 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix the SELinux context for Salt Minion service (bsc#1219041)
- Added:
  * fix-the-selinux-context-for-salt-minion-service-bsc-.patch
* Wed Sep  4 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Set contextvars as a build requirement for package
* Wed Sep  4 2024 Marek Czernek <marek.czernek@suse.com>
- Increase warn_until_date date for code we still support
- The test_debian test now uses port 80 for ubuntu keyserver
- Fix too frequent systemd service restart in test_system test
- Added:
  * fix-test_debian-to-work-in-our-infrastructure-676.patch
  * fix-test_system-flaky-setup_teardown-fn.patch
  * fix-deprecated-code-677.patch
* Fri Aug 30 2024 Victor Zhestkov <vzhestkov@suse.com>
- Avoid crash on wrong output of systemctl version (bsc#1229539)
- Improve error handling with different OpenSSL versions
- Remove redundant run_func from salt.master.MWorker._handle_aes
- Added:
  * avoid-crash-on-wrong-output-of-systemctl-version-bsc.patch
  * improve-error-handling-with-different-openssl-versio.patch
  * remove-redundant-run_func-from-salt.master.mworker._.patch
* Thu Aug 29 2024 Yeray Gutiérrez Cedrés <yeray.gutierrez@suse.com>
- Fix cloud minion configuration for multiple masters (bsc#1229109)
- Added:
  * join-masters-if-it-is-a-list-671.patch
* Wed Aug 21 2024 Marek Czernek <marek.czernek@suse.com>
- Use Pygit2 id instead of deprecated oid in gitfs
- Added:
  * replace-use-of-pygit2-deprecated-and-removed-1.15.0-.patch
* Wed Aug  7 2024 Marek Czernek <marek.czernek@suse.com>
- Fix few failing tests to work with both Salt and Salt bundle
- Skip testing unsupported OpenSSL crypto algorithms
- Added:
  * make-tests-compatible-with-venv-bundle.patch
  * skip-more-tests-related-to-old-openssl-algorithms.patch
* Wed Jul 24 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix rich rule comparison in firewalld module (bsc#1222684)
- Added:
  * firewalld-normalize-new-rich-rules-before-comparing-.patch
* Tue Jul  9 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- test_vultrpy: adjust test expectation to prevent failure after Debian 10 EOL
- Added:
  * test_vultrpy-adjust-test-expectation-to-prevent-fail.patch
* Mon Jul  8 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Make auth.pam more robust with Salt Bundle and fix tests
- Added:
  * some-more-small-tests-fixes-enhancements-661.patch
* Wed Jul  3 2024 Flex Liu <fliu@suse.com>
- Fix performance of user.list_groups with many remote groups
  (bsc#1226964)
- Added:
  * fix-user.list_groups-omits-remote-groups.patch
* Tue Jun 18 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix "status.diskusage" function and exclude some tests for Salt Bundle
- Added:
  * fix-status.diskusage-and-exclude-some-tests-to-run-w.patch
* Wed Jun 12 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Skip certain tests if necessary for some OSes and set flaky ones
- Added:
  * skip-certain-tests-if-necessary-and-mark-some-flaky-.patch
* Thu Jun  6 2024 Marek Czernek <marek.czernek@suse.com>
- Add a timer to delete old env post update for venv-minion
- Added:
  * provide-systemd-timer-unit.patch
* Mon May 27 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Several fixes for tests to avoid errors and failures in some OSes
- Speed up salt.matcher.confirm_top by using __context__
- Do not call the async wrapper calls with the separate thread
- Prevent OOM with high amount of batch async calls (bsc#1216063)
- Add missing contextvars dependency in salt.version
- Skip tests for unsupported algorithm on old OpenSSL version
- Remove redundant `_file_find` call to the master
- Prevent possible exception in tornado.concurrent.Future._set_done
- Make reactor engine less blocking the EventPublisher
- Make salt-master self recoverable on killing EventPublisher
- Improve broken events catching and reporting
- Make logging calls lighter
- Remove unused import causing delays on starting salt-master
- Added:
  * improve-broken-events-catching-and-reporting.patch
  * add-missing-contextvars-dependency-in-salt.version.patch
  * prevent-oom-with-high-amount-of-batch-async-calls-bs.patch
  * speed-up-salt.matcher.confirm_top-by-using-__context.patch
  * remove-redundant-_file_find-call-to-the-master.patch
  * make-logging-calls-lighter.patch
  * make-salt-master-self-recoverable-on-killing-eventpu.patch
  * skip-tests-for-unsupported-algorithm-on-old-openssl-.patch
  * remove-unused-import-causing-delays-on-starting-salt.patch
  * do-not-call-the-async-wrapper-calls-with-the-separat.patch
  * prevent-possible-exception-in-tornado.concurrent.fut.patch
  * several-fixes-for-tests-to-avoid-errors-and-failures.patch
  * make-reactor-engine-less-blocking-the-eventpublisher.patch
* Mon May 13 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Mark python3-CherryPy as recommended package for the testsuite
* Tue May  7 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Make "man" a recommended package instead of required
* Tue Mar 26 2024 Marek Czernek <marek.czernek@suse.com>
- Convert oscap output to UTF-8
- Added:
  * switch-oscap-encoding-to-utf-8-639.patch
* Thu Mar 21 2024 Marek Czernek <marek.czernek@suse.com>
- Make Salt compatible with Python 3.11
- Added:
  * fix-salt-warnings-and-testuite-for-python-3.11-635.patch
* Fri Mar 15 2024 Yeray Gutiérrez Cedrés <yeray.gutierrez@suse.com>
- Ignore non-ascii chars in oscap output (bsc#1219001)
- Added:
  * decode-oscap-byte-stream-to-string-bsc-1219001.patch
* Thu Mar 14 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix detected issues in Salt tests when running on VMs
- Added:
  * fix-tests-failures-and-errors-when-detected-on-vm-ex.patch
* Wed Mar  6 2024 Marek Czernek <marek.czernek@suse.com>
- Make importing seco.range thread safe (bsc#1211649)
- Added:
  * make-importing-seco.range-thread-safe-bsc-1211649.patch
* Mon Feb 26 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix problematic tests and allow smooth tests executions on containers
- Added:
  * fix-problematic-tests-and-allow-smooth-tests-executi.patch
* Wed Feb 21 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Discover Ansible playbook files as "*.yml" or "*.yaml" files (bsc#1211888)
- Added:
  * discover-both-.yml-and-.yaml-playbooks-bsc-1211888.patch
* Tue Feb 20 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Extend dependencies for python3-salt-testsuite and python3-salt packages
- Improve Salt and testsuite packages multibuild
* Thu Feb  8 2024 Yeray Gutiérrez Cedrés <yeray.gutierrez@suse.com>
- Enable multibuilld and create test flavor
- Additionally we require python-mock just for older Python versions.
* Mon Feb  5 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Remove python-boto dependency for the python3-salt-testsuite package for Tumbleweed
- Rename salt-tests to python3-salt-testsuite
* Thu Feb  1 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent directory traversal when creating syndic cache directory
  on the master (CVE-2024-22231, bsc#1219430)
- Prevent directory traversal attacks in the master's serve_file
  method (CVE-2024-22232, bsc#1219431)
- Added:
  * fix-cve-2024-22231-and-cve-2024-22232-bsc-1219430-bs.patch
* Mon Jan 29 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Provide user(salt)/group(salt) capabilities for RPM 4.19
* Tue Jan 23 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent exceptions with fileserver.update when called via state (bsc#1218482)
- Added:
  * allow-kwargs-for-fileserver-roots-update-bsc-1218482.patch
* Thu Jan 18 2024 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Improve pip target override condition with VENV_PIP_TARGET
  environment variable (bsc#1216850)
- Fixed KeyError in logs when running a state that fails
- Added:
  * improve-pip-target-override-condition-with-venv_pip_.patch
  * fixed-keyerror-in-logs-when-running-a-state-that-fai.patch
* Thu Jan 18 2024 Marek Czernek <marek.czernek@suse.com>
- Ensure that pillar refresh loads beacons from pillar without restart
- Fix the aptpkg.py unit test failure
- Prefer unittest.mock to python-mock in test suite
- Added:
  * update-__pillar__-during-pillar_refresh.patch
  * fix-the-aptpkg.py-unit-test-failure.patch
  * prefer-unittest.mock-for-python-versions-that-are-su.patch
* Fri Dec  1 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Enable "KeepAlive" probes for Salt SSH executions (bsc#1211649)
- Added:
  * enable-keepalive-probes-for-salt-ssh-executions-bsc-.patch
* Thu Nov 16 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Revert changes to set Salt configured user early in the stack (bsc#1216284)
- Added:
  * revert-make-sure-configured-user-is-properly-set-by-.patch
* Mon Nov 13 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Align behavior of some modules when using salt-call via symlink (bsc#1215963)
- Fix gitfs "__env__" and improve cache cleaning (bsc#1193948)
- Added:
  * fix-gitfs-__env__-and-improve-cache-cleaning-bsc-119.patch
  * dereference-symlinks-to-set-proper-__cli-opt-bsc-121.patch
* Tue Oct 31 2023 Alexander Graul <alexander.graul@suse.com>
- Randomize pre_flight_script path (CVE-2023-34049 bsc#1215157)
- Added:
  * fix-cve-2023-34049-bsc-1215157.patch
* Tue Oct 17 2023 Marek Czernek <marek.czernek@suse.com>
- Allow all primitive grain types for autosign_grains (bsc#1214477)
- Added:
  * allow-all-primitive-grain-types-for-autosign_grains-.patch
* Mon Oct  2 2023 Victor Zhestkov <vzhestkov@suse.com>
- Fix optimization_order opt to prevent testsuite fails
- Improve salt.utils.json.find_json to avoid fails
  with transactional salt salt-ssh managed clients (bsc#1213293)
- Use salt-call from salt bundle with transactional_update
- Only call native_str on curl_debug message in tornado when needed
- Implement the calling for batch async from the salt CLI
- Added:
  * implement-the-calling-for-batch-async-from-the-salt-.patch
  * improve-salt.utils.json.find_json-bsc-1213293.patch
  * only-call-native_str-on-curl_debug-message-in-tornad.patch
  * use-salt-call-from-salt-bundle-with-transactional_up.patch
  * fix-optimization_order-opt-to-prevent-test-fails.patch
* Mon Oct  2 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix calculation of SLS context vars when trailing dots
  on targetted sls/state (bsc#1213518)
- Added:
  * fix-calculation-of-sls-context-vars-when-trailing-do.patch
* Wed Sep 20 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix inconsistency in reported version by egg-info metadata (bsc#1215489)
- Added:
  * write-salt-version-before-building-when-using-with-s.patch
* Fri Sep  1 2023 Victor Zhestkov <vzhestkov@suse.com>
- Revert usage of long running REQ channel to prevent possible
  missing responses on requests and dublicated responses
  (bsc#1213960, bsc#1213630, bsc#1213257)
- Added:
  * revert-usage-of-long-running-req-channel-bsc-1213960.patch
* Thu Aug 31 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix gitfs cachedir basename to avoid hash collisions
  (bsc#1193948, bsc#1214797, CVE-2023-20898)
- Added:
  * fixed-gitfs-cachedir_basename-to-avoid-hash-collisio.patch
* Tue Aug 22 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Make sure configured user is properly set by Salt (bsc#1210994)
- Do not fail on bad message pack message (bsc#1213441, CVE-2023-20897, bsc#1214796)
- Fix broken tests to make them running in the testsuite
- Prevent possible exceptions on salt.utils.user.get_group_dict (bsc#1212794)
- Added:
  * do-not-fail-on-bad-message-pack-message-bsc-1213441-.patch
  * fix-tests-to-make-them-running-with-salt-testsuite.patch
  * prevent-possible-exceptions-on-salt.utils.user.get_g.patch
  * make-sure-configured-user-is-properly-set-by-salt-bs.patch
* Wed Aug  9 2023 Alexander Graul <alexander.graul@suse.com>
- Create minion_id with reproducible mtime
- Fix detection of Salt codename by "salt_version" execution module
- Fix regression: multiple values for keyword argument 'saltenv' (bsc#1212844)
- Fix the regression of user.present state when group is unset (bsc#1212855)
- Fix zypper repositories always being reconfigured
- Fix utf8 handling in 'pass' renderer and make it more robust
- Prevent _pygit2.GitError: error loading known_hosts when $HOME is not set (bsc#1210994)
- Fix ModuleNotFoundError and other issues raised by salt-support module (bsc#1211591)
- tornado: Fix an open redirect in StaticFileHandler (CVE-2023-28370, bsc#1211741)
- Make master_tops compatible with Salt 3000 and older minions (bsc#1212516) (bsc#1212517)
- Avoid failures due transactional_update module not available in Salt 3006.0 (bsc#1211754)
- Avoid conflicts with Salt dependencies versions (bsc#1211612)
- Added:
  * fix-utf8-handling-in-pass-renderer-and-make-it-more-.patch
  * fix-the-regression-of-user.present-state-when-group-.patch
  * make-master_tops-compatible-with-salt-3000-and-older.patch
  * avoid-conflicts-with-dependencies-versions-bsc-12116.patch
  * tornado-fix-an-open-redirect-in-staticfilehandler-cv.patch
  * fix-regression-multiple-values-for-keyword-argument-.patch
  * zypper-pkgrepo-alreadyconfigured-585.patch
  * mark-salt-3006-as-released-586.patch
  * fix-some-issues-detected-in-salt-support-cli-module-.patch
  * define-__virtualname__-for-transactional_update-modu.patch
  * 3006.0-prevent-_pygit2.giterror-error-loading-known_.patch
* Fri May  5 2023 Alexander Graul <alexander.graul@suse.com>
- Update to Salt release version 3006.0 (jsc#PED-3139)
  * See release notes: https://docs.saltproject.io/en/latest/topics/releases/3006.0.html
- Add python3-looseversion as new dependency for salt
- Add python3-packaging as new dependency for salt
- Drop conflictive patch dicarded from upstream
- Fix SLS rendering error when Jinja macros are used
- Fix version detection and avoid building and testing failures
- Added:
  * fix-version-detection-and-avoid-building-and-testing.patch
  * make-sure-the-file-client-is-destroyed-upon-used.patch
- Modified:
  * 3005.1-implement-zypper-removeptf-573.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * add-custom-suse-capabilities-as-grains.patch
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * add-migrated-state-and-gpg-key-management-functions-.patch
  * add-publish_batch-to-clearfuncs-exposed-methods.patch
  * add-salt-ssh-support-with-venv-salt-minion-3004-493.patch
  * add-sleep-on-exception-handling-on-minion-connection.patch
  * add-standalone-configuration-file-for-enabling-packa.patch
  * add-support-for-gpgautoimport-539.patch
  * allow-vendor-change-option-with-zypper.patch
  * async-batch-implementation.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * bsc-1176024-fix-file-directory-user-and-group-owners.patch
  * change-the-delimeters-to-prevent-possible-tracebacks.patch
  * control-the-collection-of-lvm-grains-via-config.patch
  * debian-info_installed-compatibility-50453.patch
  * dnfnotify-pkgset-plugin-implementation-3002.2-450.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
  * don-t-use-shell-sbin-nologin-in-requisites.patch
  * drop-serial-from-event.unpack-in-cli.batch_async.patch
  * early-feature-support-config.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
  * enhance-openscap-module-add-xccdf_eval-call-386.patch
  * fix-bsc-1065792.patch
  * fix-for-suse-expanded-support-detection.patch
  * fix-issue-2068-test.patch
  * fix-missing-minion-returns-in-batch-mode-360.patch
  * fix-ownership-of-salt-thin-directory-when-using-the-.patch
  * fix-regression-with-depending-client.ssh-on-psutil-b.patch
  * fix-salt-ssh-opts-poisoning-bsc-1197637-3004-501.patch
  * fix-salt.utils.stringutils.to_str-calls-to-make-it-w.patch
  * fix-the-regression-for-yumnotify-plugin-456.patch
  * fix-traceback.print_exc-calls-for-test_pip_state-432.patch
  * fixes-for-python-3.10-502.patch
  * include-aliases-in-the-fqdns-grains.patch
  * info_installed-works-without-status-attr-now.patch
  * let-salt-ssh-use-platform-python-binary-in-rhel8-191.patch
  * make-aptpkg.list_repos-compatible-on-enabled-disable.patch
  * make-setup.py-script-to-not-require-setuptools-9.1.patch
  * pass-the-context-to-pillar-ext-modules.patch
  * prevent-affection-of-ssh.opts-with-lazyloader-bsc-11.patch
  * prevent-pkg-plugins-errors-on-missing-cookie-path-bs.patch
  * prevent-shell-injection-via-pre_flight_script_args-4.patch
  * read-repo-info-without-using-interpolation-bsc-11356.patch
  * restore-default-behaviour-of-pkg-list-return.patch
  * return-the-expected-powerpc-os-arch-bsc-1117995.patch
  * revert-fixing-a-use-case-when-multiple-inotify-beaco.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * save-log-to-logfile-with-docker.build.patch
  * skip-package-names-without-colon-bsc-1208691-578.patch
  * switch-firewalld-state-to-use-change_interface.patch
  * temporary-fix-extend-the-whitelist-of-allowed-comman.patch
  * update-target-fix-for-salt-ssh-to-process-targets-li.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * use-rlock-to-avoid-deadlocks-in-salt-ssh.patch
  * use-salt-bundle-in-dockermod.patch
  * x509-fixes-111.patch
  * zypperpkg-ignore-retcode-104-for-search-bsc-1176697-.patch
- Removed:
  * add-amazon-ec2-detection-for-virtual-grains-bsc-1195.patch
  * add-support-for-name-pkgs-and-diff_attr-parameters-t.patch
  * align-amazon-ec2-nitro-grains-with-upstream-pr-bsc-1.patch
  * allow-entrypoint-compatibility-for-importlib-metadat.patch
  * clarify-pkg.installed-pkg_verify-documentation.patch
  * detect-module.run-syntax.patch
  * fix-salt.states.file.managed-for-follow_symlinks-tru.patch
  * fix-state.apply-in-test-mode-with-file-state-module-.patch
  * fix-test_ipc-unit-tests.patch
  * fixes-pkg.version_cmp-on-openeuler-systems-and-a-few.patch
  * fopen-workaround-bad-buffering-for-binary-mode-563.patch
  * ignore-erros-on-reading-license-files-with-dpkg_lowp.patch
  * ignore-extend-declarations-from-excluded-sls-files.patch
  * ignore-non-utf8-characters-while-reading-files-with-.patch
  * include-stdout-in-error-message-for-zypperpkg-559.patch
  * make-pass-renderer-configurable-other-fixes-532.patch
  * make-sure-saltcacheloader-use-correct-fileclient-519.patch
  * normalize-package-names-once-with-pkg.installed-remo.patch
  * retry-if-rpm-lock-is-temporarily-unavailable-547.patch
  * set-default-target-for-pip-from-venv_pip_target-envi.patch
  * state.apply-don-t-check-for-cached-pillar-errors.patch
  * state.orchestrate_single-does-not-pass-pillar-none-4.patch
* Fri Mar 17 2023 Alexander Graul <alexander.graul@suse.com>
- Require python3-jmespath runtime dependency (bsc#1209233)
- Fix problem with detecting PTF packages (bsc#1208691)
- Added:
  * skip-package-names-without-colon-bsc-1208691-578.patch
* Tue Jan 31 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fixes pkg.version_cmp on openEuler systems and a few other OS flavors
- Added:
  * fixes-pkg.version_cmp-on-openeuler-systems-and-a-few.patch
* Mon Jan 23 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Make pkg.remove function from zypperpkg module to handle also PTF packages
- Added:
  * 3005.1-implement-zypper-removeptf-573.patch
* Tue Jan 17 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Control the collection of lvm grains via config (bsc#1204939)
- Added:
  * control-the-collection-of-lvm-grains-via-config.patch
* Thu Jan 12 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Allow entrypoint compatibility for "importlib-metadata>=5.0.0" (bsc#1207071)
- Added:
  * allow-entrypoint-compatibility-for-importlib-metadat.patch
* Mon Jan  9 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add missing patch after rebase to fix collections Mapping issues
- Added:
  * fixes-for-python-3.10-502.patch
* Wed Jan  4 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent deadlocks in salt-ssh executions
- Added:
  * use-rlock-to-avoid-deadlocks-in-salt-ssh.patch
* Mon Jan  2 2023 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Create new salt-tests subpackage containing Salt tests
* Thu Dec 29 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update to Salt release version 3005.1
  * See release notes: https://docs.saltstack.com/en/latest/topics/releases/3005.1.html
- Modified:
  * activate-all-beacons-sources-config-pillar-grains.patch
  * add-amazon-ec2-detection-for-virtual-grains-bsc-1195.patch
  * add-custom-suse-capabilities-as-grains.patch
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * add-migrated-state-and-gpg-key-management-functions-.patch
  * add-publish_batch-to-clearfuncs-exposed-methods.patch
  * add-salt-ssh-support-with-venv-salt-minion-3004-493.patch
  * add-sleep-on-exception-handling-on-minion-connection.patch
  * add-standalone-configuration-file-for-enabling-packa.patch
  * add-support-for-gpgautoimport-539.patch
  * add-support-for-name-pkgs-and-diff_attr-parameters-t.patch
  * align-amazon-ec2-nitro-grains-with-upstream-pr-bsc-1.patch
  * allow-vendor-change-option-with-zypper.patch
  * async-batch-implementation.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * bsc-1176024-fix-file-directory-user-and-group-owners.patch
  * change-the-delimeters-to-prevent-possible-tracebacks.patch
  * clarify-pkg.installed-pkg_verify-documentation.patch
  * debian-info_installed-compatibility-50453.patch
  * detect-module.run-syntax.patch
  * dnfnotify-pkgset-plugin-implementation-3002.2-450.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
  * don-t-use-shell-sbin-nologin-in-requisites.patch
  * drop-serial-from-event.unpack-in-cli.batch_async.patch
  * early-feature-support-config.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
  * enhance-openscap-module-add-xccdf_eval-call-386.patch
  * fix-bsc-1065792.patch
  * fix-for-suse-expanded-support-detection.patch
  * fix-issue-2068-test.patch
  * fix-missing-minion-returns-in-batch-mode-360.patch
  * fix-ownership-of-salt-thin-directory-when-using-the-.patch
  * fix-regression-with-depending-client.ssh-on-psutil-b.patch
  * fix-salt-ssh-opts-poisoning-bsc-1197637-3004-501.patch
  * fix-salt.states.file.managed-for-follow_symlinks-tru.patch
  * fix-salt.utils.stringutils.to_str-calls-to-make-it-w.patch
  * fix-state.apply-in-test-mode-with-file-state-module-.patch
  * fix-test_ipc-unit-tests.patch
  * fix-the-regression-for-yumnotify-plugin-456.patch
  * fix-traceback.print_exc-calls-for-test_pip_state-432.patch
  * fopen-workaround-bad-buffering-for-binary-mode-563.patch
  * ignore-erros-on-reading-license-files-with-dpkg_lowp.patch
  * ignore-extend-declarations-from-excluded-sls-files.patch
  * ignore-non-utf8-characters-while-reading-files-with-.patch
  * include-aliases-in-the-fqdns-grains.patch
  * include-stdout-in-error-message-for-zypperpkg-559.patch
  * info_installed-works-without-status-attr-now.patch
  * let-salt-ssh-use-platform-python-binary-in-rhel8-191.patch
  * make-aptpkg.list_repos-compatible-on-enabled-disable.patch
  * make-pass-renderer-configurable-other-fixes-532.patch
  * make-setup.py-script-to-not-require-setuptools-9.1.patch
  * make-sure-saltcacheloader-use-correct-fileclient-519.patch
  * normalize-package-names-once-with-pkg.installed-remo.patch
  * pass-the-context-to-pillar-ext-modules.patch
  * prevent-affection-of-ssh.opts-with-lazyloader-bsc-11.patch
  * prevent-pkg-plugins-errors-on-missing-cookie-path-bs.patch
  * prevent-shell-injection-via-pre_flight_script_args-4.patch
  * read-repo-info-without-using-interpolation-bsc-11356.patch
  * restore-default-behaviour-of-pkg-list-return.patch
  * retry-if-rpm-lock-is-temporarily-unavailable-547.patch
  * return-the-expected-powerpc-os-arch-bsc-1117995.patch
  * revert-fixing-a-use-case-when-multiple-inotify-beaco.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * save-log-to-logfile-with-docker.build.patch
  * set-default-target-for-pip-from-venv_pip_target-envi.patch
  * state.apply-don-t-check-for-cached-pillar-errors.patch
  * state.orchestrate_single-does-not-pass-pillar-none-4.patch
  * switch-firewalld-state-to-use-change_interface.patch
  * temporary-fix-extend-the-whitelist-of-allowed-comman.patch
  * update-target-fix-for-salt-ssh-to-process-targets-li.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * use-salt-bundle-in-dockermod.patch
  * x509-fixes-111.patch
  * zypperpkg-ignore-retcode-104-for-search-bsc-1176697-.patch
- Removed:
  * 3003.3-do-not-consider-skipped-targets-as-failed-for.patch
  * 3003.3-postgresql-json-support-in-pillar-423.patch
  * add-missing-ansible-module-functions-to-whitelist-in.patch
  * add-rpm_vercmp-python-library-for-version-comparison.patch
  * adds-explicit-type-cast-for-port.patch
  * backport-syndic-auth-fixes.patch
  * batch.py-avoid-exception-when-minion-does-not-respon.patch
  * check-if-dpkgnotify-is-executable-bsc-1186674-376.patch
  * do-not-crash-when-unexpected-cmd-output-at-listing-p.patch
  * enhance-logging-when-inotify-beacon-is-missing-pyino.patch
  * fix-62092-catch-zmq.error.zmqerror-to-set-hwm-for-zm.patch
  * fix-crash-when-calling-manage.not_alive-runners.patch
  * fixes-56144-to-enable-hotadd-profile-support.patch
  * fixes-for-python-3.10-502.patch
  * fix-exception-in-yumpkg.remove-for-not-installed-pac.patch
  * fix-for-cve-2022-22967-bsc-1200566.patch
  * fix-inspector-module-export-function-bsc-1097531-481.patch
  * fix-ip6_interface-grain-to-not-leak-secondary-ipv4-a.patch
  * fix-issues-with-salt-ssh-s-extra-filerefs.patch
  * fix-jinja2-contextfuntion-base-on-version-bsc-119874.patch
  * fix-multiple-security-issues-bsc-1197417.patch
  * fix-salt-call-event.send-call-with-grains-and-pillar.patch
  * fix-the-regression-in-schedule-module-releasded-in-3.patch
  * fix-wrong-test_mod_del_repo_multiline_values-test-af.patch
  * force-zyppnotify-to-prefer-packages.db-than-packages.patch
  * implementation-of-held-unheld-functions-for-state-pk.patch
  * implementation-of-suse_ip-execution-module-bsc-10999.patch
  * improvements-on-ansiblegate-module-354.patch
  * mock-ip_addrs-in-utils-minions.py-unit-test-443.patch
  * notify-beacon-for-debian-ubuntu-systems-347.patch
  * refactor-and-improvements-for-transactional-updates-.patch
  * support-transactional-systems-microos.patch
  * wipe-notify_socket-from-env-in-cmdmod-bsc-1193357-30.patch
* Fri Oct 28 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Pass the context to pillar ext modules
- Align Amazon EC2 (Nitro) grains with upstream (bsc#1203685)
- Detect module run syntax version
- Implement automated patches alignment for the Salt Bundle
- Added:
  * detect-module.run-syntax.patch
  * pass-the-context-to-pillar-ext-modules.patch
  * align-amazon-ec2-nitro-grains-with-upstream-pr-bsc-1.patch
* Fri Oct 21 2022 Alexander Graul <alexander.graul@suse.com>
- Ignore extend declarations from excluded SLS files (bsc#1203886)
- Clarify pkg.installed pkg_verify documentation
- Enhance capture of error messages for Zypper calls in zypperpkg module
- Added:
  * ignore-extend-declarations-from-excluded-sls-files.patch
  * include-stdout-in-error-message-for-zypperpkg-559.patch
  * clarify-pkg.installed-pkg_verify-documentation.patch
* Thu Oct  6 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Make pass renderer configurable and fix detected issues
- Workaround fopen line buffering for binary mode (bsc#1203834)
- Handle non-UTF-8 bytes in core grains generation (bsc#1202165)
- Fix Syndic authentication errors (bsc#1199562)
- Added:
  * make-pass-renderer-configurable-other-fixes-532.patch
  * ignore-non-utf8-characters-while-reading-files-with-.patch
  * fopen-workaround-bad-buffering-for-binary-mode-563.patch
  * backport-syndic-auth-fixes.patch
* Thu Sep  1 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Add Amazon EC2 detection for virtual grains (bsc#1195624)
- Fix the regression in schedule module releasded in 3004 (bsc#1202631)
- Fix state.apply in test mode with file state module
  on user/group checking (bsc#1202167)
- Change the delimeters to prevent possible tracebacks
  on some packages with dpkg_lowpkg
- Make zypperpkg to retry if RPM lock is temporarily unavailable (bsc#1200596)
- Added:
  * fix-the-regression-in-schedule-module-releasded-in-3.patch
  * retry-if-rpm-lock-is-temporarily-unavailable-547.patch
  * change-the-delimeters-to-prevent-possible-tracebacks.patch
  * add-amazon-ec2-detection-for-virtual-grains-bsc-1195.patch
  * fix-state.apply-in-test-mode-with-file-state-module-.patch
* Tue Jul 12 2022 Alexander Graul <alexander.graul@suse.com>
- Fix test_ipc unit test
- Added:
  * fix-test_ipc-unit-tests.patch
* Fri Jul  8 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add support for gpgautoimport in zypperpkg module
- Update Salt to work with Jinja >= and <= 3.1.0 (bsc#1198744)
- Fix salt.states.file.managed() for follow_symlinks=True and test=True (bsc#1199372)
- Make Salt 3004 compatible with pyzmq >= 23.0.0 (bsc#1201082)
- Added:
  * fix-jinja2-contextfuntion-base-on-version-bsc-119874.patch
  * add-support-for-gpgautoimport-539.patch
  * fix-62092-catch-zmq.error.zmqerror-to-set-hwm-for-zm.patch
  * fix-salt.states.file.managed-for-follow_symlinks-tru.patch
* Thu Jul  7 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add support for name, pkgs and diff_attr parameters to upgrade
  function for zypper and yum (bsc#1198489)
- Added:
  * add-support-for-name-pkgs-and-diff_attr-parameters-t.patch
* Tue Jun 28 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Fix ownership of salt thin directory when using the Salt Bundle
- Set default target for pip from VENV_PIP_TARGET environment variable
- Normalize package names once with pkg.installed/removed using yum (bsc#1195895)
- Save log to logfile with docker.build
- Use Salt Bundle in dockermod
- Ignore erros on reading license files with dpkg_lowpkg (bsc#1197288)
- Added:
  * normalize-package-names-once-with-pkg.installed-remo.patch
  * use-salt-bundle-in-dockermod.patch
  * fix-ownership-of-salt-thin-directory-when-using-the-.patch
  * ignore-erros-on-reading-license-files-with-dpkg_lowp.patch
  * set-default-target-for-pip-from-venv_pip_target-envi.patch
  * save-log-to-logfile-with-docker.build.patch
* Thu Jun 16 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix PAM auth issue due missing check for PAM_ACCT_MGM return value (CVE-2022-22967) (bsc#1200566)
- Added:
  * fix-for-cve-2022-22967-bsc-1200566.patch
* Thu May 19 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Make sure SaltCacheLoader use correct fileclient (bsc#1199149)
- Added:
  * make-sure-saltcacheloader-use-correct-fileclient-519.patch
* Tue Apr 12 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Prevent data pollution between actions proceesed
  at the same time (bsc#1197637)
- Fix regression preventing bootstrapping new clients
  caused by redundant dependency on psutil (bsc#1197533)
- Added:
  * fix-regression-with-depending-client.ssh-on-psutil-b.patch
  * prevent-affection-of-ssh.opts-with-lazyloader-bsc-11.patch
* Tue Apr  5 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Fixes for Python 3.10
- Added:
  * fixes-for-python-3.10-502.patch
* Thu Mar 31 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Fix salt-ssh opts poisoning (bsc#1197637)
- Added:
  * fix-salt-ssh-opts-poisoning-bsc-1197637-3004-501.patch
* Thu Mar 31 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix multiple security issues (bsc#1197417)
  * Sign authentication replies to prevent MiTM (CVE-2022-22935)
  * Sign pillar data to prevent MiTM attacks. (CVE-2022-22934)
  * Prevent job and fileserver replays (CVE-2022-22936)
  * Fixed targeting bug, especially visible when using syndic and user auth. (CVE-2022-22941)
- Added:
  * fix-multiple-security-issues-bsc-1197417.patch
* Mon Feb 28 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix issues found around pre_flight_script_args
- Added:
  * prevent-shell-injection-via-pre_flight_script_args-4.patch
* Thu Feb 24 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Add salt-ssh with Salt Bundle support (venv-salt-minion)
  (bsc#1182851, bsc#1196432)
- Added:
  * add-salt-ssh-support-with-venv-salt-minion-3004-493.patch
* Thu Feb 17 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Restrict "state.orchestrate_single" to pass a pillar value if it exists (bsc#1194632)
- Added:
  * state.orchestrate_single-does-not-pass-pillar-none-4.patch
* Tue Feb  8 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update generated documentation to 3004
* Tue Feb  8 2022 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Expose missing "ansible" module functions in Salt 3004 (bsc#1195625)
- Added:
  * add-missing-ansible-module-functions-to-whitelist-in.patch
* Mon Feb  7 2022 Alexander Graul <alexander.graul@suse.com>
- Fix salt-call event.send with pillar or grains
- Added:
  * fix-salt-call-event.send-call-with-grains-and-pillar.patch
* Mon Jan 31 2022 Alexander Graul <alexander.graul@suse.com>
- Fix exception in batch_async caused by a bad function call
- Added:
  * drop-serial-from-event.unpack-in-cli.batch_async.patch
* Fri Jan 28 2022 Victor Zhestkov <victor.zhestkov@suse.com>
- Fix inspector module export function (bsc#1097531)
- Wipe NOTIFY_SOCKET from env in cmdmod (bsc#1193357)
- Added:
  * fix-inspector-module-export-function-bsc-1097531-481.patch
  * wipe-notify_socket-from-env-in-cmdmod-bsc-1193357-30.patch
* Wed Jan 26 2022 Alexander Graul <alexander.graul@suse.com>
- Update to version 3004, see release notes: https://docs.saltproject.io/en/master/topics/releases/3004.html
- Don't check for cached pillar errors on state.apply (bsc#1190781)
- Added:
  * state.apply-don-t-check-for-cached-pillar-errors.patch
- Modified:
  * add-migrated-state-and-gpg-key-management-functions-.patch
  * switch-firewalld-state-to-use-change_interface.patch
  * include-aliases-in-the-fqdns-grains.patch
  * debian-info_installed-compatibility-50453.patch
  * info_installed-works-without-status-attr-now.patch
  * fix-traceback.print_exc-calls-for-test_pip_state-432.patch
  * add-custom-suse-capabilities-as-grains.patch
  * add-rpm_vercmp-python-library-for-version-comparison.patch
  * 3003.3-do-not-consider-skipped-targets-as-failed-for.patch
  * support-transactional-systems-microos.patch
  * do-not-crash-when-unexpected-cmd-output-at-listing-p.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
  * update-target-fix-for-salt-ssh-to-process-targets-li.patch
  * fix-exception-in-yumpkg.remove-for-not-installed-pac.patch
  * enhance-openscap-module-add-xccdf_eval-call-386.patch
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * zypperpkg-ignore-retcode-104-for-search-bsc-1176697-.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * 3003.3-postgresql-json-support-in-pillar-423.patch
  * prevent-pkg-plugins-errors-on-missing-cookie-path-bs.patch
  * early-feature-support-config.patch
  * implementation-of-held-unheld-functions-for-state-pk.patch
  * x509-fixes-111.patch
  * fix-issues-with-salt-ssh-s-extra-filerefs.patch
  * mock-ip_addrs-in-utils-minions.py-unit-test-443.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * refactor-and-improvements-for-transactional-updates-.patch
  * improvements-on-ansiblegate-module-354.patch
  * revert-fixing-a-use-case-when-multiple-inotify-beaco.patch
- Removed:
  * add-alibaba-cloud-linux-2-by-backporting-upstream-s-.patch
  * prevent-logging-deadlock-on-salt-api-subprocesses-bs.patch
  * do-not-break-master_tops-for-minion-with-version-low.patch
  * don-t-call-zypper-with-more-than-one-no-refresh.patch
  * do-not-monkey-patch-yaml-bsc-1177474.patch
  * add-missing-aarch64-to-rpm-package-architectures-405.patch
  * figure-out-python-interpreter-to-use-inside-containe.patch
  * parsing-epoch-out-of-version-provided-during-pkg-rem.patch
  * fix-a-test-and-some-variable-names-229.patch
  * add-astra-linux-common-edition-to-the-os-family-list.patch
  * better-handling-of-bad-public-keys-from-minions-bsc-.patch
  * templates-move-the-globals-up-to-the-environment-jin.patch
  * virt-enhancements.patch
  * fix-aptpkg.normalize_name-when-package-arch-is-all.patch
  * adding-preliminary-support-for-rocky.-59682-391.patch
  * fix-save-for-iptables-state-module-bsc-1185131-372.patch
* Mon Nov 15 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Simplify "transactional_update" module to not use SSH wrapper and allow more flexible execution
- Add "--no-return-event" option to salt-call to prevent sending return event back to master.
- Make "state.highstate" to acts on concurrent flag.
- Fix print regression for yumnotify plugin
- Added:
  * refactor-and-improvements-for-transactional-updates-.patch
  * fix-the-regression-for-yumnotify-plugin-456.patch
* Tue Nov  9 2021 Victor Zhestkov <victor.zhestkov@suse.com>
- Use dnfnotify instead yumnotify for relevant distros
- dnfnotify pkgset plugin implementation
- Add rpm_vercmp python library support for version comparison
- Prevent pkg plugins errors on missing cookie path (bsc#1186738)
- Added:
  * add-rpm_vercmp-python-library-for-version-comparison.patch
  * mock-ip_addrs-in-utils-minions.py-unit-test-443.patch
  * dnfnotify-pkgset-plugin-implementation-3002.2-450.patch
  * fix-traceback.print_exc-calls-for-test_pip_state-432.patch
  * prevent-pkg-plugins-errors-on-missing-cookie-path-bs.patch
* Fri Oct 15 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix ip6_interface grain to not leak secondary IPv4 aliases (bsc#1191412)
- Make "salt-api" package to require python3-cherrypy on RHEL systems
- Make "tar" as required for "salt-transactional-update" package
- Added:
  * fix-ip6_interface-grain-to-not-leak-secondary-ipv4-a.patch
* Fri Oct  8 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix issues with salt-ssh's extra-filerefs
- Added:
  * fix-issues-with-salt-ssh-s-extra-filerefs.patch
* Fri Oct  8 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix crash when calling manage.not_alive runners
- Added:
  * fix-crash-when-calling-manage.not_alive-runners.patch
* Wed Oct  6 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not consider skipped targets as failed for ansible.playbooks state (bsc#1190446)
- Added:
  * 3003.3-do-not-consider-skipped-targets-as-failed-for.patch
* Thu Sep 30 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not break master_tops for minion with version lower to 3003
- Added:
  * do-not-break-master_tops-for-minion-with-version-low.patch
* Fri Sep 24 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Support querying for JSON data in external sql pillar
- Added:
  * 3003.3-postgresql-json-support-in-pillar-423.patch
* Mon Sep 20 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update to Salt release version 3003.3
- See release notes: https://docs.saltstack.com/en/latest/topics/releases/3003.3.html
- Added:
  * allow-vendor-change-option-with-zypper.patch
  * support-transactional-systems-microos.patch
  * virt-enhancements.patch
- Modified:
  * adds-explicit-type-cast-for-port.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
  * fixes-56144-to-enable-hotadd-profile-support.patch
  * include-aliases-in-the-fqdns-grains.patch
  * implementation-of-held-unheld-functions-for-state-pk.patch
  * add-alibaba-cloud-linux-2-by-backporting-upstream-s-.patch
  * debian-info_installed-compatibility-50453.patch
  * fix-wrong-test_mod_del_repo_multiline_values-test-af.patch
  * update-target-fix-for-salt-ssh-to-process-targets-li.patch
  * x509-fixes-111.patch
  * prevent-logging-deadlock-on-salt-api-subprocesses-bs.patch
  * restore-default-behaviour-of-pkg-list-return.patch
  * adding-preliminary-support-for-rocky.-59682-391.patch
  * add-astra-linux-common-edition-to-the-os-family-list.patch
  * templates-move-the-globals-up-to-the-environment-jin.patch
  * fix-bsc-1065792.patch
  * add-migrated-state-and-gpg-key-management-functions-.patch
  * zypperpkg-ignore-retcode-104-for-search-bsc-1176697-.patch
  * improvements-on-ansiblegate-module-354.patch
  * add-custom-suse-capabilities-as-grains.patch
  * return-the-expected-powerpc-os-arch-bsc-1117995.patch
  * revert-fixing-a-use-case-when-multiple-inotify-beaco.patch
  * enhance-openscap-module-add-xccdf_eval-call-386.patch
  * implementation-of-suse_ip-execution-module-bsc-10999.patch
  * add-missing-aarch64-to-rpm-package-architectures-405.patch
  * async-batch-implementation.patch
  * temporary-fix-extend-the-whitelist-of-allowed-comman.patch
  * do-not-crash-when-unexpected-cmd-output-at-listing-p.patch
  * figure-out-python-interpreter-to-use-inside-containe.patch
  * better-handling-of-bad-public-keys-from-minions-bsc-.patch
  * early-feature-support-config.patch
  * do-not-monkey-patch-yaml-bsc-1177474.patch
- Removed:
  * fix-memory-leak-produced-by-batch-async-find_jobs-me.patch
  * fix-regression-on-cmd.run-when-passing-tuples-as-cmd.patch
  * fix-for-log-checking-in-x509-test.patch
  * do-not-make-ansiblegate-to-crash-on-python3-minions.patch
  * prevent-race-condition-on-sigterm-for-the-minion-bsc.patch
  * remove-msgpack-1.0.0-requirement-in-the-installed-me.patch
  * move-server_id-deprecation-warning-to-reduce-log-spa.patch
  * re-adding-function-to-test-for-root.patch
  * make-profiles-a-package.patch
  * handle-master-tops-data-when-states-are-applied-by-t.patch
  * fix-unit-tests-for-batch-async-after-refactor.patch
  * prevent-test_mod_del_repo_multiline_values-to-fail.patch
  * prevent-import-errors-when-running-test_btrfs-unit-t.patch
  * fix-failing-unit-tests-for-batch-async.patch
  * remove-unnecessary-yield-causing-badyielderror-bsc-1.patch
  * virt-use-dev-kvm-to-detect-kvm-383.patch
  * 3002.2-xen-spicevmc-dns-srv-records-backports-314.patch
  * add-docker-logout-237.patch
  * drop-wrong-mock-from-chroot-unit-test.patch
  * fix-async-batch-multiple-done-events.patch
  * fix-unit-test-for-grains-core.patch
  * remove-arch-from-name-when-pkg.list_pkgs-is-called-w.patch
  * pkgrepo-support-python-2.7-function-call-295.patch
  * opensuse-3000-virt-defined-states-222.patch
  * open-suse-3002.2-xen-grub-316.patch
  * add-patch-support-for-allow-vendor-change-option-wit.patch
  * fix-the-removed-six.itermitems-and-six.-_type-262.patch
  * fix-aptpkg-systemd-call-bsc-1143301.patch
  * add-almalinux-and-alibaba-cloud-linux-to-the-os-fami.patch
  * fix-cve-2020-25592-and-add-tests-bsc-1178319.patch
  * regression-fix-of-salt-ssh-on-processing-targets-353.patch
  * do-not-break-repo-files-with-multiple-line-values-on.patch
  * 3002-set-distro-requirement-to-oldest-supported-vers.patch
  * integration-of-msi-authentication-with-azurearm-clou.patch
  * zypperpkg-filter-patterns-that-start-with-dot-244.patch
  * fix-for-temp-folder-definition-in-loader-unit-test.patch
  * fix-novendorchange-option-284.patch
  * backport-virt-patches-from-3001-256.patch
  * allow-passing-kwargs-to-pkg.list_downloaded-bsc-1140.patch
  * path-replace-functools.wraps-with-six.wraps-bsc-1177.patch
  * virt-uefi-fix-backport-312.patch
  * add-all_versions-parameter-to-include-all-installed-.patch
  * add-pkg.services_need_restart-302.patch
  * add-batch_presence_ping_timeout-and-batch_presence_p.patch
  * allow-vendor-change-option-with-zypper-313.patch
  * avoid-traceback-when-http.query-request-cannot-be-pe.patch
  * changed-imports-to-vendored-tornado.patch
  * fix-issue-parsing-errors-in-ansiblegate-state-module.patch
  * sanitize-grains-loaded-from-roster_grains.json.patch
  * handle-volumes-on-stopped-pools-in-virt.vm_info-373.patch
  * add-multi-file-support-and-globbing-to-the-filetree-.patch
  * loosen-azure-sdk-dependencies-in-azurearm-cloud-driv.patch
  * backport-thread.is_alive-fix-390.patch
  * get-os_arch-also-without-rpm-package-installed.patch
  * python3.8-compatibility-pr-s-235.patch
  * fixed-bug-lvm-has-no-parttion-type.-the-scipt-later-.patch
  * ensure-virt.update-stop_on_reboot-is-updated-with-it.patch
  * xfs-do-not-fails-if-type-is-not-present.patch
  * grains-master-can-read-grains.patch
  * invalidate-file-list-cache-when-cache-file-modified-.patch
  * move-vendor-change-logic-to-zypper-class-355.patch
  * implement-network.fqdns-module-function-bsc-1134860-.patch
  * opensuse-3000.2-virt-backports-236-257.patch
  * prevent-ansiblegate-unit-tests-to-fail-on-ubuntu.patch
  * batch_async-avoid-using-fnmatch-to-match-event-217.patch
  * provide-the-missing-features-required-for-yomi-yet-o.patch
  * fix-__mount_device-wrapper-254.patch
  * fix-ipv6-scope-bsc-1108557.patch
  * fix-failing-unit-tests-for-systemd.patch
  * use-current-ioloop-for-the-localclient-instance-of-b.patch
  * revert-add-patch-support-for-allow-vendor-change-opt.patch
  * remove-deprecated-warning-that-breaks-miniion-execut.patch
  * prevent-systemd-run-description-issue-when-running-a.patch
  * fix-grains.test_core-unit-test-277.patch
  * prevent-command-injection-in-the-snapper-module-bsc-.patch
  * backport-of-upstream-pr59492-to-3002.2-404.patch
  * use-threadpool-from-multiprocessing.pool-to-avoid-le.patch
  * reintroducing-reverted-changes.patch
  * add-cpe_name-for-osversion-grain-parsing-u-49946.patch
  * add-hold-unhold-functions.patch
  * virt._get_domain-don-t-raise-an-exception-if-there-i.patch
  * fix-error-handling-in-openscap-module-bsc-1188647-40.patch
  * apply-patch-from-upstream-to-support-python-3.8.patch
  * remove-deprecated-usage-of-no_mock-and-no_mock_reaso.patch
  * add-supportconfig-module-for-remote-calls-and-saltss.patch
  * allow-extra_filerefs-as-sanitized-kwargs-for-ssh-cli.patch
  * fall-back-to-pymysql.patch
  * fixes-cve-2018-15750-cve-2018-15751.patch
  * do-not-crash-when-there-are-ipv6-established-connect.patch
  * improve-batch_async-to-release-consumed-memory-bsc-1.patch
  * support-config-non-root-permission-issues-fixes-u-50.patch
  * transactional_update-detect-recursion-in-the-executo.patch
  * open-suse-3002.2-virt-network-311.patch
  * option-to-en-disable-force-refresh-in-zypper-215.patch
  * do-noop-for-services-states-when-running-systemd-in-.patch
  * exclude-the-full-path-of-a-download-url-to-prevent-i.patch
  * fix-a-wrong-rebase-in-test_core.py-180.patch
  * add-new-custom-suse-capability-for-saltutil-state-mo.patch
  * opensuse-3000-libvirt-engine-fixes-251.patch
  * accumulated-changes-from-yomi-167.patch
  * fix-async-batch-race-conditions.patch
  * fix-onlyif-unless-when-multiple-conditions-bsc-11808.patch
  * loop-fix-variable-names-for-until_no_eval.patch
  * batch-async-catch-exceptions-and-safety-unregister-a.patch
  * grains.extra-support-old-non-intel-kernels-bsc-11806.patch
  * backport-a-few-virt-prs-272.patch
  * fix-git_pillar-merging-across-multiple-__env__-repos.patch
  * drop-wrong-virt-capabilities-code-after-rebasing-pat.patch
  * virt-adding-kernel-boot-parameters-to-libvirt-xml-55.patch
  * async-batch-implementation-fix-320.patch
  * support-for-btrfs-and-xfs-in-parted-and-mkfs.patch
  * support-transactional-systems-microos-271.patch
  * strip-trailing-from-repo.uri-when-comparing-repos-in.patch
  * opensuse-3000.3-spacewalk-runner-parse-command-250.patch
  * calculate-fqdns-in-parallel-to-avoid-blockings-bsc-1.patch
  * add-virt.all_capabilities.patch
  * ansiblegate-take-care-of-failed-skipped-and-unreacha.patch
  * virt-pass-emulator-when-getting-domain-capabilities-.patch
  * fixing-streamclosed-issue.patch
  * fix-for-some-cves-bsc1181550.patch
  * transactional_update-unify-with-chroot.call.patch
  * do-not-raise-streamclosederror-traceback-but-only-lo.patch
  * fix-batch_async-obsolete-test.patch
  * fix-zypper-pkg.list_pkgs-expectation-and-dpkg-mockin.patch
  * fix-zypper.list_pkgs-to-be-aligned-with-pkg-state.patch
  * accumulated-changes-required-for-yomi-165.patch
  * fix-virt.update-with-cpu-defined-263.patch
  * remove-vendored-backports-abc-from-requirements.patch
  * open-suse-3002.2-bigvm-310.patch
  * xen-disk-fixes-264.patch
  * virt.network_update-handle-missing-ipv4-netmask-attr.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
* Wed Sep 15 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Exclude the full path of a download URL to prevent injection of
  malicious code (bsc#1190265) (CVE-2021-21996)
- Added:
  * exclude-the-full-path-of-a-download-url-to-prevent-i.patch
* Tue Aug 31 2021 Victor Zhestkov <victor.zhestkov@suse.com>
- Fix wrong relative paths resolution with Jinja renderer when importing subdirectories
- Added:
  * templates-move-the-globals-up-to-the-environment-jin.patch
* Thu Aug 19 2021 Victor Zhestkov <victor.zhestkov@suse.com>
- Don't pass shell="/sbin/nologin" to onlyif/unless checks (bsc#1188259)
- Add missing aarch64 to rpm package architectures
- Backport of upstream PR#59492
- Added:
  * backport-of-upstream-pr59492-to-3002.2-404.patch
  * don-t-use-shell-sbin-nologin-in-requisites.patch
  * add-missing-aarch64-to-rpm-package-architectures-405.patch
* Wed Aug 11 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix failing unit test for systemd
- Fix error handling in openscap module (bsc#1188647)
- Better handling of bad public keys from minions (bsc#1189040)
- Added:
  * better-handling-of-bad-public-keys-from-minions-bsc-.patch
  * fix-error-handling-in-openscap-module-bsc-1188647-40.patch
  * fix-failing-unit-tests-for-systemd.patch
* Tue Aug 10 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Define license macro as doc in spec file if not existing
- Add standalone formulas configuration for salt minion and remove salt-master requirement (bsc#1168327)
* Fri Jul 16 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do noop for services states when running systemd in offline mode (bsc#1187787)
- transactional_updates: do not execute states in parallel but use a queue (bsc#1188170)
- Added:
  * do-noop-for-services-states-when-running-systemd-in-.patch
* Thu Jul  8 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Handle "master tops" data when states are applied by "transactional_update" (bsc#1187787)
- Enhance openscap module: add "xccdf_eval" call
- Added:
  * enhance-openscap-module-add-xccdf_eval-call-386.patch
  * handle-master-tops-data-when-states-are-applied-by-t.patch
* Tue Jul  6 2021 Victor Zhestkov <victor.zhestkov@suse.com>
- virt: pass emulator when getting domain capabilities from libvirt
- Adding preliminary support for Rocky Linux
- Implementation of held/unheld functions for state pkg (bsc#1187813)
- Added:
  * implementation-of-held-unheld-functions-for-state-pk.patch
  * adding-preliminary-support-for-rocky.-59682-391.patch
  * virt-pass-emulator-when-getting-domain-capabilities-.patch
* Fri Jun 25 2021 Alexander Graul <alexander.graul@suse.com>
- Replace deprecated Thread.isAlive() with Thread.is_alive()
- Added:
  * backport-thread.is_alive-fix-390.patch
* Thu Jun 24 2021 Victor Zhestkov <victor.zhestkov@suse.com>
- Fix exception in yumpkg.remove for not installed package
- Fix save for iptables state module (bsc#1185131)
- Added:
  * fix-exception-in-yumpkg.remove-for-not-installed-pac.patch
  * fix-save-for-iptables-state-module-bsc-1185131-372.patch
* Thu Jun 24 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- virt: use /dev/kvm to detect KVM
- Added:
  * virt-use-dev-kvm-to-detect-kvm-383.patch
* Thu Jun 24 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- zypperpkg: improve logic for handling vendorchange flags
- Added:
  * move-vendor-change-logic-to-zypper-class-355.patch
* Mon Jun 21 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add bundled provides for tornado to the spec file
- Enhance logging when inotify beacon is missing pyinotify (bsc#1186310)
- Add "python3-pyinotify" as a recommended package for Salt in SUSE/OpenSUSE distros
- Added:
  * enhance-logging-when-inotify-beacon-is-missing-pyino.patch
* Fri Jun  4 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix tmpfiles.d configuration for salt to not use legacy paths (bsc#1173103)
* Tue Jun  1 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Check if dpkgnotify is executable (bsc#1186674)
- Added:
  * check-if-dpkgnotify-is-executable-bsc-1186674-376.patch
* Fri May 21 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Detect Python version to use inside container (bsc#1167586) (bsc#1164192)
- Handle volumes on stopped pools in virt.vm_info (bsc#1186287)
- Drop support for Python2. Obsoletes "python2-salt" package
- Added:
  * handle-volumes-on-stopped-pools-in-virt.vm_info-373.patch
  * figure-out-python-interpreter-to-use-inside-containe.patch
* Mon May 10 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- grains.extra: support old non-intel kernels (bsc#1180650)
- Fix missing minion returns in batch mode (bsc#1184659)
- Added:
  * fix-missing-minion-returns-in-batch-mode-360.patch
  * grains.extra-support-old-non-intel-kernels-bsc-11806.patch
* Tue May  4 2021 Jochen Breuer <jbreuer@suse.de>
- Parsing Epoch out of version provided during pkg remove (bsc#1173692)
- Added:
  * parsing-epoch-out-of-version-provided-during-pkg-rem.patch
* Tue Apr 27 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix issue parsing errors in ansiblegate state module
- Added:
  * fix-issue-parsing-errors-in-ansiblegate-state-module.patch
* Tue Apr 27 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent command injection in the snapper module (bsc#1185281) (CVE-2021-31607)
- transactional_update: detect recursion in the executor
- Add subpackage salt-transactional-update (jsc#SLE-18028)
- Remove duplicate directories from specfile
- Added:
  * transactional_update-detect-recursion-in-the-executo.patch
  * prevent-command-injection-in-the-snapper-module-bsc-.patch
* Tue Apr 20 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Improvements on "ansiblegate" module (bsc#1185092):
  * New methods: ansible.targets / ansible.discover_playbooks
  * General bugfixes
- Added:
  * improvements-on-ansiblegate-module-354.patch
* Tue Apr 13 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Regression fix of salt-ssh on processing some targets
- Added:
  * regression-fix-of-salt-ssh-on-processing-targets-353.patch
* Tue Apr 13 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add support for Alibaba Cloud Linux 2 (Aliyun Linux)
- Added:
  * add-alibaba-cloud-linux-2-by-backporting-upstream-s-.patch
* Fri Apr  9 2021 Victor Zhestkov <victor.zhestkov@suse.com>
- Update target fix for salt-ssh to process targets list (bsc#1179831)
- Added:
  * update-target-fix-for-salt-ssh-to-process-targets-li.patch
* Fri Apr  9 2021 Alexander Graul <alexander.graul@suse.com>
- Add notify beacon for Debian/Ubuntu systems
- Add core grains support for AlmaLinux and Alibaba Could Linux
- Added:
  * add-almalinux-and-alibaba-cloud-linux-to-the-os-fami.patch
  * notify-beacon-for-debian-ubuntu-systems-347.patch
* Wed Mar 17 2021 Jochen Breuer <jbreuer@suse.de>
- Allow vendor change option with zypper
- Added:
  * allow-vendor-change-option-with-zypper-313.patch
* Wed Mar 10 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- virt.network_update: handle missing ipv4 netmask attribute
- Added:
  * virt.network_update-handle-missing-ipv4-netmask-attr.patch
* Tue Mar  9 2021 Alexander Graul <alexander.graul@suse.com>
- Set distro requirement to oldest supported version in requirements/base.txt
- Added:
  * 3002-set-distro-requirement-to-oldest-supported-vers.patch
* Tue Mar  9 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not monkey patch yaml loaders: Prevent breaking Ansible filter modules (bsc#1177474)
- Don't require python3-certifi
- Added:
  * do-not-monkey-patch-yaml-bsc-1177474.patch
* Wed Mar  3 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix race conditions for corner cases when handling SIGTERM by minion (bsc#1172110)
- Added:
  * prevent-race-condition-on-sigterm-for-the-minion-bsc.patch
* Mon Mar  1 2021 Alexander Graul <alexander.graul@suse.com>
- Allow extra_filerefs as sanitized kwargs for SSH client
- Fix regression on cmd.run when passing tuples as cmd (bsc#1182740)
- Fix for multiple for security issues
  (CVE-2020-28243) (CVE-2020-28972) (CVE-2020-35662) (CVE-2021-3148) (CVE-2021-3144)
  (CVE-2021-25281) (CVE-2021-25282) (CVE-2021-25283) (CVE-2021-25284) (CVE-2021-3197)
  (bsc#1181550) (bsc#1181556) (bsc#1181557) (bsc#1181558) (bsc#1181559) (bsc#1181560)
  (bsc#1181561) (bsc#1181562) (bsc#1181563) (bsc#1181564) (bsc#1181565)
- Implementation of suse_ip execution module to prevent issues with network.managed (bsc#1099976)
- Add sleep on exception handling on minion connection attempt to the master (bsc#1174855)
- Allows for the VMware provider to handle CPU and memory hot-add in newer versions of the software. (bsc#1181347)
- Always require python-certifi (used by salt.ext.tornado)
- Bring missing part of async batch implementation back (bsc#1182382) (CVE-2021-25315)
- Added:
  * implementation-of-suse_ip-execution-module-bsc-10999.patch
  * fix-regression-on-cmd.run-when-passing-tuples-as-cmd.patch
  * async-batch-implementation-fix-320.patch
  * add-sleep-on-exception-handling-on-minion-connection.patch
  * allow-extra_filerefs-as-sanitized-kwargs-for-ssh-cli.patch
  * fix-for-some-cves-bsc1181550.patch
  * fixes-56144-to-enable-hotadd-profile-support.patch
* Tue Feb 16 2021 Alexander Graul <alexander.graul@suse.com>
- Always require python3-distro (bsc#1182293)
* Thu Feb 11 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- virt: search for grub.xen path
- Xen spicevmc, DNS SRV records backports:
  Fix virtual network generated DNS XML for SRV records
  Don't add spicevmc channel to xen VMs
- virt UEFI fix: virt.update when efi=True
- Added:
  * virt-uefi-fix-backport-312.patch
  * 3002.2-xen-spicevmc-dns-srv-records-backports-314.patch
  * open-suse-3002.2-xen-grub-316.patch
* Mon Jan 25 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not crash when unexpected cmd output at listing patches (bsc#1181290)
- Added:
  * do-not-crash-when-unexpected-cmd-output-at-listing-p.patch
* Fri Jan 22 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix behavior for "onlyif/unless" when multiple conditions (bsc#1180818)
- Added:
  * fix-onlyif-unless-when-multiple-conditions-bsc-11808.patch
* Wed Jan 13 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Remove deprecated warning that breaks minion execution when "server_id_use_crc" opts is missing
- Added:
  * remove-deprecated-warning-that-breaks-miniion-execut.patch
* Wed Jan 13 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Revert wrong zypper patch to support vendorchanges flags on pkg.install
- Added:
  * revert-add-patch-support-for-allow-vendor-change-opt.patch
* Tue Jan 12 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Force zyppnotify to prefer Packages.db than Packages if it exists
- Allow vendor change option with zypper
- Add pkg.services_need_restart
- Fix for file.check_perms to work with numeric uid/gid
- Added:
  * force-zyppnotify-to-prefer-packages.db-than-packages.patch
  * fix-salt.utils.stringutils.to_str-calls-to-make-it-w.patch
  * add-patch-support-for-allow-vendor-change-option-wit.patch
  * add-pkg.services_need_restart-302.patch
* Tue Jan 12 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- virt: more network support
  Add more network and PCI/USB host devices passthrough support
  to virt module and states
- Added:
  * open-suse-3002.2-virt-network-311.patch
* Tue Jan 12 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Bigvm backports
  virt consoles, CPU tuning and topology, and memory tuning.
- Added:
  * open-suse-3002.2-bigvm-310.patch
* Mon Jan 11 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix pkg states when DEB package has "all" arch
- Added:
  * fix-aptpkg.normalize_name-when-package-arch-is-all.patch
* Tue Jan  5 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not force beacons configuration to be a list.
  Revert https://github.com/saltstack/salt/pull/58655
- Added:
  * revert-fixing-a-use-case-when-multiple-inotify-beaco.patch
* Tue Jan  5 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Drop wrong virt capabilities code after rebasing patches
- Added:
  * drop-wrong-virt-capabilities-code-after-rebasing-pat.patch
* Fri Dec 18 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update to Salt release version 3002.2 (jsc#ECO-3212) (jsc#SLE-18033)
- See release notes: https://docs.saltstack.com/en/latest/topics/releases/3002.2.html
- Modified:
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * let-salt-ssh-use-platform-python-binary-in-rhel8-191.patch
  * fix-__mount_device-wrapper-254.patch
  * opensuse-3000.2-virt-backports-236-257.patch
  * fixes-cve-2018-15750-cve-2018-15751.patch
  * strip-trailing-from-repo.uri-when-comparing-repos-in.patch
  * include-aliases-in-the-fqdns-grains.patch
  * support-config-non-root-permission-issues-fixes-u-50.patch
  * support-for-btrfs-and-xfs-in-parted-and-mkfs.patch
  * fix-batch_async-obsolete-test.patch
  * early-feature-support-config.patch
  * changed-imports-to-vendored-tornado.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * add-hold-unhold-functions.patch
  * do-not-crash-when-there-are-ipv6-established-connect.patch
  * add-docker-logout-237.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
  * fix-a-test-and-some-variable-names-229.patch
  * implement-network.fqdns-module-function-bsc-1134860-.patch
  * debian-info_installed-compatibility-50453.patch
  * fix-bsc-1065792.patch
  * use-current-ioloop-for-the-localclient-instance-of-b.patch
  * restore-default-behaviour-of-pkg-list-return.patch
  * virt-adding-kernel-boot-parameters-to-libvirt-xml-55.patch
  * use-threadpool-from-multiprocessing.pool-to-avoid-le.patch
  * add-migrated-state-and-gpg-key-management-functions-.patch
  * info_installed-works-without-status-attr-now.patch
  * bsc-1176024-fix-file-directory-user-and-group-owners.patch
  * opensuse-3000.3-spacewalk-runner-parse-command-250.patch
  * fix-aptpkg-systemd-call-bsc-1143301.patch
  * fix-memory-leak-produced-by-batch-async-find_jobs-me.patch
  * ansiblegate-take-care-of-failed-skipped-and-unreacha.patch
  * calculate-fqdns-in-parallel-to-avoid-blockings-bsc-1.patch
  * add-cpe_name-for-osversion-grain-parsing-u-49946.patch
  * python3.8-compatibility-pr-s-235.patch
  * backport-virt-patches-from-3001-256.patch
  * do-not-break-repo-files-with-multiple-line-values-on.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
  * accumulated-changes-required-for-yomi-165.patch
  * support-transactional-systems-microos-271.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * remove-vendored-backports-abc-from-requirements.patch
  * fall-back-to-pymysql.patch
  * xen-disk-fixes-264.patch
  * fix-for-temp-folder-definition-in-loader-unit-test.patch
  * batch.py-avoid-exception-when-minion-does-not-respon.patch
  * move-server_id-deprecation-warning-to-reduce-log-spa.patch
  * avoid-traceback-when-http.query-request-cannot-be-pe.patch
  * fixed-bug-lvm-has-no-parttion-type.-the-scipt-later-.patch
  * fix-zypper-pkg.list_pkgs-expectation-and-dpkg-mockin.patch
  * grains-master-can-read-grains.patch
  * remove-arch-from-name-when-pkg.list_pkgs-is-called-w.patch
  * fix-wrong-test_mod_del_repo_multiline_values-test-af.patch
  * accumulated-changes-from-yomi-167.patch
  * allow-passing-kwargs-to-pkg.list_downloaded-bsc-1140.patch
  * loosen-azure-sdk-dependencies-in-azurearm-cloud-driv.patch
  * add-astra-linux-common-edition-to-the-os-family-list.patch
  * fix-async-batch-race-conditions.patch
  * batch-async-catch-exceptions-and-safety-unregister-a.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * drop-wrong-mock-from-chroot-unit-test.patch
  * fix-for-suse-expanded-support-detection.patch
  * fix-novendorchange-option-284.patch
  * fix-virt.update-with-cpu-defined-263.patch
  * add-batch_presence_ping_timeout-and-batch_presence_p.patch
  * fix-git_pillar-merging-across-multiple-__env__-repos.patch
  * add-publish_batch-to-clearfuncs-exposed-methods.patch
  * fix-unit-tests-for-batch-async-after-refactor.patch
  * add-new-custom-suse-capability-for-saltutil-state-mo.patch
  * prevent-test_mod_del_repo_multiline_values-to-fail.patch
  * x509-fixes-111.patch
  * adds-explicit-type-cast-for-port.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * remove-msgpack-1.0.0-requirement-in-the-installed-me.patch
  * switch-firewalld-state-to-use-change_interface.patch
  * option-to-en-disable-force-refresh-in-zypper-215.patch
  * fix-async-batch-multiple-done-events.patch
  * make-setup.py-script-to-not-require-setuptools-9.1.patch
  * add-custom-suse-capabilities-as-grains.patch
  * don-t-call-zypper-with-more-than-one-no-refresh.patch
  * transactional_update-unify-with-chroot.call.patch
  * fix-ipv6-scope-bsc-1108557.patch
  * temporary-fix-extend-the-whitelist-of-allowed-comman.patch
  * opensuse-3000-libvirt-engine-fixes-251.patch
  * fix-grains.test_core-unit-test-277.patch
  * pkgrepo-support-python-2.7-function-call-295.patch
  * prevent-import-errors-when-running-test_btrfs-unit-t.patch
  * do-not-make-ansiblegate-to-crash-on-python3-minions.patch
  * fix-issue-2068-test.patch
  * ensure-virt.update-stop_on_reboot-is-updated-with-it.patch
  * remove-deprecated-usage-of-no_mock-and-no_mock_reaso.patch
  * read-repo-info-without-using-interpolation-bsc-11356.patch
  * fix-zypper.list_pkgs-to-be-aligned-with-pkg-state.patch
  * fixing-streamclosed-issue.patch
  * virt._get_domain-don-t-raise-an-exception-if-there-i.patch
  * loop-fix-variable-names-for-until_no_eval.patch
  * improve-batch_async-to-release-consumed-memory-bsc-1.patch
  * prevent-systemd-run-description-issue-when-running-a.patch
  * integration-of-msi-authentication-with-azurearm-clou.patch
  * add-all_versions-parameter-to-include-all-installed-.patch
  * sanitize-grains-loaded-from-roster_grains.json.patch
  * fix-failing-unit-tests-for-batch-async.patch
  * reintroducing-reverted-changes.patch
  * fix-for-log-checking-in-x509-test.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
  * opensuse-3000-virt-defined-states-222.patch
  * add-virt.all_capabilities.patch
  * prevent-logging-deadlock-on-salt-api-subprocesses-bs.patch
  * fix-cve-2020-25592-and-add-tests-bsc-1178319.patch
  * fix-unit-test-for-grains-core.patch
  * async-batch-implementation.patch
  * apply-patch-from-upstream-to-support-python-3.8.patch
  * remove-unnecessary-yield-causing-badyielderror-bsc-1.patch
  * re-adding-function-to-test-for-root.patch
  * zypperpkg-filter-patterns-that-start-with-dot-244.patch
  * fix-a-wrong-rebase-in-test_core.py-180.patch
  * add-multi-file-support-and-globbing-to-the-filetree-.patch
  * fix-the-removed-six.itermitems-and-six.-_type-262.patch
  * zypperpkg-ignore-retcode-104-for-search-bsc-1176697-.patch
  * add-standalone-configuration-file-for-enabling-packa.patch
  * make-profiles-a-package.patch
  * return-the-expected-powerpc-os-arch-bsc-1117995.patch
  * batch_async-avoid-using-fnmatch-to-match-event-217.patch
  * do-not-raise-streamclosederror-traceback-but-only-lo.patch
  * provide-the-missing-features-required-for-yomi-yet-o.patch
  * make-aptpkg.list_repos-compatible-on-enabled-disable.patch
  * backport-a-few-virt-prs-272.patch
  * add-supportconfig-module-for-remote-calls-and-saltss.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * path-replace-functools.wraps-with-six.wraps-bsc-1177.patch
  * get-os_arch-also-without-rpm-package-installed.patch
  * invalidate-file-list-cache-when-cache-file-modified-.patch
  * xfs-do-not-fails-if-type-is-not-present.patch
  * prevent-ansiblegate-unit-tests-to-fail-on-ubuntu.patch
- Removed:
  * do-not-report-patches-as-installed-when-not-all-the-.patch
  * add-pkg.services_need_restart-302.patch
  * removes-unresolved-merge-conflict-in-yumpkg-module.patch
  * add-missing-fun-for-returns-from-wfunc-executions.patch
  * force-zyppnotify-to-prefer-packages.db-than-packages.patch
  * decide-if-the-source-should-be-actually-skipped.patch
  * make-lazyloader.__init__-call-to-_refresh_file_mappi.patch
  * avoid-has_docker-true-if-import-messes-with-salt.uti.patch
  * fix-for-bsc-1102248-psutil-is-broken-and-so-process-.patch
  * set-passphrase-for-salt-ssh-keys-to-empty-string-293.patch
  * fix-salt.utils.stringutils.to_str-calls-to-make-it-w.patch
  * add-patch-support-for-allow-vendor-change-option-wit.patch
  * opensuse-3000.3-bigvm-backports-303.patch
  * msgpack-support-versions-1.0.0.patch
  * fix-typo-on-msgpack-version-when-sanitizing-msgpack-.patch
  * use-full-option-name-instead-of-undocumented-abbrevi.patch
  * add-missing-_utils-at-loader-grains_func.patch
  * loader-invalidate-the-import-cachefor-extra-modules.patch
  * fix-for-return-value-ret-vs-return-in-batch-mode.patch
  * make-salt.ext.tornado.gen-to-use-salt.ext.backports_.patch
* Thu Dec 10 2020 Jochen Breuer <jbreuer@suse.de>
- Force zyppnotify to prefer Packages.db than Packages if it exists
- Allow vendor change option with zypper
- Added:
  * add-patch-support-for-allow-vendor-change-option-wit.patch
  * force-zyppnotify-to-prefer-packages.db-than-packages.patch
* Tue Dec  8 2020 Jochen Breuer <jbreuer@suse.de>
- Add pkg.services_need_restart
-  Bigvm backports:
  virt consoles, CPU tuning and topology, and memory tuning.
-  Fix for file.check_perms to work with numeric uid/gid
- Added:
  * add-pkg.services_need_restart-302.patch
  * fix-salt.utils.stringutils.to_str-calls-to-make-it-w.patch
  * opensuse-3000.3-bigvm-backports-303.patch
* Fri Nov 27 2020 Victor Zhestkov <victor.zhestkov@suse.com>
- Change 'Requires(pre)' to 'Requires' for salt-minion package (bsc#1083110)
* Mon Nov 16 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix syntax error on pkgrepo state with Python 2.7
- transactional_update: unify with chroot.call
- Added:
  * pkgrepo-support-python-2.7-function-call-295.patch
  * transactional_update-unify-with-chroot.call.patch
* Tue Nov 10 2020 Jochen Breuer <jbreuer@suse.de>
- Add "migrated" state and GPG key management functions
- Added:
  * add-migrated-state-and-gpg-key-management-functions-.patch
* Tue Nov 10 2020 Jochen Breuer <jbreuer@suse.de>
- Master can read grains (bsc#1179696)
- Added:
  * grains-master-can-read-grains.patch
* Tue Nov 10 2020 Jochen Breuer <jbreuer@suse.de>
- Fix for broken psutil (bsc#1102248)
- Added:
  * fix-for-bsc-1102248-psutil-is-broken-and-so-process-.patch
* Fri Nov  6 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Set passphrase for salt-ssh keys to empty string (bsc#1178485)
- Added:
  * set-passphrase-for-salt-ssh-keys-to-empty-string-293.patch
* Wed Nov  4 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Properly validate eauth credentials and tokens on SSH calls made by Salt API
  (bsc#1178319) (bsc#1178362) (bsc#1178361)
  (CVE-2020-25592) (CVE-2020-17490) (CVE-2020-16846)
- Added:
  * fix-cve-2020-25592-and-add-tests-bsc-1178319.patch
* Tue Oct 27 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix novendorchange handling in zypperpkg module
- Added:
  * fix-novendorchange-option-284.patch
* Tue Oct 20 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix disk.blkid to avoid unexpected keyword argument '__pub_user' (bsc#1177867)
- Added:
  * path-replace-functools.wraps-with-six.wraps-bsc-1177.patch
* Wed Oct 14 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Ensure virt.update stop_on_reboot is updated with its default value
- Added:
  * ensure-virt.update-stop_on_reboot-is-updated-with-it.patch
* Tue Oct 13 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not break package building for systemd OSes
* Tue Oct 13 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Drop wrong mock from chroot unit test
- Added:
  * drop-wrong-mock-from-chroot-unit-test.patch
* Wed Oct  7 2020 Jochen Breuer <jbreuer@suse.de>
- Support systemd versions with dot (bsc#1176294)
* Tue Oct  6 2020 Jochen Breuer <jbreuer@suse.de>
- Fix for grains.test_core unit test
- Fix file/directory user and group ownership containing UTF-8
  characters (bsc#1176024)
- Several changes to virtualization:
-   - Fix virt update when cpu and memory are changed
-   - Memory Tuning GSoC
-   - Properly fix memory setting regression in virt.update
-   - Expose libvirt on_reboot in virt states
- Support transactional systems (MicroOS)
- zypperpkg module ignores retcode 104 for search() (bsc#1159670)
- Xen disk fixes. No longer generates volumes for Xen disks, but the
  corresponding file or block disk (bsc#1175987)
- Added:
  * fix-grains.test_core-unit-test-277.patch
  * support-transactional-systems-microos-271.patch
  * backport-a-few-virt-prs-272.patch
  * xen-disk-fixes-264.patch
  * zypperpkg-ignore-retcode-104-for-search-bsc-1176697-.patch
  * bsc-1176024-fix-file-directory-user-and-group-owners.patch
* Wed Sep 23 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Invalidate file list cache when cache file modified time is in the future (bsc#1176397)
- Added:
  * invalidate-file-list-cache-when-cache-file-modified-.patch
* Wed Sep 16 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent import errors when running test_btrfs unit tests
- Added:
  * prevent-import-errors-when-running-test_btrfs-unit-t.patch
* Wed Sep 16 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Remove msgpack < 1.0.0 from base requirements (bsc#1176293)
- Added:
  * remove-msgpack-1.0.0-requirement-in-the-installed-me.patch
* Tue Sep 15 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix virt.update with CPU defined
- Added:
  * fix-virt.update-with-cpu-defined-263.patch
* Tue Sep 15 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix virt issues and invalid input errors from 'salt.utils.data' (bsc#1176480)
- Added:
  * fix-the-removed-six.itermitems-and-six.-_type-262.patch
* Tue Sep  8 2020 Jochen Breuer <jbreuer@suse.de>
- Reintroduces the patches from
  opensuse-3000.2-virt-backports-236.patch coming from Salt 3001
- Added:
  * backport-virt-patches-from-3001-256.patch
* Tue Sep  1 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Adding missing virt backports to 3000.3
- Added:
  * opensuse-3000.2-virt-backports-236-257.patch
* Thu Aug 27 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not raise StreamClosedError traceback but only log it (bsc#1175549)
- Added:
  * do-not-raise-streamclosederror-traceback-but-only-lo.patch
* Mon Aug 17 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Take care of failed, skipped and unreachable tasks and propagate "retcode" (bsc#1173911) (bsc#1173909)
- Added:
  * ansiblegate-take-care-of-failed-skipped-and-unreacha.patch
* Mon Aug 10 2020 Alexander Graul <alexander.graul@suse.com>
- Require /usr/bin/python instead of /bin/python for RHEL-family (bsc#1173936)
* Fri Jul 31 2020 Alexander Graul <alexander.graul@suse.com>
- Don't install SuSEfirewall2 service files in Factory
- Fix __mount_device wrapper to accept separate args and kwargs
- Added:
  * fix-__mount_device-wrapper-254.patch
* Fri Jul  3 2020 Jochen Breuer <jbreuer@suse.de>
- Fix the registration of libvirt pool and nodedev events
- Accept nested namespaces in spacewalk.api runner function. (bsc#1172211)
- info_installed works without status attr now (bsc#1171461)
- Added:
  * info_installed-works-without-status-attr-now.patch
  * opensuse-3000.3-spacewalk-runner-parse-command-250.patch
  * opensuse-3000-libvirt-engine-fixes-251.patch
* Thu May 28 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Avoid traceback on debug logging for swarm module (bsc#1172075)
- Added:
  * avoid-has_docker-true-if-import-messes-with-salt.uti.patch
* Thu May 28 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add publish_batch to ClearFuncs exposed methods
- Added:
  * add-publish_batch-to-clearfuncs-exposed-methods.patch
* Tue May 26 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update to Salt release version 3000.3
  See release notes: https://docs.saltstack.com/en/latest/topics/releases/3000.3.html
- Removed:
  * fix-typo-in-minion_runner-for-aesfuncs-exposed-metho.patch
* Thu May 21 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- zypperpkg: filter patterns that start with dot (bsc#1171906)
- Added:
  * zypperpkg-filter-patterns-that-start-with-dot-244.patch
* Wed May 20 2020 Jochen Breuer <jbreuer@suse.de>
- Batch mode now also correctly provides return value (bsc#1168340)
- Added:
  * fix-for-return-value-ret-vs-return-in-batch-mode.patch
* Mon May 18 2020 Alexander Graul <alexander.graul@suse.com>
- Add docker.logout to docker execution module (bsc#1165572)
- Added:
  * add-docker-logout-237.patch
* Tue May 12 2020 Jochen Breuer <jbreuer@suse.de>
- Testsuite fix
- Add option to enable/disable force refresh for zypper
- Added:
  * option-to-en-disable-force-refresh-in-zypper-215.patch
  * fix-a-test-and-some-variable-names-229.patch
* Fri May  8 2020 Jochen Breuer <jbreuer@suse.de>
- Python 3.8 compatibility changes
- msgpack support for version >= 1.0.0 (bsc#1171257)
- Added:
  * python3.8-compatibility-pr-s-235.patch
  * msgpack-support-versions-1.0.0.patch
* Thu May  7 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent sporious "salt-api" stuck processes when managing SSH minions
  because of logging deadlock (bsc#1159284)
- Avoid segfault from "salt-api" under certain conditions of heavy load
  managing SSH minions (bsc#1169604)
- Added:
  * prevent-logging-deadlock-on-salt-api-subprocesses-bs.patch
  * make-lazyloader.__init__-call-to-_refresh_file_mappi.patch
* Thu Apr 30 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update to Salt release version 3000.2
  See release notes: https://docs.saltstack.com/en/latest/topics/releases/3000.2.html
- Fix typo in 'minion_runner' for AESFuncs exposed methods
- Added:
  * fix-typo-in-minion_runner-for-aesfuncs-exposed-metho.patch
- Removed:
  * fix-cve-2020-11651-and-fix-cve-2020-11652.patch
* Thu Apr 30 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update to Salt release version 3000.1
  See release notes: https://docs.saltstack.com/en/latest/topics/releases/3000.1.html
- Fix CVE-2020-11651 and CVE-2020-11652 (bsc#1170595)
- Do not require vendored backports-abc (bsc#1170288)
- Fix partition.mkpart to work without fstype (bsc#1169800)
- Added:
  * fixed-bug-lvm-has-no-parttion-type.-the-scipt-later-.patch
  * remove-vendored-backports-abc-from-requirements.patch
  * fix-cve-2020-11651-and-fix-cve-2020-11652.patch
- Modified:
  * fix-a-wrong-rebase-in-test_core.py-180.patch
  * make-setup.py-script-to-not-require-setuptools-9.1.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
  * accumulated-changes-from-yomi-167.patch
- Removed:
  * fix-for-unless-requisite-when-pip-is-not-installed.patch
  * fix-regression-in-service-states-with-reload-argumen.patch
* Tue Apr  7 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Update to Salt version 3000
  See release notes: https://docs.saltstack.com/en/latest/topics/releases/3000.html
- Do not make file.recurse state to fail when msgpack 0.5.4 (bsc#1167437)
- Fixes status attribute issue in aptpkg test
- Make setup.py script not to require setuptools greater than 9.1
  loop: fix variable names for until_no_eval
- Drop conflictive module.run state patch (bsc#1167437)
- Update patches after rebase with upstream v3000 tag (bsc#1167437)
- Fix some requirements issues depending on Python3 versions
- Removes obsolete patch
- Fix for low rpm_lowpkg unit test
- Add python-singledispatch as dependency for python2-salt
- Fix for temp folder definition in loader unit test
- Make "salt.ext.tornado.gen" to use "salt.ext.backports_abc" on Python 2
- Fix regression in service states with reload argument
- Fix integration test failure for test_mod_del_repo_multiline_values
- Fix for unless requisite when pip is not installed
- Fix errors from unit tests due NO_MOCK and NO_MOCK_REASON deprecation
- Fix tornado imports and missing _utils after rebasing patches
- Removes unresolved merge conflict in yumpkg module
- Added:
  * make-setup.py-script-to-not-require-setuptools-9.1.patch
  * opensuse-3000-virt-defined-states-222.patch
  * fix-for-unless-requisite-when-pip-is-not-installed.patch
  * fix-typo-on-msgpack-version-when-sanitizing-msgpack-.patch
  * fix-regression-in-service-states-with-reload-argumen.patch
  * batch_async-avoid-using-fnmatch-to-match-event-217.patch
  * make-salt.ext.tornado.gen-to-use-salt.ext.backports_.patch
  * virt._get_domain-don-t-raise-an-exception-if-there-i.patch
  * loop-fix-variable-names-for-until_no_eval.patch
  * removes-unresolved-merge-conflict-in-yumpkg-module.patch
  * add-missing-_utils-at-loader-grains_func.patch
  * changed-imports-to-vendored-tornado.patch
  * sanitize-grains-loaded-from-roster_grains.json.patch
  * fix-for-temp-folder-definition-in-loader-unit-test.patch
  * remove-deprecated-usage-of-no_mock-and-no_mock_reaso.patch
  * reintroducing-reverted-changes.patch
  * adds-explicit-type-cast-for-port.patch
  * fix-wrong-test_mod_del_repo_multiline_values-test-af.patch
  * re-adding-function-to-test-for-root.patch
- Modified:
  * move-server_id-deprecation-warning-to-reduce-log-spa.patch
  * let-salt-ssh-use-platform-python-binary-in-rhel8-191.patch
  * strip-trailing-from-repo.uri-when-comparing-repos-in.patch
  * prevent-test_mod_del_repo_multiline_values-to-fail.patch
  * prevent-ansiblegate-unit-tests-to-fail-on-ubuntu.patch
  * remove-arch-from-name-when-pkg.list_pkgs-is-called-w.patch
  * async-batch-implementation.patch
  * add-hold-unhold-functions.patch
  * add-all_versions-parameter-to-include-all-installed-.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
  * fix-for-log-checking-in-x509-test.patch
  * fix-zypper.list_pkgs-to-be-aligned-with-pkg-state.patch
  * add-multi-file-support-and-globbing-to-the-filetree-.patch
  * remove-unnecessary-yield-causing-badyielderror-bsc-1.patch
  * fix-bsc-1065792.patch
  * use-threadpool-from-multiprocessing.pool-to-avoid-le.patch
  * return-the-expected-powerpc-os-arch-bsc-1117995.patch
  * fixes-cve-2018-15750-cve-2018-15751.patch
  * add-cpe_name-for-osversion-grain-parsing-u-49946.patch
  * fix-failing-unit-tests-for-batch-async.patch
  * decide-if-the-source-should-be-actually-skipped.patch
  * allow-passing-kwargs-to-pkg.list_downloaded-bsc-1140.patch
  * add-batch_presence_ping_timeout-and-batch_presence_p.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * use-current-ioloop-for-the-localclient-instance-of-b.patch
  * integration-of-msi-authentication-with-azurearm-clou.patch
  * temporary-fix-extend-the-whitelist-of-allowed-comman.patch
  * improve-batch_async-to-release-consumed-memory-bsc-1.patch
  * fix-unit-test-for-grains-core.patch
  * add-supportconfig-module-for-remote-calls-and-saltss.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * debian-info_installed-compatibility-50453.patch
  * include-aliases-in-the-fqdns-grains.patch
  * implement-network.fqdns-module-function-bsc-1134860-.patch
  * fix-async-batch-multiple-done-events.patch
  * support-config-non-root-permission-issues-fixes-u-50.patch
  * fix-zypper-pkg.list_pkgs-expectation-and-dpkg-mockin.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * avoid-traceback-when-http.query-request-cannot-be-pe.patch
  * fix-aptpkg-systemd-call-bsc-1143301.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * do-not-break-repo-files-with-multiple-line-values-on.patch
  * fix-batch_async-obsolete-test.patch
  * provide-the-missing-features-required-for-yomi-yet-o.patch
  * fall-back-to-pymysql.patch
  * xfs-do-not-fails-if-type-is-not-present.patch
  * restore-default-behaviour-of-pkg-list-return.patch
  * add-missing-fun-for-returns-from-wfunc-executions.patch
  * virt-adding-kernel-boot-parameters-to-libvirt-xml-55.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * loosen-azure-sdk-dependencies-in-azurearm-cloud-driv.patch
  * support-for-btrfs-and-xfs-in-parted-and-mkfs.patch
  * fixing-streamclosed-issue.patch
  * do-not-crash-when-there-are-ipv6-established-connect.patch
  * calculate-fqdns-in-parallel-to-avoid-blockings-bsc-1.patch
  * fix-async-batch-race-conditions.patch
  * fix-issue-2068-test.patch
  * fix-a-wrong-rebase-in-test_core.py-180.patch
  * fix-for-suse-expanded-support-detection.patch
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * add-standalone-configuration-file-for-enabling-packa.patch
  * switch-firewalld-state-to-use-change_interface.patch
  * do-not-make-ansiblegate-to-crash-on-python3-minions.patch
  * make-aptpkg.list_repos-compatible-on-enabled-disable.patch
  * add-custom-suse-capabilities-as-grains.patch
  * accumulated-changes-from-yomi-167.patch
  * get-os_arch-also-without-rpm-package-installed.patch
  * fix-git_pillar-merging-across-multiple-__env__-repos.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
  * early-feature-support-config.patch
  * add-virt.all_capabilities.patch
  * accumulated-changes-required-for-yomi-165.patch
  * fix-memory-leak-produced-by-batch-async-find_jobs-me.patch
  * fix-ipv6-scope-bsc-1108557.patch
  * prevent-systemd-run-description-issue-when-running-a.patch
  * make-profiles-a-package.patch
  * don-t-call-zypper-with-more-than-one-no-refresh.patch
  * batch.py-avoid-exception-when-minion-does-not-respon.patch
  * read-repo-info-without-using-interpolation-bsc-11356.patch
  * x509-fixes-111.patch
  * do-not-report-patches-as-installed-when-not-all-the-.patch
- Removed:
  * remove-virt.pool_delete-fast-parameter-178.patch
  * adds-the-possibility-to-also-use-downloadonly-in-kwa.patch
  * align-virt-full-info-fixes-with-upstream-192.patch
  * take-checksums-arg-into-account-for-postgres.datadir.patch
  * virt-1.volume_infos-fix-for-single-vm.patch
  * virt.volume_infos-needs-to-ignore-inactive-pools-174.patch
  * preserve-already-defined-destructive_tests-and-expen.patch
  * list_downloaded-for-apt-module.patch
  * fix-virt-states-to-not-fail-on-vms-already-stopped.-.patch
  * virt.volume_infos-fix-for-single-vm.patch
  * restrict-the-start_event_grains-only-to-the-start-ev.patch
  * fix-virt.full_info-176.patch
  * preserving-signature-in-module.run-state-u-50049.patch
  * checking-for-jid-before-returning-data.patch
  * virt.volume_infos-silence-libvirt-error-message-175.patch
  * add-virt.volume_infos-and-virt.volume_delete.patch
  * add-virt.network_get_xml-function.patch
  * virt.network_define-allow-adding-ip-configuration.patch
  * add-ppc64le-as-a-valid-rpm-package-architecture.patch
  * bugfix-any-unicode-string-of-length-16-will-raise-ty.patch
  * fix-for-older-mock-module.patch
  * fix-virt.get_hypervisor-188.patch
  * 2019.2.0-pr-54196-backport-173.patch
  * enable-passing-grains-to-start-event-based-on-start_.patch
  * fix-load-cached-grain-osrelease_info.patch
  * open-suse-2019.2.3-virt-defined-states-219.patch
  * backport-saltutil-state-module-to-2019.2-codebase.patch
* Thu Apr  2 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Enable building and installation for Fedora
- Disable python2 build on Tumbleweed
  We are removing the python2 interpreter from openSUSE (SLE16).
  As such disable salt building for python2 there.
* Thu Apr  2 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Sanitize grains loaded from roster_grains.json cache during "state.pkg"
- Added:
  * fix-load-cached-grain-osrelease_info.patch
* Fri Mar 27 2020 Jochen Breuer <jbreuer@suse.de>
- Build: Buildequire pkgconfig(systemd) instead of systemd
* Thu Mar 26 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Backport saltutil state module to 2019.2 codebase (bsc#1167556)
- Add new custom SUSE capability for saltutil state module
- Added:
  * backport-saltutil-state-module-to-2019.2-codebase.patch
  * add-new-custom-suse-capability-for-saltutil-state-mo.patch
* Tue Mar 17 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- virt._get_domain: don't raise an exception if there is no VM
- Added:
  * virt._get_domain-don-t-raise-an-exception-if-there-i.patch
* Mon Mar 16 2020 Jochen Breuer <jbreuer@suse.de>
- Adds test for zypper abbreviation fix
- Improved storage pool or network handling
- Better import cache handline
- Added:
  * loader-invalidate-the-import-cachefor-extra-modules.patch
  * open-suse-2019.2.3-virt-defined-states-219.patch
- Modified:
  * use-full-option-name-instead-of-undocumented-abbrevi.patch
* Thu Mar  5 2020 Jochen Breuer <jbreuer@suse.de>
- Use full option name instead of undocumented abbreviation for zypper
- Requiring python3-distro only for openSUSE/SLE >= 15
- Added:
  * use-full-option-name-instead-of-undocumented-abbrevi.patch
* Thu Mar  5 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- python-distro is only needed for > Python 3.7. Removing it for Python 2
* Wed Mar  4 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Avoid possible user escalation upgrading salt-master (bsc#1157465) (CVE-2019-18897)
* Wed Mar  4 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix unit tests failures in test_batch_async tests
- Added:
  * fix-unit-tests-for-batch-async-after-refactor.patch
* Mon Mar  2 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Batch Async: Handle exceptions, properly unregister and close instances
  after running async batching to avoid CPU starvation of the MWorkers (bsc#1162327)
- RHEL/CentOS 8 uses platform-python instead of python3
- Enable build for Python 3.8
- Added:
  * batch_async-avoid-using-fnmatch-to-match-event-217.patch
  * apply-patch-from-upstream-to-support-python-3.8.patch
  * batch-async-catch-exceptions-and-safety-unregister-a.patch
* Wed Feb 12 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix 'os_family' grain for Astra Linux Common Edition
- Added:
  * add-astra-linux-common-edition-to-the-os-family-list.patch
* Mon Feb  3 2020 Jochen Breuer <jbreuer@suse.de>
- Update to Salt version 2019.2.3 (CVE-2019-17361) (bsc#1163981) (bsc#1162504)
  See release notes: https://docs.saltstack.com/en/latest/topics/releases/2019.2.3.html
- Modified:
  * use-adler32-algorithm-to-compute-string-checksums.patch
* Wed Jan 29 2020 Jochen Breuer <jbreuer@suse.de>
- Enable passing grains to start event based on 'start_event_grains' configuration parameter
- Added:
  * restrict-the-start_event_grains-only-to-the-start-ev.patch
  * enable-passing-grains-to-start-event-based-on-start_.patch
* Mon Jan 13 2020 Jochen Breuer <jbreuer@suse.de>
- Support for Btrfs and XFS in parted and mkfs added
- Added:
  * support-for-btrfs-and-xfs-in-parted-and-mkfs.patch
* Thu Jan  9 2020 Jochen Breuer <jbreuer@suse.de>
- Adds list_downloaded for apt Module to enable pre-downloading support
- Adds virt.(pool|network)_get_xml functions
- Various libvirt updates
  * Add virt.pool_capabilities function
  * virt.pool_running improvements
  * Add virt.pool_deleted state
  * virt.network_define allow adding IP configuration
- Added:
  * virt.network_define-allow-adding-ip-configuration.patch
  * list_downloaded-for-apt-module.patch
  * add-virt.network_get_xml-function.patch
* Tue Jan  7 2020 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- virt: adding kernel boot parameters to libvirt xml
- Added:
  * virt-adding-kernel-boot-parameters-to-libvirt-xml-55.patch
* Mon Dec 16 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix virt states to not fail on VMs already stopped
- Added:
  * fix-virt-states-to-not-fail-on-vms-already-stopped.-.patch
* Thu Dec 12 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add missing bugzilla references:
  Properly handle colons in inline dicts with yamlloader (bsc#1095651)
  Fix corrupt public key with m2crypto python3 (bsc#1099323)
  Add missing dateutils import (bsc#1099945)
  Fix UnicodeDecodeError using is_binary check (bsc#1100225)
  Prevent payload crash on decoding binary data (bsc#1100697)
  Fix file.blockreplace to avoid throwing IndexError (bsc#1101812)
  Add API log rotation on SUSE package (bsc#1102218)
  Fix wrong recurse behavior on for linux_acl.present (bsc#1106164)
  Handle anycast IPv6 addresses on network.routes (bsc#1114474)
  Crontab module fix: file attributes option missing (bsc#1114824)
  Add metadata to accepted keyword arguments (bsc#1122680)
  Bugfix: properly refresh pillars (bsc#1125015)
* Wed Dec 11 2019 Mihai Dincă <mihai.dinca@suse.com>
- xfs: do not fail if type is not present (bsc#1153611)
- Added:
  * xfs-do-not-fails-if-type-is-not-present.patch
* Tue Dec 10 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Don't use __python indirection macros on spec file
  %%__python is no longer defined in RPM 4.15 (python2 is going EOL in Jan 2020);
  additionally, python/python3 are just binaries in the path.
* Tue Dec 10 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix errors when running virt.get_hypervisor function
- Added:
  * fix-virt.get_hypervisor-188.patch
* Mon Dec  9 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Align virt.full_info fixes with upstream Salt
- Let salt-ssh use platform-python on RHEL8 (bsc#1158441)
- Added:
  * align-virt-full-info-fixes-with-upstream-192.patch
  * let-salt-ssh-use-platform-python-binary-in-rhel8-191.patch
* Tue Dec  3 2019 Mihai Dincă <mihai.dinca@suse.com>
- Fix StreamClosedError issue (bsc#1157479)
- Added:
  * fix-batch_async-obsolete-test.patch
  * fixing-streamclosed-issue.patch
* Thu Nov 28 2019 Mihai Dincă <mihai.dinca@suse.com>
- Prevent test_mod_del_repo_multiline_values to fail
- Read repo info without using interpolation (bsc#1135656)
- Requires vs BuildRequires
- Limiting M2Crypto to >= SLE15
- Replacing pycrypto with M2Crypto (bsc#1165425)
- Fix for log checking in x509 test
- Update to 2019.2.2 release
- Added:
  * fix-for-log-checking-in-x509-test.patch
  * prevent-test_mod_del_repo_multiline_values-to-fail.patch
  * read-repo-info-without-using-interpolation-bsc-11356.patch
- Modified:
  * async-batch-implementation.patch
  * add-hold-unhold-functions.patch
  * adds-the-possibility-to-also-use-downloadonly-in-kwa.patch
  * decide-if-the-source-should-be-actually-skipped.patch
  * allow-passing-kwargs-to-pkg.list_downloaded-bsc-1140.patch
  * add-batch_presence_ping_timeout-and-batch_presence_p.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * fix-unit-test-for-grains-core.patch
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * fix-async-batch-multiple-done-events.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * fix-for-older-mock-module.patch
  * do-not-break-repo-files-with-multiple-line-values-on.patch
  * fall-back-to-pymysql.patch
  * add-missing-fun-for-returns-from-wfunc-executions.patch
  * loosen-azure-sdk-dependencies-in-azurearm-cloud-driv.patch
  * add-virt.volume_infos-and-virt.volume_delete.patch
  * fix-issue-2068-test.patch
  * switch-firewalld-state-to-use-change_interface.patch
  * make-aptpkg.list_repos-compatible-on-enabled-disable.patch
  * fix-ipv6-scope-bsc-1108557.patch
  * 2019.2.0-pr-54196-backport-173.patch
  * do-not-make-ansiblegate-to-crash-on-python3-minions.patch
  * x509-fixes-111.patch
  * prevent-ansiblegate-unit-tests-to-fail-on-ubuntu.patch
  * fix-zypper.list_pkgs-to-be-aligned-with-pkg-state.patch
  * add-cpe_name-for-osversion-grain-parsing-u-49946.patch
  * fix-failing-unit-tests-for-batch-async.patch
  * temporary-fix-extend-the-whitelist-of-allowed-comman.patch
  * improve-batch_async-to-release-consumed-memory-bsc-1.patch
  * batch.py-avoid-exception-when-minion-does-not-respon.patch
  * preserve-already-defined-destructive_tests-and-expen.patch
  * virt.volume_infos-fix-for-single-vm.patch
  * move-server_id-deprecation-warning-to-reduce-log-spa.patch
  * include-aliases-in-the-fqdns-grains.patch
  * don-t-call-zypper-with-more-than-one-no-refresh.patch
  * add-custom-suse-capabilities-as-grains.patch
  * get-os_arch-also-without-rpm-package-installed.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
  * accumulated-changes-required-for-yomi-165.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * remove-arch-from-name-when-pkg.list_pkgs-is-called-w.patch
  * use-current-ioloop-for-the-localclient-instance-of-b.patch
  * remove-virt.pool_delete-fast-parameter-178.patch
  * add-multi-file-support-and-globbing-to-the-filetree-.patch
  * use-threadpool-from-multiprocessing.pool-to-avoid-le.patch
  * prevent-systemd-run-description-issue-when-running-a.patch
  * integration-of-msi-authentication-with-azurearm-clou.patch
  * virt.volume_infos-needs-to-ignore-inactive-pools-174.patch
  * virt-1.volume_infos-fix-for-single-vm.patch
  * add-supportconfig-module-for-remote-calls-and-saltss.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * strip-trailing-from-repo.uri-when-comparing-repos-in.patch
  * preserving-signature-in-module.run-state-u-50049.patch
  * fix-zypper-pkg.list_pkgs-expectation-and-dpkg-mockin.patch
  * fix-aptpkg-systemd-call-bsc-1143301.patch
  * calculate-fqdns-in-parallel-to-avoid-blockings-bsc-1.patch
  * remove-unnecessary-yield-causing-badyielderror-bsc-1.patch
  * debian-info_installed-compatibility-50453.patch
  * add-standalone-configuration-file-for-enabling-packa.patch
  * accumulated-changes-from-yomi-167.patch
  * add-virt.all_capabilities.patch
  * fix-memory-leak-produced-by-batch-async-find_jobs-me.patch
  * do-not-report-patches-as-installed-when-not-all-the-.patch
  * support-config-non-root-permission-issues-fixes-u-50.patch
  * add-all_versions-parameter-to-include-all-installed-.patch
  * fixes-cve-2018-15750-cve-2018-15751.patch
  * fix-bsc-1065792.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
  * avoid-traceback-when-http.query-request-cannot-be-pe.patch
  * restore-default-behaviour-of-pkg-list-return.patch
  * take-checksums-arg-into-account-for-postgres.datadir.patch
  * early-feature-support-config.patch
  * provide-the-missing-features-required-for-yomi-yet-o.patch
  * implement-network.fqdns-module-function-bsc-1134860-.patch
  * fix-virt.full_info-176.patch
  * checking-for-jid-before-returning-data.patch
  * virt.volume_infos-silence-libvirt-error-message-175.patch
  * do-not-crash-when-there-are-ipv6-established-connect.patch
  * fix-for-suse-expanded-support-detection.patch
  * fix-a-wrong-rebase-in-test_core.py-180.patch
  * add-ppc64le-as-a-valid-rpm-package-architecture.patch
  * make-profiles-a-package.patch
  * bugfix-any-unicode-string-of-length-16-will-raise-ty.patch
  * fix-git_pillar-merging-across-multiple-__env__-repos.patch
  * return-the-expected-powerpc-os-arch-bsc-1117995.patch
  * fix-async-batch-race-conditions.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
- Removed:
  * fix-syndic-start-issue.patch
  * prevent-already-reading-continuous-exception-message.patch
  * virt.pool_running-fix-pool-start.patch
  * azurefs-gracefully-handle-attributeerror.patch
  * virt-handle-whitespaces-in-vm-names.patch
  * mount-fix-extra-t-parameter.patch
  * try-except-undefineflags-as-this-operation-is-not-su.patch
* Wed Oct 30 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Remove virt.pool_delete fast parameter (U#54474)
- Added:
  * remove-virt.pool_delete-fast-parameter-178.patch
* Wed Oct 30 2019 Mihai Dincă <mihai.dinca@suse.com>
- Remove unnecessary yield causing BadYieldError (bsc#1154620)
- Added:
  * remove-unnecessary-yield-causing-badyielderror-bsc-1.patch
* Tue Oct 29 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent 'Already reading' continuous exception message (bsc#1137642)
- Added:
  * prevent-already-reading-continuous-exception-message.patch
* Fri Oct 25 2019 Jochen Breuer <jbreuer@suse.de>
- Fix for aptpkg test with older mock modules
- Added:
  * fix-for-older-mock-module.patch
* Fri Oct 25 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Remove wrong tests for core grain and improve debug logging
- Use rich RPM deps to get a compatible version of tornado into the
  buildroot.
- Added:
  * fix-a-wrong-rebase-in-test_core.py-180.patch
* Tue Oct 22 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- core.py: ignore wrong product_name files
- zypperpkg: understand product type
- Added:
  * accumulated-changes-from-yomi-167.patch
* Mon Oct 21 2019 Jochen Breuer <jbreuer@suse.de>
- Enable usage of downloadonly parameter for apt module
- Added:
  * adds-the-possibility-to-also-use-downloadonly-in-kwa.patch
* Wed Oct  9 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add missing 'fun' on events coming from salt-ssh wfunc executions (bsc#1151947)
- Added:
  * add-missing-fun-for-returns-from-wfunc-executions.patch
* Fri Oct  4 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix failing unit tests for batch async
- Added:
  * fix-failing-unit-tests-for-batch-async.patch
* Thu Oct  3 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix memory consumption problem on BatchAsync (bsc#1137642)
- Added:
  * use-current-ioloop-for-the-localclient-instance-of-b.patch
* Tue Oct  1 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix dependencies for RHEL 8
* Mon Sep 30 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent systemd-run description issue when running aptpkg (bsc#1152366)
- Added:
  * prevent-systemd-run-description-issue-when-running-a.patch
* Thu Sep 26 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Take checksums arg into account for postgres.datadir_init (bsc#1151650)
- Added:
  * take-checksums-arg-into-account-for-postgres.datadir.patch
* Thu Sep 26 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Improve batch_async to release consumed memory (bsc#1140912)
- Fix memory leak produced by batch async find_jobs mechanism (bsc#1140912)
- Grant read and execute permission to others (bsc#1150447)
- Added:
  * improve-batch_async-to-release-consumed-memory-bsc-1.patch
  * fix-memory-leak-produced-by-batch-async-find_jobs-me.patch
* Thu Sep  5 2019 Jochen Breuer <jbreuer@suse.de>
- Require shadow instead of old pwdutils (bsc#1130588)
* Wed Sep  4 2019 Jochen Breuer <jbreuer@suse.de>
- Conflict with tornado >= 5; for now we can only cope with Tornado 4.x (boo#1101780).
* Tue Sep  3 2019 Mihai Dincă <mihai.dinca@suse.com>
- Fix virt.full_info (bsc#1146382)
- virt.volume_infos: silence libvirt error message
- virt.volume_infos needs to ignore inactive pools
- Fix for various bugs in virt network and pool states
- Implement network.fqdns module function (bsc#1134860)
- Added:
  * 2019.2.0-pr-54196-backport-173.patch
  * virt.volume_infos-silence-libvirt-error-message-175.patch
  * fix-virt.full_info-176.patch
  * implement-network.fqdns-module-function-bsc-1134860-.patch
  * virt.volume_infos-needs-to-ignore-inactive-pools-174.patch
* Fri Aug 30 2019 Jochen Breuer <jbreuer@suse.de>
- Restore default behaviour of pkg list return (bsc#1148714)
- Strip trailing "/" from repo.uri when comparing repos in apktpkg.mod_repo (bsc#1146192)
- Added:
  * strip-trailing-from-repo.uri-when-comparing-repos-in.patch
  * restore-default-behaviour-of-pkg-list-return.patch
* Tue Aug 13 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Use python3 to build package Salt for RHEL8
- Make python3 default for RHEL8
* Fri Aug  9 2019 Mihai Dincă <mihai.dinca@suse.com>
- Fix aptpkg systemd call (bsc#1143301)
- Added:
  * fix-aptpkg-systemd-call-bsc-1143301.patch
* Tue Jul 30 2019 Mihai Dincă <mihai.dinca@suse.com>
- Move server_id deprecation warning to reduce log spamming (bsc#1135567) (bsc#1135732)
- Added:
  * move-server_id-deprecation-warning-to-reduce-log-spa.patch
* Tue Jul 30 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Multiple fixes on cmdmod, chroot, freezer and zypperpkg needed for Yomi
  cmdmod: fix runas and group in run_chroot
  chroot: add missing sys directory
  chroot: change variable name to root
  chroot: fix bug in safe_kwargs iteration
  freezer: do not fail in cache dir is present
  freezer: clean freeze YAML profile on restore
  zypperpkg: fix pkg.list_pkgs cache
- Added:
  * accumulated-changes-required-for-yomi-165.patch
* Mon Jul 29 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Avoid traceback on http.query when there are errors with the requested URL (bsc#1128554)
- Added:
  * avoid-traceback-when-http.query-request-cannot-be-pe.patch
* Thu Jul 25 2019 Mihai Dincă <mihai.dinca@suse.com>
- Salt python client get_full_returns seems return data from incorrect jid (bsc#1131114)
- Added:
  * checking-for-jid-before-returning-data.patch
* Wed Jul 10 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- virt.volume_infos: don't raise an error if there is no VM
- Added:
  * virt-1.volume_infos-fix-for-single-vm.patch
* Mon Jul  8 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Prevent ansiblegate unit tests to fail on Ubuntu
- Added:
  * prevent-ansiblegate-unit-tests-to-fail-on-ubuntu.patch
* Wed Jul  3 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Allow passing kwargs to pkg.list_downloaded for Zypper (bsc#1140193)
- Added:
  * allow-passing-kwargs-to-pkg.list_downloaded-bsc-1140.patch
* Fri Jun 28 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Do not make "ansiblegate" module to crash on Python3 minions (bsc#1139761)
- Added:
  * do-not-make-ansiblegate-to-crash-on-python3-minions.patch
* Thu Jun 20 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Provide the missing features required for Yomi (Yet one more installer)
- Added:
  * provide-the-missing-features-required-for-yomi-yet-o.patch
* Fri Jun 14 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Fix zypper pkg.list_pkgs test expectation and dpkg mocking
- Added:
  * fix-zypper-pkg.list_pkgs-expectation-and-dpkg-mockin.patch
* Fri Jun 14 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Set 'salt' group for files and directories created by
  salt-standalone-formulas-configuration package
- Various fixes for virt module
- Fix virt.volume_infos raising an exception when there is only virtual machine on the minion.
- Fix virt.purge() on all non-KVM hypervisors. For instance on Xen, virt.purge would simply throw an exception about unsupported flag
- Building a libvirt pool starts it. When defining a new pool, we need to
  let build start it or we will get libvirt errors.
- Fix handling of Virtual Machines with white space in their name.
- Added:
  * virt.pool_running-fix-pool-start.patch
  * virt-handle-whitespaces-in-vm-names.patch
  * virt.volume_infos-fix-for-single-vm.patch
  * try-except-undefineflags-as-this-operation-is-not-su.patch
* Wed Jun  5 2019 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- avoid batch.py exception when minion does not respond (bsc#1135507)
- Added:
  * batch.py-avoid-exception-when-minion-does-not-respon.patch
* Mon Jun  3 2019 psuarezhernandez@suse.com
- Preserve already defined DESTRUCTIVE_TESTS and EXPENSIVE_TESTS
  env variables
- Added:
  * preserve-already-defined-destructive_tests-and-expen.patch
* Wed May 29 2019 psuarezhernandez@suse.com
- Do not break repo files with multiple line values on yumpkg (bsc#1135360)
- Added:
  * do-not-break-repo-files-with-multiple-line-values-on.patch
* Fri May 24 2019 psuarezhernandez@suse.com
- Fix return status when installing or updating RPM packages
  with "ppc64le" arch (bsc#1133647)
- Added:
  * add-ppc64le-as-a-valid-rpm-package-architecture.patch
* Thu May 23 2019 psuarezhernandez@suse.com
- Add new "salt-standalone-formulas-configuration" package (fate#327791)
- Added:
  * add-standalone-configuration-file-for-enabling-packa.patch
* Mon May 20 2019 psuarezhernandez@suse.com
- Switch firewalld state to use change_interface (bsc#1132076)
- Added:
  * switch-firewalld-state-to-use-change_interface.patch
* Wed May  8 2019 Mihai Dincă <mihai.dinca@suse.com>
- Fix async-batch to fire a single done event
- Added:
  * fix-async-batch-multiple-done-events.patch
* Tue May  7 2019 psuarezhernandez@suse.com
- Do not make Salt CLI to crash when there are IPv6 established
  connections (bsc#1130784)
- Added:
  * do-not-crash-when-there-are-ipv6-established-connect.patch
* Fri May  3 2019 mdinca <mdinca@suse.de>
- Include aliases in FQDNS grain (bsc#1121439)
* Thu May  2 2019 mdinca <mdinca@suse.de>
- Fix issue preventing syndic to start
- Update year on spec copyright notice
- Added:
  * fix-syndic-start-issue.patch
* Tue Apr 30 2019 psuarezhernandez@suse.com
- Use ThreadPool from multiprocessing.pool to avoid leakings
  when calculating FQDNs
- Do not report patches as installed on RHEL systems when not all
  the related packages are installed (bsc#1128061)
- Added:
  * use-threadpool-from-multiprocessing.pool-to-avoid-le.patch
  * do-not-report-patches-as-installed-when-not-all-the-.patch
* Fri Apr 26 2019 mdinca@suse.de
- Update to 2019.2.0 complete (FATE#327138, bsc#1133523)
- Fix batch/batch-async related issues
- Calculate FQDNs in parallel to avoid blockings (bsc#1129079)
- Incorporate virt.volume_info fixes (PR#131)
- Re-adds patch because of increased offset due to previous patch removal
- Removing patch to add root parameter to zypper module
- Fix for -t parameter in mount module
- Added:
  * mount-fix-extra-t-parameter.patch
  * add-batch_presence_ping_timeout-and-batch_presence_p.patch
  * fix-async-batch-race-conditions.patch
  * calculate-fqdns-in-parallel-to-avoid-blockings-bsc-1.patch
- Modified:
  * don-t-call-zypper-with-more-than-one-no-refresh.patch
  * add-virt.volume_infos-and-virt.volume_delete.patch
- Removed:
  * zypper-add-root-configuration-parameter.patch
* Thu Feb 28 2019 Jochen Breuer <jbreuer@suse.de>
- No longer limiting Python3 version to <3.7
* Thu Feb 28 2019 Jochen Breuer <jbreuer@suse.de>
- Async batch implementation
- Added:
  * async-batch-implementation.patch
* Wed Feb 27 2019 jbreuer@suse.de
- Update to Salt 2019.2.0 release
  For further information see:
  https://docs.saltstack.com/en/latest/topics/releases/2019.2.0.html
- Added:
  * add-virt.all_capabilities.patch
  * add-virt.volume_infos-and-virt.volume_delete.patch
  * don-t-call-zypper-with-more-than-one-no-refresh.patch
  * include-aliases-in-the-fqdns-grains.patch
  * temporary-fix-extend-the-whitelist-of-allowed-comman.patch
- Removed:
  * accounting-for-when-files-in-an-archive-contain-non-.patch
  * add-engine-relaying-libvirt-events.patch
  * add-other-attribute-to-gecos-fields-to-avoid-inconsi.patch
  * add-support-for-python-3.7.patch
  * align-suse-salt-master.service-limitnofiles-limit-wi.patch
  * avoid-incomprehensive-message-if-crashes.patch
  * change-stringio-import-in-python2-to-import-the-clas.patch
  * decode-file-contents-for-python2-bsc-1102013.patch
  * do-not-override-jid-on-returners-only-sending-back-t.patch
  * don-t-error-on-retcode-0-in-libcrypto.openssl_init_c.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-async-call-to-process-manager.patch
  * fix-decrease-loglevel-when-unable-to-resolve-addr.patch
  * fix-deprecation-warning-bsc-1095507.patch
  * fix-diffing-binary-files-in-file.get_diff-bsc-109839.patch
  * fix-for-ec2-rate-limit-failures.patch
  * fix-for-errno-0-resolver-error-0-no-error-bsc-108758.patch
  * fix-for-sorting-of-multi-version-packages-bsc-109717.patch
  * fix-index-error-when-running-on-python-3.patch
  * fix-latin1-encoding-problems-on-file-module-bsc-1116.patch
  * fix-mine.get-not-returning-data-workaround-for-48020.patch
  * fix-unboundlocalerror-in-file.get_diff.patch
  * fixed-usage-of-ipaddress.patch
  * fixing-issue-when-a-valid-token-is-generated-even-wh.patch
  * get-os_family-for-rpm-distros-from-the-rpm-macros.-u.patch
  * improved-handling-of-ldap-group-id.patch
  * only-do-reverse-dns-lookup-on-ips-for-salt-ssh.patch
  * option-to-merge-current-pillar-with-opts-pillar-duri.patch
  * prepend-current-directory-when-path-is-just-filename.patch
  * prevent-zypper-from-parsing-repo-configuration-from-.patch
  * remove-old-hack-when-reporting-multiversion-packages.patch
  * retire-md5-checksum-for-pkg-mgmt-plugins.patch
  * show-recommendations-for-salt-ssh-cross-version-pyth.patch
  * strip-trailing-commas-on-linux-user-gecos-fields.patch
  * support-use-of-gce-instance-credentials-109.patch
  * update-error-list-for-zypper.patch
  * x509-fixes-for-remote-signing-106.patch
- Modified:
  * add-all_versions-parameter-to-include-all-installed-.patch
  * add-cpe_name-for-osversion-grain-parsing-u-49946.patch
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * add-hold-unhold-functions.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
  * azurefs-gracefully-handle-attributeerror.patch
  * bugfix-any-unicode-string-of-length-16-will-raise-ty.patch
  * debian-info_installed-compatibility-50453.patch
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
  * fall-back-to-pymysql.patch
  * fix-for-suse-expanded-support-detection.patch
  * fix-git_pillar-merging-across-multiple-__env__-repos.patch
  * fix-ipv6-scope-bsc-1108557.patch
  * fix-issue-2068-test.patch
  * fix-zypper.list_pkgs-to-be-aligned-with-pkg-state.patch
  * fixes-cve-2018-15750-cve-2018-15751.patch
  * get-os_arch-also-without-rpm-package-installed.patch
  * integration-of-msi-authentication-with-azurearm-clou.patch
  * loosen-azure-sdk-dependencies-in-azurearm-cloud-driv.patch
  * remove-arch-from-name-when-pkg.list_pkgs-is-called-w.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
  * x509-fixes-111.patch
  * zypper-add-root-configuration-parameter.patch
* Wed Jan 23 2019 bo@suse.de
- Add root parameter to Zypper module
- Added:
  * zypper-add-root-configuration-parameter.patch
* Wed Jan 16 2019 psuarezhernandez@suse.com
- Do not restrict the Python version to < 3.7
* Tue Jan 15 2019 bo@suse.de
- Fix integration tests in state compiler (U#2068)
- Added:
  * fix-issue-2068-test.patch
* Fri Jan 11 2019 psuarezhernandez@suse.com
- Fix "pkg.list_pkgs" output when using "attr" to take the arch into account (bsc#1114029)
- Added:
  * remove-arch-from-name-when-pkg.list_pkgs-is-called-w.patch
* Thu Jan 10 2019 mdinca <mdinca@suse.de>
- Fix powerpc null server_id_arch (bsc#1117995)
- Added:
  * return-the-expected-powerpc-os-arch-bsc-1117995.patch
* Thu Jan 10 2019 bo@suse.de
- Fix module 'azure.storage' has no attribute '__version__'
  (bsc#1121091)
- Added:
  * azurefs-gracefully-handle-attributeerror.patch
* Fri Jan  4 2019 bo@suse.de
- Add supportconfig module and states for minions and SaltSSH
- Added:
  * add-supportconfig-module-for-remote-calls-and-saltss.patch
* Thu Jan  3 2019 bo@suse.de
- Fix FIPS enabled RES clients (bsc#1099887)
- Added:
  * retire-md5-checksum-for-pkg-mgmt-plugins.patch
* Thu Jan  3 2019 bo@suse.de
- Add hold/unhold functions. Fix Debian repo "signed-by".
- Added:
  * decide-if-the-source-should-be-actually-skipped.patch
  * add-hold-unhold-functions.patch
* Tue Dec  4 2018 psuarezhernandez@suse.com
- Fix latin1 encoding problems on file module (bsc#1116837)
- Added:
  * fix-latin1-encoding-problems-on-file-module-bsc-1116.patch
* Fri Nov 30 2018 bo@suse.de
- Don't error on retcode 0 in libcrypto.OPENSSL_init_crypto
- Added:
  * don-t-error-on-retcode-0-in-libcrypto.openssl_init_c.patch
* Tue Nov 20 2018 bo@suse.de
- Debian info_installed compatibility (U#50453)
- Added:
  * debian-info_installed-compatibility-50453.patch
* Fri Nov 16 2018 bo@suse.de
- Add compatibility with other package modules for "list_repos" function
- Bugfix: unable to detect os arch when RPM is not installed (bsc#1114197)
- Added:
  * make-aptpkg.list_repos-compatible-on-enabled-disable.patch
  * get-os_arch-also-without-rpm-package-installed.patch
* Thu Nov  8 2018 psuarezhernandez@suse.com
- Fix git_pillar merging across multiple __env__ repositories (bsc#1112874)
- Added:
  * fix-git_pillar-merging-across-multiple-__env__-repos.patch
* Wed Oct 31 2018 bo@suse.de
- Fix LDAP authentication issue when a valid token is generated
  by the salt-api even when invalid user credentials are passed.
  (U#48901)
- Added:
  * fixing-issue-when-a-valid-token-is-generated-even-wh.patch
* Tue Oct 30 2018 Jochen Breuer <jbreuer@suse.de>
- Improved handling of LDAP group id. gid is no longer treated as a
  string, which could have lead to faulty group creations. (bsc#1113784)
- Added:
  * improved-handling-of-ldap-group-id.patch
* Thu Oct 25 2018 psuarezhernandez@suse.com
- Fix remote command execution and incorrect access control
  when using salt-api. (bsc#1113699) (CVE-2018-15751)
- Fix Directory traversal vulnerability when using salt-api.
  Allows an attacker to determine what files exist on
  a server when querying /run or /events. (bsc#1113698) (CVE-2018-15750)
- Added:
  * fixes-cve-2018-15750-cve-2018-15751.patch
* Thu Oct 18 2018 bo@suse.de
- Add multi-file support and globbing to the filetree (U#50018)
- Added:
  * add-multi-file-support-and-globbing-to-the-filetree-.patch
* Wed Oct 17 2018 bo@suse.de
- Bugfix: supportconfig non-root permission issues (U#50095)
- Added:
  * support-config-non-root-permission-issues-fixes-u-50.patch
* Wed Oct 17 2018 bo@suse.de
- Open profiles permissions to everyone for read-only
* Tue Oct 16 2018 bo@suse.de
- Preserving signature in "module.run" state (U#50049)
- Added:
  * preserving-signature-in-module.run-state-u-50049.patch
* Fri Oct 12 2018 bo@suse.de
- Install default salt-support profiles
* Thu Oct 11 2018 bo@suse.de
- Fix unit tests due to merger failure
- Add CPE_NAME for osversion* grain parsing
- Get os_family for RPM distros from the RPM macros
- Install support profiles
- Added:
  * get-os_family-for-rpm-distros-from-the-rpm-macros.-u.patch
  * add-cpe_name-for-osversion-grain-parsing-u-49946.patch
  * make-profiles-a-package.patch
  * fix-unit-test-for-grains-core.patch
* Tue Oct  9 2018 psuarezhernandez@suse.com
- Bugfix: any unicode string of length 16 will raise TypeError
- Added:
  * bugfix-any-unicode-string-of-length-16-will-raise-ty.patch
* Mon Oct  8 2018 psuarezhernandez@suse.com
- Fix async call to process manager (bsc#1110938)
- Early feature: Salt support-config (salt-support)
- Added:
  * fix-async-call-to-process-manager.patch
  * early-feature-support-config.patch
* Mon Oct  1 2018 bo@suse.de
- Fix IPv6 scope (bsc#1108557)
- Added:
  * fix-ipv6-scope-bsc-1108557.patch
* Fri Sep 28 2018 bo@suse.de
- Handle zypper ZYPPER_EXIT_NO_REPOS exit code (bsc#1108834, bsc#1109893)
- Added:
  * update-error-list-for-zypper.patch
* Mon Sep 24 2018 bo@suse.de
- Bugfix for pkg_resources crash (bsc#1104491)
- Added:
  * do-not-load-pip-state-if-there-is-no-3rd-party-depen.patch
* Fri Sep 21 2018 psuarezhernandez@suse.com
- Fix loosen azure sdk dependencies in azurearm cloud driver (bsc#1107333)
- Added:
  * loosen-azure-sdk-dependencies-in-azurearm-cloud-driv.patch
* Thu Sep 20 2018 psuarezhernandez@suse.com
- Fix broken "resolve_capabilities" on Python 3 (bsc#1108995)
- Added:
  * fix-index-error-when-running-on-python-3.patch
* Wed Sep 19 2018 psuarezhernandez@suse.com
- Allow empty service_account_private_key in GCE driver (bsc#1108969)
- Added:
  * support-use-of-gce-instance-credentials-109.patch
* Tue Sep 18 2018 mihai.dinca@suse.com
- Decode file contents for python2 (bsc#1103530)
- Check dmidecoder executable on each "smbios" call to avoid race condition (bsc#1101880)
- Fix pkg.upgrade reports when dealing with multiversion packages (bsc#1102265)
- Accounting for when files in an archive contain non-ascii characters (bsc#1099460)
- Fix deprecation warning (bsc#1095507)
- Fix (bsc#1065792)
- Fix (bsc#108758)
- Handle packages with multiple version properly with zypper (bsc#1096514)
- Fix file.get_diff regression in 2018.3 (bsc#1098394)
- Provide python version mismatch solutions (bsc#1072599)
- Fix file.managed binary file utf8 error (bsc#1098394)
- Prevent zypper from parsing repo configuration from not .repo files (bsc#1094055)
- Add environment variable to know if yum is invoked from Salt (bsc#1057635)
- Prevent deprecation warning with salt-ssh (bsc#1095507)
- Align SUSE salt-master.service 'LimitNOFILES' limit with upstream Salt
- Add 'other' attribute to GECOS fields to avoid inconsistencies with chfn
- Collect all versions of installed packages on SUSE and RHEL systems (bsc#1089526)
* Mon Sep 17 2018 bo@suse.de
- Prepend current directory when path is just filename (bsc#1095942)
- Integration of MSI authentication for azurearm
- Adds fix for SUSE Expanded Support os grain detection
- Fixes 509x remote signing
- Fix for StringIO import in Python2
- Use Adler32 algorithm to compute string checksums (bsc#1102819)
- Only do reverse DNS lookup on IPs for salt-ssh (bsc#1104154)
- Add support for Python 3.7
- Fix license macro to build on SLE12SP2
- Decode file contents for python2 (bsc#1102013)
- Fix for sorting of multi-version packages (bsc#1097174 and bsc#1097413)
- Fix mine.get not returning data - workaround for #48020 (bsc#1100142)
- Added:
  * change-stringio-import-in-python2-to-import-the-clas.patch
  * integration-of-msi-authentication-with-azurearm-clou.patch
  * x509-fixes-for-remote-signing-106.patch
  * fix-for-suse-expanded-support-detection.patch
  * only-do-reverse-dns-lookup-on-ips-for-salt-ssh.patch
  * prepend-current-directory-when-path-is-just-filename.patch
  * add-support-for-python-3.7.patch
  * decode-file-contents-for-python2-bsc-1102013.patch
  * fix-mine.get-not-returning-data-workaround-for-48020.patch
  * x509-fixes-111.patch
  * use-adler32-algorithm-to-compute-string-checksums.patch
- Modified:
  * fix-for-sorting-of-multi-version-packages-bsc-109717.patch
* Mon Jul 30 2018 mihai.dinca@suse.com
- Update to 2018.3.2
  See https://docs.saltstack.com/en/latest/topics/releases/2018.3.2.html
  for full changelog
- Added:
  * accounting-for-when-files-in-an-archive-contain-non-.patch
  * add-all_versions-parameter-to-include-all-installed-.patch
  * add-custom-suse-capabilities-as-grains.patch
  * add-engine-relaying-libvirt-events.patch
  * add-environment-variable-to-know-if-yum-is-invoked-f.patch
  * add-other-attribute-to-gecos-fields-to-avoid-inconsi.patch
  * align-suse-salt-master.service-limitnofiles-limit-wi.patch
  * avoid-incomprehensive-message-if-crashes.patch
  * fix-deprecation-warning-bsc-1095507.patch
  * fix-diffing-binary-files-in-file.get_diff-bsc-109839.patch
  * fix-unboundlocalerror-in-file.get_diff.patch
  * fix-zypper.list_pkgs-to-be-aligned-with-pkg-state.patch
  * prevent-zypper-from-parsing-repo-configuration-from-.patch
  * remove-old-hack-when-reporting-multiversion-packages.patch
  * show-recommendations-for-salt-ssh-cross-version-pyth.patch
- Modified:
  * activate-all-beacons-sources-config-pillar-grains.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * do-not-override-jid-on-returners-only-sending-back-t.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
  * fall-back-to-pymysql.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-bsc-1065792.patch
  * fix-decrease-loglevel-when-unable-to-resolve-addr.patch
  * fix-for-ec2-rate-limit-failures.patch
  * fix-for-errno-0-resolver-error-0-no-error-bsc-108758.patch
  * fixed-usage-of-ipaddress.patch
  * option-to-merge-current-pillar-with-opts-pillar-duri.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * strip-trailing-commas-on-linux-user-gecos-fields.patch
- Deleted:
  * explore-module.run-response-to-catch-the-result-in-d.patch
  * extra-filerefs-include-files-even-if-no-refs-in-stat.patch
  * fix-cp.push-empty-file.patch
  * fix-for-sorting-of-multi-version-packages-bsc-109717.patch
  * fix-openscap-push.patch
  * initialize-__context__-retcode-for-functions-handled.patch
  * make-it-possible-to-use-login-pull-and-push-from-mod.patch
  * move-log_file-option-to-changeable-defaults.patch
  * provide-kwargs-to-pkg_resource.parse_targets-require.patch
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
* Thu May 17 2018 jbreuer@suse.de
- Documentation refresh to 2018.3.0
* Wed May 16 2018 jbreuer@suse.de
- No more AWS EC2 rate limitations in salt-cloud (bsc#1088888)
- MySQL returner now also allows to use Unix sockets (bsc#1091371)
- Added:
  * fix-for-ec2-rate-limit-failures.patch
  * enable-passing-a-unix_socket-for-mysql-returners-bsc.patch
* Thu May 10 2018 psuarezhernandez@suse.com
- Do not override jid on returners, only sending back to master (bsc#1092373)
- Fixes for salt-ssh:
  - Option --extra-filerefs doesn't add all files to the state
    archive
  - Pillar completely overwritten (not merged) when doing
    module.run + state.apply with pillar in kwargs
- Remove minion/thin/version if exists to force thin regeneration (bsc#1092161)
- Added:
  * extra-filerefs-include-files-even-if-no-refs-in-stat.patch
  * do-not-override-jid-on-returners-only-sending-back-t.patch
  * option-to-merge-current-pillar-with-opts-pillar-duri.patch
* Fri May  4 2018 jbreuer@suse.de
- Fixed Python 3 issue with CIDR addresses.
- Added:
  * fixed-usage-of-ipaddress.patch
* Wed Apr 25 2018 psuarezhernandez@suse.com
- Fix minion scheduler to return a 'retcode' attribute (bsc#1089112)
- Fix for logging during network interface querying (bsc#1087581)
- Fix rhel packages requires both net-tools and iproute (bsc#1087055)
- Added:
  * initialize-__context__-retcode-for-functions-handled.patch
- Modified:
  * fix-for-errno-0-resolver-error-0-no-error-bsc-108758.patch
* Wed Apr 18 2018 psuarezhernandez@suse.com
- Fix patchinstall on yum module. Bad comparison (bsc#1087278)
- Added:
  * provide-kwargs-to-pkg_resource.parse_targets-require.patch
* Wed Apr 18 2018 psuarezhernandez@suse.com
- Strip trailing commas on Linux user's GECOS fields (bsc#1089362)
- Fallback to PyMySQL (bsc#1087891)
- Improved test for fqdns
- Update SaltSSH patch
- Fix for [Errno 0] Resolver Error 0 (no error) (bsc#1087581)
  * Lintfix: PEP8 ident
  * Use proper levels of the error handling, use proper log formatting.
  * Fix unit test for reversed fqdns return data
- Added:
  * strip-trailing-commas-on-linux-user-gecos-fields.patch
  * fall-back-to-pymysql.patch
  * fix-for-errno-0-resolver-error-0-no-error-bsc-108758.patch
- Modified:
  * add-saltssh-multi-version-support-across-python-inte.patch
* Fri Apr  6 2018 mdinca@suse.de
- Update to 2018.3.0
- Modified:
  * explore-module.run-response-to-catch-the-result-in-d.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * fix-openscap-push.patch
  * fix-decrease-loglevel-when-unable-to-resolve-addr.patch
  * fix-cp.push-empty-file.patch
  * make-it-possible-to-use-login-pull-and-push-from-mod.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-bsc-1065792.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * move-log_file-option-to-changeable-defaults.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
* Thu Apr  5 2018 mdinca@suse.de
- Add python-2.6 support to salt-ssh
- Modified:
  * add-saltssh-multi-version-support-across-python-inte.patch
* Wed Apr  4 2018 mdinca@suse.de
- Update salt-ssh multiversion patch
- Modified:
  * add-saltssh-multi-version-support-across-python-inte.patch
- Removed:
  * require-same-major-version-while-minor-is-allowed-to.patch
* Wed Mar 28 2018 mdinca@suse.de
- Add iprout/net-tools dependency
* Wed Mar 28 2018 mc@suse.de
- salt-ssh: require same major version while minor is allowed to be
- Added:
  * require-same-major-version-while-minor-is-allowed-to.patch
- Modified:
  * explore-module.run-response-to-catch-the-result-in-d.patch
  * add-saltssh-multi-version-support-across-python-inte.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * fix-openscap-push.patch
  * fix-decrease-loglevel-when-unable-to-resolve-addr.patch
  * fix-cp.push-empty-file.patch
  * make-it-possible-to-use-login-pull-and-push-from-mod.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-bsc-1065792.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * move-log_file-option-to-changeable-defaults.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
* Tue Mar 27 2018 mdinca@suse.de
- Add SaltSSH multi-version support across Python interpeters.
- Added:
  * add-saltssh-multi-version-support-across-python-inte.patch
* Fri Mar 23 2018 mdinca@suse.de
- Fix zypper.info_installed 'ascii' issue
- Modified:
  * explore-module.run-response-to-catch-the-result-in-d.patch
  * fix-openscap-push.patch
  * fix-decrease-loglevel-when-unable-to-resolve-addr.patch
  * fix-cp.push-empty-file.patch
  * make-it-possible-to-use-login-pull-and-push-from-mod.patch
  * move-log_file-option-to-changeable-defaults.patch
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
* Fri Mar 23 2018 mdinca@suse.de
- Update openscap push patch to include the test fixes
- Modified:
  * explore-module.run-response-to-catch-the-result-in-d.patch
  * fix-openscap-push.patch
  * fix-decrease-loglevel-when-unable-to-resolve-addr.patch
  * fix-cp.push-empty-file.patch
  * make-it-possible-to-use-login-pull-and-push-from-mod.patch
  * move-log_file-option-to-changeable-defaults.patch
* Thu Mar 22 2018 psuarezhernandez@suse.com
- Explore 'module.run' state module output in depth to catch "result" properly
- Added:
  * explore-module.run-response-to-catch-the-result-in-d.patch
* Thu Mar 22 2018 mc@suse.de
- make it possible to use docker login, pull and push from module.run and detect errors
- Added:
  * make-it-possible-to-use-login-pull-and-push-from-mod.patch
* Tue Mar 20 2018 michele.bologna@suse.com
- Fix logging with FQDNs
- Added:
  * fix-decrease-loglevel-when-unable-to-resolve-addr.patch
* Wed Mar 14 2018 mdinca@suse.de
- Update patches
- Modified:
  * run-salt-master-as-dedicated-salt-user.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * fix-openscap-push.patch
  * fix-cp.push-empty-file.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-bsc-1065792.patch
  * move-log_file-option-to-changeable-defaults.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
- Removed:
  * salt-ssh-fix-json-load-of-return-data-when-it-contai.patch
* Tue Mar 13 2018 mdinca@suse.de
- Update cp.push patch
- Modified:
  * fix-cp.push-empty-file.patch
  * salt-ssh-fix-json-load-of-return-data-when-it-contai.patch
* Mon Mar 12 2018 mc@suse.de
- force re-generate a new thin.tgz when an update gets installed
* Sat Mar 10 2018 mc@suse.de
- fix salt-ssh with a different patch
- remove: dumps-should-return-unicode-also-with-py2-to-prevent.patch
- added: salt-ssh-fix-json-load-of-return-data-when-it-contai.patch
- Added:
  * salt-ssh-fix-json-load-of-return-data-when-it-contai.patch
- Removed:
  * dumps-should-return-unicode-also-with-py2-to-prevent.patch
* Fri Mar  9 2018 mdinca@suse.de
- Fix unicode decode error with salt-ssh
- Added:
  * dumps-should-return-unicode-also-with-py2-to-prevent.patch
- Modified:
  * run-salt-master-as-dedicated-salt-user.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * fix-openscap-push.patch
  * fix-cp.push-empty-file.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-bsc-1065792.patch
  * move-log_file-option-to-changeable-defaults.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
* Thu Mar  8 2018 mdinca@suse.de
- Fix cp.push empty file (bsc#1075950)
- salt-ssh - move log_file option to changeable defaults
- Added:
  * fix-cp.push-empty-file.patch
  * move-log_file-option-to-changeable-defaults.patch
- Modified:
  * run-salt-master-as-dedicated-salt-user.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * fix-openscap-push.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-bsc-1065792.patch
  * activate-all-beacons-sources-config-pillar-grains.patch
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
* Fri Mar  2 2018 mdinca@suse.de
- Daily update
- Added:
  * fix-openscap-push.patch
- Removed:
  * fix-grains-with-n.patch
* Fri Mar  2 2018 mdinca@suse.de
- Fix grains containing trailing "\n"
- Added:
  * fix-grains-with-n.patch
* Tue Feb 20 2018 mdinca@suse.de
- Remove salt-minion python2 requirement when python3 is default (bsc#1081592)
* Tue Feb 13 2018 mdinca@suse.de
- Remove-obsolete-unicode-handling-in-pkg.info_installed
- Added:
  * remove-obsolete-unicode-handling-in-pkg.info_install.patch
* Fri Feb  9 2018 mdinca@suse.de
- Update to salt-2018.1.99
- Modified:
  * activate-all-beacons-sources-config-pillar-grains.patch
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * feat-add-grain-for-all-fqdns.patch
  * fix-bsc-1065792.patch
  * list_pkgs-add-parameter-for-returned-attribute-selec.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
  * run-salt-master-as-dedicated-salt-user.patch
- Deleted:
  * python3-compatibility-fix-got-bytes-instead-of-strin.patch
  * enable-with-salt-version-parameter-for-setup.py-scri.patch
  * catching-error-when-pidfile-cannot-be-deleted.patch
  * bugfix-always-return-a-string-list-on-unknown-job-ta.patch
  * bugfix-the-logic-according-to-the-exact-described-pu.patch
  * cherrypy-read-reads-bytes-from-the-wire-and-write-th.patch
  * fix-for-delete_deployment-in-kubernetes-module.patch
  * fix-salt-master-for-old-psutil.patch
  * introduce-process_count_max-minion-configuration-par.patch
  * multiprocessing-minion-option-documentation-fixes.patch
  * older-logrotate-need-su-directive.patch
  * return-error-when-gid_from_name-and-group-does-not-e.patch
  * set-shell-environment-variable-64.patch
  * split-only-strings-if-they-are-such.patch
  * use-home-to-get-the-user-home-directory-instead-usin.patch
  * yumpkg-don-t-use-diff_attr-when-determining-install-.patch
* Fri Feb  9 2018 jbreuer@suse.de
- Fix-epoch-handling-for-Rhel-6-and-7
- Modified:
  * yumpkg-don-t-use-diff_attr-when-determining-install-.patch
- Removed:
  * fix-for-wrong-version-processing.patch
* Fri Feb  9 2018 jbreuer@suse.de
- Restoring-installation-of-packages-for-Rhel-6-7
  Added:
  * yumpkg-don-t-use-diff_attr-when-determining-install-.patch
* Wed Feb  7 2018 mdinca@suse.de
- Prevent queryformat pattern from expanding (bsc#1079048)
* Thu Feb  1 2018 jbreuer@suse.de
- Fix epoch handling for Rhel 6 and 7 (bsc#1068566)
- Reverting to current API for split_input
- Added:
  * yumpkg-don-t-use-diff_attr-when-determining-install-.patch
- Removed:
  * fix-for-wrong-version-processing.patch
* Fri Jan 26 2018 pablo.suarezhernandez@suse.com
- Fix for wrong version processing during yum pkg install (bsc#1068566)
- Feat: add grain for all FQDNs (bsc#1063419)
- Added:
  * fix-for-wrong-version-processing.patch
  * feat-add-grain-for-all-fqdns.patch
* Thu Jan 25 2018 pablo.suarezhernandez@suse.com
- Fix the usage of custom macros on the spec file.
* Thu Jan 25 2018 bmaryniuk@suse.com
- Fix RES7: different dependency names for python-PyYAML
  and python-MarkupSafe
* Wed Jan 24 2018 bmaryniuk@suse.com
- Build both python2 and python3 binaries together.
* Wed Jan 17 2018 pablo.suarezhernandez@suse.com
- Bugfix: errors in external pillar causes crash instead of report
  of them (bsc#1068446)
- Fix 'user.present' when 'gid_from_name' is set but group does
  not exist.
- Added:
  * bugfix-the-logic-according-to-the-exact-described-pu.patch
  * return-error-when-gid_from_name-and-group-does-not-e.patch
* Thu Jan 11 2018 jrenner@suse.com
- Fix "No service execution module loaded" issue (bsc#1065792)
- Set SHELL environment variable
  Added:
  * fix-bsc-1065792.patch
  * set-shell-environment-variable-64.patch
* Fri Jan  5 2018 jbreuer@suse.de
- Removed unnecessary logging on shutdown (bsc#1050003)
- Renamed patch that adds grain fqdns
  Changed:
  * catching-error-when-pidfile-cannot-be-deleted
  Removed:
  * fix-for-pidfile-removal-logging
  Renamed:
  * add-fqdns-grains -> feat-add-grain-for-all-fqdns
* Thu Dec 28 2017 michele.bologna@suse.com
- Add fqdns to grains (bsc#1063419)
  Added:
  * add-fqdns-grains.patch
* Tue Dec 19 2017 mc@suse.com
- Fixing cherrypy websocket with python3
  Added:
  * python3-compatibility-fix-got-bytes-instead-of-strin.patch
* Mon Dec 18 2017 mihai.dinca@suse.com
- Various-bug-fixes
- Python3 bugfix for cherrypy read()
- Fix for logging on salt-master exit in rare cases (pid-file removal)
- Added:
  * cherrypy-read-reads-bytes-from-the-wire-and-write-th.patch
  * fix-for-pidfile-removal-logging.patch
  * split-only-strings-if-they-are-such.patch
* Thu Dec 14 2017 mihai.dinca@suse.com
- Fix salt-master for old psutil version
- Added:
  * fix-salt-master-for-old-psutil.patch
* Wed Dec 13 2017 mihai.dinca@suse.com
- Put back accidentally removed patches
- Added:
  * avoid-excessive-syslogging-by-watchdog-cronjob-58.patch
  * catching-error-when-pidfile-cannot-be-deleted.patch
* Wed Dec 13 2017 mihai.dinca@suse.com
- Fix for delete_deployment in Kubernetes module (bsc#1059291)
- Added:
  * fix-for-delete_deployment-in-kubernetes-module.patch
* Wed Dec 13 2017 mihai.dinca@suse.com
- Older logrotate need su directive (bsc#1071322)
  * Added:
    older-logrotate-need-su-directive.patch
* Wed Dec 13 2017 mihai.dinca@suse.com
- Fix bsc#1041993 already included in 2017.7.2
- Removed:
  * removes-beacon-configuration-deprecation-warning-48.patch
* Wed Dec 13 2017 mihai.dinca@suse.com
- Fixed beacons failure when pillar-based suppressing config-based.
  (bsc#1060230)
- Added:
  * activate-all-beacons-sources-config-pillar-grains.patch
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Fri Dec  1 2017 mihai.dinca@suse.com
- Fix wrong version reported by Salt (bsc#1061407)
- Fix CVE-2017-14696 (bsc#1062464) already included in 2017.7.2
* Mon Nov 27 2017 mihai.dinca@suse.com
- Run salt master as dedicated salt user
- Run salt-api as user salt (bsc#1064520)
- Added:
  * run-salt-master-as-dedicated-salt-user.patch
  * run-salt-api-as-user-salt-bsc-1064520.patch
* Thu Nov  9 2017 mdinca@suse.de
- Update to 2017.7.2
  See https://docs.saltstack.com/en/latest/topics/releases/2017.7.2.html
- Added:
  * enable-with-salt-version-parameter-for-setup.py-scri.patch
- Removed:
  * add-a-salt-minion-service-control-file.patch
  * add-clean_id-function-to-salt.utils.verify.py.patch
  * add-options-for-dockerng.patch
  * add-ssh-option-to-salt-ssh.patch
  * add-unit-test-for-skip-false-values-from-preferred_i.patch
  * add-yum-plugin.patch
  * add-zypp-notify-plugin.patch
  * adding-salt-minion-watchdog-for-sysv-systems-rhel6-a.patch
  * adding-support-for-installing-patches-in-yum-dnf-exe.patch
  * avoid-failures-on-sles-12-sp2-because-of-new-systemd.patch
  * bugfix-jobs-scheduled-to-run-at-a-future-time-stay-p.patch
  * bugfix-unable-to-use-127-as-hostname.patch
  * catching-error-when-pidfile-cannot-be-deleted.patch
  * change-travis-configuration-file-to-use-salt-toaster.patch
  * check-if-byte-strings-are-properly-encoded-in-utf-8.patch
  * clean-up-change-attribute-from-interface-dict.patch
  * do-not-generate-a-date-in-a-comment-to-prevent-rebui.patch
  * enables-salt-minion-watchdog-on-init.d-script-for-sy.patch
  * escape-the-os.sep.patch
  * fix-for-delete_deployment-in-kubernetes-module.patch
  * fix-format-error-bsc-1043111.patch
  * fix-grain-for-os_family-on-suse-series.patch
  * fix-os_family-case-in-unittest.patch
  * fix-regression-in-file.get_managed-add-unit-tests.patch
  * fix-salt-summary-to-count-not-responding-minions-cor.patch
  * fix-setting-language-on-suse-systems.patch
  * fixed-issue-with-parsing-of-master-minion-returns-wh.patch
  * fixing-beacons.list-integration-test-failure.patch
  * introducing-the-kubernetes-module.patch
  * notify-systemd-synchronously-bsc-1053376.patch
  * rest_cherrypy-remove-sleep-call.patch
  * revert-we-don-t-have-python-systemd-so-notify-can-t-.patch
  * run-salt-api-as-user-salt-bsc-990029.patch
  * run-salt-master-as-dedicated-salt-user.patch
  * search-the-entire-cache_dir-because-storage-paths-ch.patch
  * security-fixes-cve-2017-14695-and-cve-2017-14696.patch
  * setting-up-os-grains-for-sles-expanded-support-suse-.patch
  * special-salt-minion.service-file-for-rhel7.patch
  * translate-variable-arguments-if-they-contain-hidden-.patch
  * tserong-suse.com-we-don-t-have-python-systemd-so-not.patch
  * use-correct-grain-constants-for-timezone.patch
* Wed Oct 11 2017 jbreuer@suse.de
- Re-added previously removed unit-test for bsc#1050003
- Changed:
  * catching-error-when-pidfile-cannot-be-deleted.patch
* Wed Oct 11 2017 bmaryniuk@suse.com
- Fixes for CVE-2017-14695 and CVE-2017-14696 (bsc#1062462)
- Added:
  * security-fixes-cve-2017-14695-and-cve-2017-14696.patch
* Tue Oct 10 2017 bmaryniuk@suse.com
- Add missing follow-up for CVE-2017-12791 (bsc#1053955)
- Fixed salt target-type field returns "String" for existing jids
  but an empty "Array" for non existing jids. (issue#1711)
- Added:
  * bugfix-always-return-a-string-list-on-unknown-job-ta.patch
  * escape-the-os.sep.patch
* Mon Oct  9 2017 bmaryniuk@suse.com
- Fixed minion resource exhaustion when many functions are being
  executed in parallel (bsc#1059758)
- Changed:
  * catching-error-when-pidfile-cannot-be-deleted.patch
- Added:
  * introduce-process_count_max-minion-configuration-par.patch
  * multiprocessing-minion-option-documentation-fixes.patch
  * revert-we-don-t-have-python-systemd-so-notify-can-t-.patch
- Removed:
  * revert-we-don-t-have-python-systemd-so-notify-can-t-work.patch
* Thu Oct  5 2017 pablo.suarezhernandez@suse.com
- Remove 'TasksTask' attribute from salt-master.service in older
  versions of systemd (bsc#985112)
* Wed Sep 27 2017 jbreuer@suse.de
- Fix for delete_deployment in Kubernetes module (bsc#1059291)
- Added:
  * fix-for-delete_deployment-in-kubernetes-module.patch
* Mon Sep 18 2017 jbreuer@suse.de
- Catching error when PIDfile cannot be deleted (bsc#1050003)
- Added:
  * catching-error-when-pidfile-cannot-be-deleted.patch
* Tue Sep 12 2017 pablo.suarezhernandez@suse.com
- Use $HOME to get the user home directory instead using '~' char (bsc#1042749)
- Added:
  * use-home-to-get-the-user-home-directory-instead-usin.patch
* Fri Sep  8 2017 jbreuer@suse.de
- Fixed patches for Kubernetes and YUM modules
- Updated:
  * list_pkgs-add-parameter-for-returned-attribute-selec.patch
  * introducing-the-kubernetes-module.patch
* Tue Sep  5 2017 jbreuer@suse.de
- Add patches to salt to support SUSE Manager scalability features
  (bsc#1052264)
- Added:
  * list_pkgs-add-parameter-for-returned-attribute-selec.patch
* Thu Aug 31 2017 jbreuer@suse.de
- Introducing the kubernetes module (bsc#1051948)
- Added:
  * introducing-the-kubernetes-module.patch
* Wed Aug 30 2017 jrenner@suse.com
- Revert "We don't have python-systemd, so notify can't work"
- Added:
  * revert-we-don-t-have-python-systemd-so-notify-can-t-work.patch
* Wed Aug 23 2017 brejoc@gmail.com
- Notify systemd synchronously via NOTIFY_SOCKET (bsc#1053376)
- Added:
  * notify-systemd-synchronously-bsc-1053376.patch
* Wed Aug 16 2017 pablo.suarezhernandez@suse.com
- Add clean_id function to salt.utils.verify.py
  (CVE-2017-12791, bsc#1053955)
- Added:
  * add-clean_id-function-to-salt.utils.verify.py.patch
* Mon Jul 17 2017 bmaryniuk@suse.com
- Added bugfix when jobs scheduled to run at a future time stay
  pending for Salt minions (bsc#1036125)
- Added:
  * bugfix-jobs-scheduled-to-run-at-a-future-time-stay-p.patch
* Tue Jun 20 2017 pablo.suarezhernandez@suse.com
- Adding procps as dependency. This provides "ps" and "pgrep" utils
  which are called from different Salt modules and also from new
  salt-minion watchdog.
* Thu Jun  8 2017 pablo.suarezhernandez@suse.com
- Adding a salt-minion watchdog for RHEL6 and SLES11 systems (sysV)
  to restart salt-minion in case of crashes during upgrade.
- Added:
  * adding-salt-minion-watchdog-for-sysv-systems-rhel6-a.patch
  * enables-salt-minion-watchdog-on-init.d-script-for-sy.patch
* Wed Jun  7 2017 mc@suse.com
- fix format error (bsc#1043111)
* Wed Jun  7 2017 mc@suse.com
- fix ownership for whole master cache directory (bsc#1035914)
* Tue Jun  6 2017 bmaryniuk@suse.com
- Bugfix: clean up `change` attribute from interface dict (upstream)
  Issue: https://github.com/saltstack/salt/issues/41461
  PR: 1. https://github.com/saltstack/salt/pull/41487
    2. https://github.com/saltstack/salt/pull/41533
  Added:
  * clean-up-change-attribute-from-interface-dict.patch
* Mon May 29 2017 bmaryniuk@suse.com
- Disable 3rd party runtime packages to be explicitly recommended.
  (bsc#1040886)
* Mon May 22 2017 bmaryniuk@suse.com
- Bugfix: orchestrate and batches returns false failed information
  https://github.com/saltstack/salt/issues/40635
  Added:
  * fixed-issue-with-parsing-of-master-minion-returns-wh.patch
* Sun May 21 2017 mc@suse.com
- speed-up cherrypy by removing sleep call
* Fri May 19 2017 mc@suse.com
- wrong os_family grains on SUSE - fix unittests (bsc#1038855)
* Thu May 18 2017 mc@suse.com
- fix setting the language on SUSE systems (bsc#1038855)
* Wed May 17 2017 bmaryniuk@suse.com
- Documentation refresh to 2016.11.4
* Wed May 17 2017 bmaryniuk@suse.com
- Update to 2016.11.4
  See https://docs.saltstack.com/en/develop/topics/releases/2016.11.4.html
  See https://docs.saltstack.com/en/develop/topics/releases/2016.11.3.html
  See https://docs.saltstack.com/en/develop/topics/releases/2016.11.2.html
  See https://docs.saltstack.com/en/develop/topics/releases/2016.11.1.html
  for full changelog
- Use SUSE specific salt-api.service (bsc#1039370)
- Bugfix: wrong os_family grains on SUSE (bsc#1038855)
- Bugfix: unable to use hostname for minion ID as '127' (upstream)
- Fix core grains constants for timezone (bsc#1032931)
- Add unit test for a skip false values from preferred IPs
  upstream patch
- Adding "yum-plugin-security" as required for RHEL 6
- Minor fixes on new pkg.list_downloaded
- Listing all type of advisory patches for Yum module
- Prevents zero length error on Python 2.6
- Fixes zypper test error after backporting
- raet protocol is no longer supported (bsc#1020831)
- Fix: move SSH data to the new home (bsc#1027722)
- Fix: /var/log/salt/minion fails logrotate (bsc#1030009)
- Fix: Result of master_tops extension is mutually overwritten
  (bsc#1030073)
- Allows to set 'timeout' and 'gather_job_timeout' via kwargs
- Allows to set custom timeouts for 'manage.up' and 'manage.status'
- Use salt's ordereddict for comparison (fixes failing tests)
- add special salt-minion.service file for RES7
- fix scripts for salt-proxy
- define with systemd for fedora and rhel >= 7 (bsc#1027240)
- add openscap module
- file.get_managed regression fix (upstream issues #39762)
- fix translate variable arguments if they contain hidden keywords
  (bsc#1025896)
- fix service handling for openSUSE
- added unit test for dockerng.sls_build dryrun
- added dryrun to dockerng.sls_build
- update dockerng minimal version requirements
- fix format error in error parsing
- keep fix for migrating salt home directory (bsc#1022562)
- Fix  salt pkg.latest raises exception if package is
  not available (bsc#1012999)
- Fix timezone: should be always in UTC (bsc#1017078)
- Fix timezone handling for rpm installtime (bsc#1017078)
- Increasing timeouts for running integrations tests
- Add buildargs option to dockerng.build module
- Disable custom rosters for Salt SSH via Salt API (bsc#1011800)
  More: https://github.com/saltstack/salt/pull/38596
- Fix error when missing ssh-option parameter
- readd yum notify plugin
- all kwargs to dockerng.create to provide all features to sls_build
  as well
- rename patches to get rid of the prefix numbers
- Added:
  * bugfix-unable-to-use-127-as-hostname.patch
  * fix-grain-for-os_family-on-suse-series.patch
  * use-correct-grain-constants-for-timezone.patch
  * search-the-entire-cache_dir-because-storage-paths-ch.patch
  * add-unit-test-for-skip-false-values-from-preferred_i.patch
  * add-a-salt-minion-service-control-file.patch
  * add-options-for-dockerng.patch
  * add-zypp-notify-plugin.patch
  * fixing-beacons.list-integration-test-failure.patch
  * fix-regression-in-file.get_managed-add-unit-tests.patch
  * fix-salt-summary-to-count-not-responding-minions-cor.patch
  * special-salt-minion.service-file-for-rhel7.patch
  * translate-variable-arguments-if-they-contain-hidden-.patch
- Renamed:
  * 0001-tserong-suse.com-We-don-t-have-python-systemd-so-not.patch
  => tserong-suse.com-we-don-t-have-python-systemd-so-not.patch
  * 0002-Run-salt-master-as-dedicated-salt-user.patch
  => run-salt-master-as-dedicated-salt-user.patch
  * 0003-Check-if-byte-strings-are-properly-encoded-in-UTF-8.patch
  => check-if-byte-strings-are-properly-encoded-in-utf-8.patch
  * 0004-do-not-generate-a-date-in-a-comment-to-prevent-rebui.patch
  => do-not-generate-a-date-in-a-comment-to-prevent-rebui.patch
  * 0009-Add-YUM-plugin.patch 0027-Add-YUM-plugin.patch
  => add-yum-plugin.patch
  * 0012-Run-salt-api-as-user-salt-bsc-990029.patch
  => run-salt-api-as-user-salt-bsc-990029.patch
  * 0020-Setting-up-OS-grains-for-SLES-Expanded-Support-SUSE-.patch
  => setting-up-os-grains-for-sles-expanded-support-suse-.patch
  * 0022-Change-travis-configuration-file-to-use-salt-toaster.patch
  => change-travis-configuration-file-to-use-salt-toaster.patch
  * 0036-Avoid-failures-on-SLES-12-SP2-because-of-new-systemd.patch
  => avoid-failures-on-sles-12-sp2-because-of-new-systemd.patch
  * 0042-Salt-ssh-ssh-option-param.patch
  => add-ssh-option-to-salt-ssh.patch
  * 0057-Adding-support-for-installing-patches-in-yum-dnf-exe.patch
  => adding-support-for-installing-patches-in-yum-dnf-exe.patch
- Removed:
  * 0005-Use-SHA256-hash-type-by-default.patch
  * 0006-Create-salt-proxy-instantiated-service-file.patch
  * 0007-Add-SUSE-Manager-plugin.patch
  * 0008-Fix-pkgrepo.managed-gpgkey-argument-bsc-979448.patch
  * 0009-Rewrite-minion-ID-generator-bsc-967803.patch
  * 0010-snapper-execution-module.patch
  * 0011-Fix-module-import-being-Py3-and-P2.6-compatible.patch
  * 0013-Bugfix-prevent-crash-if-python-dbus-module-is-instal.patch
  * 0014-Fix-some-unittests.patch
  * 0015-Check-for-single-quote-before-splitting-on-single-qu.patch
  * 0016-Unit-test-fixes-for-2015.8.7.patch
  * 0017-Fix-snapper_test-for-python26.patch
  * 0018-Integration-tests-fixes-for-2015.8.7.patch
  * 0019-Generate-Salt-Thin-with-configured-extra-modules.patch
  * 0021-acl.delfacl-fix-position-of-X-option-to-setfacl.patch
  * 0023-Adding-dist-upgrade-support-to-zypper-module.patch
  * 0024-Fix-open-ssh-bsc-1004723-upstream-issue-36966.patch
  * 0025-Including-resolver-params-for-Zypper-debug-solver.patch
  * 0026-fix-status-handling-in-sysv-init-scripts.patch
  * 0028-change-TIMEZONE-on-SUSE-systems-bsc-1008933.patch
  * 0029-Do-not-include-gpg-pubkey-packages-filtering-by-thei.patch
  * 0030-Extract-archive-into-existing-directory-add-overwrit.patch
  * 0031-Port-rsync-state-from-2016.3.patch
  * 0032-Support-remote-port-forwarding-with-salt-ssh.patch
  * 0033-Add-master_tops-support-in-salt-ssh.patch
  * 0034-Fix-pkg.latest_version-when-latest-already-installed.patch
  * 0035-salt-api-service-must-be-from-type-simple.patch
  * 0037-salt-minion-service-back-to-type-simple.patch
  * 0038-Successfully-exit-of-salt-api-child-processes-when-S.patch
  * 0039-Re-introducing-KillMode-process-for-salt-minion-syst.patch
  * 0040-Adding-Restart-on-failure-for-salt-minion-systemd-se.patch
  * 0041-add-try-restart-to-fix-autorestarting-on-SUSE-system.patch
  * 0043-Fixes-wrong-enabled-opts-for-yumnotify-plugin.patch
  * 0044-Add-general-sanitisers.patch
  * 0045-Fix-timezone-handling-for-rpm-installtime-bsc-101707.patch
  * 0046-Snapper-module-improvements.patch
  * 0047-Fix-issue-with-cp.push-36136.patch
  * 0048-Prevents-OSError-exception-in-case-path-doesn-t-exis.patch
  * 0049-OpenSCAP-module.patch
  * 0050-Fix-service-state-returning-stacktrace-bsc-1027044.patch
  * 0051-Allows-to-set-timeout-and-gather_job_timeout-via-kwa.patch
  * 0052-Don-t-send-passwords-after-shim-delimiter-is-found-3.patch
  * 0053-fix-race-condition-on-cache-directory-creation.patch
  * 0054-Merge-output-from-master_tops.patch
  * 0055-Adding-downloadonly-support-to-yum-dnf-module.patch
  * 0056-Makes-sure-gather_job_timeout-is-an-integer.patch
  * 0058-Adds-custom-timeout-and-gather_job_timeout-to-local_.patch
  * 0059-Add-SHELL-env-var-for-the-salt-api.service.patch
  * 0060-Fix-logrotate-for-minion-bsc-1030009-21.patch
* Thu May 11 2017 bmaryniuk@suse.com
- Bugfix: datetime should be returned always in UTC
- Added:
  * 0063-Bugfix-datetime-should-be-returned-always-in-UTC.patch
* Mon May  8 2017 bmaryniuk@suse.com
- Bugfix: scheduled state may cause crash while deserialising data
    on infinite recursion. (bsc#1036125)
- Added:
  * 0062-Bugfix-deserialising-crashes-in-the-recursive-loop-b.patch
* Tue May  2 2017 pablo.suarezhernandez@suse.com
- Enable yum to handle errata on RHEL 6: require yum-plugin-security
* Wed Apr 26 2017 pablo.suarezhernandez@suse.com
- Minor fixes on new pkg.list_downloaded
- Listing all type of advisory patches for Yum module
- Prevents zero length error on Python 2.6
- Fixes zypper test error after backporting
- Added:
  * 0061-Search-the-entire-CACHE_DIR-because-storage-paths-ch.patch
- Modified:
  * 0057-Adding-support-for-installing-patches-in-yum-dnf-exe.patch
* Mon Apr 17 2017 pablo.suarezhernandez@suse.com
- Refactoring on Zypper and Yum execution and state modules to allow
  installation of patches/errata.
- Added:
  * 0057-Adding-support-for-installing-patches-in-yum-dnf-exe.patch
- Removed:
  * 0057-Allows-using-downloadonly-in-a-pkg.installed-state.patch
* Wed Apr 12 2017 bmaryniuk@suse.com
- Fix log rotation permission issue (bsc#1030009)
- Use pkg/suse/salt-api.service by this package
- Removed:
  * 0059-Set-salt-api-shell-env.patch
- Added:
  * 0059-Add-SHELL-env-var-for-the-salt-api.service.patch
  * 0060-Fix-logrotate-for-minion-bsc-1030009-21.patch
* Tue Apr 11 2017 malbu@suse.com
- Patch to set SHELL env variable for the salt-api.service.
  Needed for salt-ssh ProxyCommand to work properly.
- Added:
  * 0059-Set-salt-api-shell-env.patch
* Mon Apr 10 2017 pablo.suarezhernandez@suse.com
- Fixes 'timeout' and 'gather_job_timeout' kwargs parameters
  for 'local_batch' client
- Added:
  * 0058-Adds-custom-timeout-and-gather_job_timeout-to-local_.patch
* Fri Apr  7 2017 bmaryniuk@suse.com
- Add missing bootstrap script for Salt Cloud (bsc#1032452)
* Tue Apr  4 2017 bmaryniuk@suse.com
- Fix: add missing /var/cache/salt/cloud directory (bsc#1032213)
* Fri Mar 31 2017 bmaryniuk@suse.com
- Added test case for race conditions on cache directory creation
- Modified:
  * 0053-fix-race-condition-on-cache-directory-creation.patch
* Thu Mar 30 2017 pablo.suarezhernandez@suse.com
- Adding "pkg.install downloadonly=True" support to yum/dnf
  execution module
- Makes sure "gather_job_timeout" is an Integer
- Adding "pkg.downloaded" state and support for installing
  patches/erratas
- Added:
  * 0055-Adding-downloadonly-support-to-yum-dnf-module.patch
  * 0056-Makes-sure-gather_job_timeout-is-an-integer.patch
  * 0057-Allows-using-downloadonly-in-a-pkg.installed-state.patch
* Wed Mar 29 2017 bmaryniuk@suse.com
- Fix: merge master_tops output
* Wed Mar 29 2017 moio@suse.com
- Fix: race condition on cache directory creation
- Added:
  * 0053-fix-race-condition-on-cache-directory-creation.patch
* Fri Mar 24 2017 bmaryniuk@suse.com
- Cleanup salt user environment preparation (bsc#1027722)
* Wed Mar 22 2017 pkazmierczak@suse.com
- Don't send passwords after shim delimiter is found (bsc#1019386)
- Add:
  * 0052-Don-t-send-passwords-after-shim-delimiter-is-found-3.patch
* Thu Mar 16 2017 pablo.suarezhernandez@suse.com
- Allows to set 'timeout' and 'gather_job_timeout' via kwargs
- Allows to set custom timeouts for 'manage.up' and 'manage.status'
- Add:
  * 0051-Allows-to-set-timeout-and-gather_job_timeout-via-kwa.patch
* Tue Mar  7 2017 mihai.dinca@suse.com
- Update systemd module unit tests (Update patch 0050)
* Sun Mar  5 2017 mc@suse.com
- define with system for fedora and rhel 7  (bsc#1027240)
* Fri Mar  3 2017 mihai.dinca@suse.com
- Fix service state returning stacktrace (bsc#1027044)
- Add:
  * 0050-Fix-service-state-returning-stacktrace-bsc-1027044.patch
* Tue Feb 21 2017 mihai.dinca@suse.com
- Update OpenSCAP Module patch
* Fri Feb 17 2017 mihai.dinca@suse.com
- OpenSCAP Module
- Added:
  * 0049-OpenSCAP-module.patch
* Wed Feb 15 2017 pablo.suarezhernandez@suse.com
- Prevents 'OSError' exception in case certain job cache path
  doesn't exist (bsc#1023535)
- Added:
  * 0048-Prevents-OSError-exception-in-case-path-doesn-t-exis.patch
* Mon Feb 13 2017 mihai.dinca@suse.com
- Backport: Fix issue with cp.push (#36136)
- Add:
  * 0047-Fix-issue-with-cp.push-36136.patch
* Tue Feb  7 2017 bmaryniuk@suse.com
- Fix salt-minion update on RHEL (bsc#1022841)
* Mon Feb  6 2017 pablo.suarezhernandez@suse.com
- Adding new functions to Snapper execution module.
- Added:
  * snapper-module-improvements.patch
* Thu Jan 26 2017 bmaryniuk@suse.com
- Fix invalid chars allowed for data IDs (bsc#1011304)
  Fix timezone: should be always in UTC (bsc#1017078)
  Add:
  * 0044-Add-general-sanitisers.patch
  * 0045-Fix-timezone-handling-for-rpm-installtime-bsc-101707.patch
* Wed Jan 25 2017 pablo.suarezhernandez@suse.com
- Fixes wrong "enabled" opts for yumnotify plugin
  Add:
  * 0043-Fixes-wrong-enabled-opts-for-yumnotify-plugin.patch
* Mon Jan  2 2017 malbu@suse.com
- ssh-option parameter for salt-ssh command.
  Added:
  * 0042-Salt-ssh-ssh-option-param.patch
* Tue Dec 20 2016 mc@suse.de
- minion should pre-require salt
- do not restart salt-minion in the salt package
- add try-restart to sys-v init scripts
  Add:
  * 0041-add-try-restart-to-fix-autorestarting-on-SUSE-system.patch
* Tue Dec 20 2016 pablo.suarezhernandez@suse.com
- Adding "Restart=on-failure" for salt-minion systemd service
  Add:
  * 0040-Adding-Restart-on-failure-for-salt-minion-systemd-se.patch
* Mon Dec 19 2016 pablo.suarezhernandez@suse.com
- Re-introducing "KillMode=process" for salt-minion systemd service
  Add:
  * 0039-Re-introducing-KillMode-process-for-salt-minion-syst.patch
* Wed Dec 14 2016 mihai.dinca@suse.com
- Successfully exit of salt-api child processes when SIGTERM is received
  Add:
  * 0038-Successfully-exit-of-salt-api-child-processes-when-S.patch
* Wed Dec 14 2016 mihai.dinca@suse.com
- Add new patches:
  * 0034-Fix-pkg.latest_version-when-latest-already-installed.patch
  * 0035-salt-api-service-must-be-from-type-simple.patch
  * 0036-Avoid-failures-on-SLES-12-SP2-because-of-new-systemd.patch
  * 0037-salt-minion-service-back-to-type-simple.patch
* Fri Dec  9 2016 mihai.dinca@suse.com
- Update to 2015.8.12
- Fix possible information leak due to revoked keys still being used.
  (bsc#1012398, CVE-2016-9639)
- inherited patches
    0001-tserong-suse.com-We-don-t-have-python-systemd-so-not.patch
    0002-Run-salt-master-as-dedicated-salt-user.patch
    0003-Check-if-byte-strings-are-properly-encoded-in-UTF-8.patch
- renamed patches
    0026-do-not-generate-a-date-in-a-comment-to-prevent-rebui.patch
  - > 0004-do-not-generate-a-date-in-a-comment-to-prevent-rebui.patch
    0036-Use-SHA256-hash-type-by-default.patch
  - > 0005-Use-SHA256-hash-type-by-default.patch
    0046-Add-SUSE-Manager-plugin.patch
  - > 0007-Add-SUSE-Manager-plugin.patch
    0048-Create-salt-proxy-instantiated-service-file.patch
  - > 0006-Create-salt-proxy-instantiated-service-file.patch
    0053-Fix-pkgrepo.managed-gpgkey-argument-bsc-979448.patch
  - > 0008-Fix-pkgrepo.managed-gpgkey-argument-bsc-979448.patch
    0059-Rewrite-minion-ID-generator-bsc-967803.patch
  - > 0009-Rewrite-minion-ID-generator-bsc-967803.patch
    0061-snapper-execution-module.patch
  - > 0010-snapper-execution-module.patch
    0063-Fix-module-import-being-Py3-and-P2.6-compatible.patch
  - > 0011-Fix-module-import-being-Py3-and-P2.6-compatible.patch
    0064-Run-salt-api-as-user-salt-bsc-990029.patch
  - > 0012-Run-salt-api-as-user-salt-bsc-990029.patch
    0067-Bugfix-prevent-crash-if-python-dbus-module-is-instal.patch
  - > 0013-Bugfix-prevent-crash-if-python-dbus-module-is-instal.patch
    0070-Fix-some-unittests.patch
  - > 0014-Fix-some-unittests.patch
    0071-Check-for-single-quote-before-splitting-on-single-qu.patch
  - > 0015-Check-for-single-quote-before-splitting-on-single-qu.patch
    0072-Unit-test-fixes-for-2015.8.7.patch
  - > 0016-Unit-test-fixes-for-2015.8.7.patch
    0073-Fix-snapper_test-for-python26.patch
  - > 0017-Fix-snapper_test-for-python26.patch
    0074-Integration-tests-fixes-for-2015.8.7.patch
  - > 0018-Integration-tests-fixes-for-2015.8.7.patch
    0075-Generate-Salt-Thin-with-configured-extra-modules.patch
  - > 0019-Generate-Salt-Thin-with-configured-extra-modules.patch
    0076-Setting-up-OS-grains-for-SLES-Expanded-Support-SUSE-.patch
  - > 0020-Setting-up-OS-grains-for-SLES-Expanded-Support-SUSE-.patch
    0077-acl.delfacl-fix-position-of-X-option-to-setfacl.patch
  - > 0021-acl.delfacl-fix-position-of-X-option-to-setfacl.patch
    0078-Change-travis-configuration-file-to-use-salt-toaster.patch
  - > 0022-Change-travis-configuration-file-to-use-salt-toaster.patch
    0079-Adding-dist-upgrade-support-to-zypper-module.patch
  - > 0023-Adding-dist-upgrade-support-to-zypper-module.patch
    0080-Fix-open-ssh-bsc-1004723-upstream-issue-36966.patch
  - > 0024-Fix-open-ssh-bsc-1004723-upstream-issue-36966.patch
    0081-Including-resolver-params-for-Zypper-debug-solver.patch
  - > 0025-Including-resolver-params-for-Zypper-debug-solver.patch
    0082-fix-status-handling-in-sysv-init-scripts.patch
  - > 0026-fix-status-handling-in-sysv-init-scripts.patch
- new patches from upstream
    0027-Add-YUM-plugin.patch
    0028-change-TIMEZONE-on-SUSE-systems-bsc-1008933.patch (bsc#1008933)
    0029-Do-not-include-gpg-pubkey-packages-filtering-by-thei.patch
    0030-Extract-archive-into-existing-directory-add-overwrit.patch
    0031-Port-rsync-state-from-2016.3.patch
    0032-Support-remote-port-forwarding-with-salt-ssh.patch
    0033-Add-master_tops-support-in-salt-ssh.patch
- upstreamed patches
    0004-Fix-pkg.latest-prevent-crash-on-multiple-package-ins.patch
    0005-Fix-package-status-filtering-on-latest-version-and-i.patch
    0006-add_key-reject_key-do-not-crash-w-Permission-denied-.patch
    0007-Force-kill-websocket-s-child-processes-faster-than-d.patch
    0008-Fix-types-in-the-output-data-and-return-just-a-list-.patch
    0009-The-functions-in-the-state-module-that-return-a-retc.patch
    0010-add-handling-for-OEM-products.patch
    0011-improve-doc-for-list_pkgs.patch
    0012-implement-version_cmp-for-zypper.patch
    0013-pylint-changes.patch
    0014-Check-if-rpm-python-can-be-imported.patch
    0015-call-zypper-with-option-non-interactive-everywhere.patch
    0016-write-a-zypper-command-builder-function.patch
    0017-Fix-crash-with-scheduler-and-runners-31106.patch
    0018-unify-behavior-of-refresh.patch
    0019-add-refresh-option-to-more-functions.patch
    0020-simplify-checking-the-refresh-paramater.patch
    0021-do-not-change-kwargs-in-refresh-while-checking-a-val.patch
    0022-fix-argument-handling-for-pkg.download.patch
    0023-Initial-Zypper-Unit-Tests-and-bugfixes.patch
    0024-proper-checking-if-zypper-exit-codes-and-handling-of.patch
    0025-adapt-tests-to-new-zypper_check_result-output.patch
    0027-make-suse-check-consistent-with-rh_service.patch
    0028-fix-numerical-check-of-osrelease.patch
    0029-Make-use-of-checksum-configurable-defaults-to-MD5-SH.patch
    0030-Bugfix-on-SLE11-series-base-product-reported-as-addi.patch
    0031-Only-use-LONGSIZE-in-rpm.info-if-available.-Otherwis.patch
    0032-Add-error-check-when-retcode-is-0-but-stderr-is-pres.patch
    0033-fixing-init-system-dectection-on-sles-11-refs-31617.patch
    0034-Fix-git_pillar-race-condition.patch
    0035-Fix-the-always-false-behavior-on-checking-state.patch
    0037-Force-sort-the-RPM-output-to-ensure-latest-version-o.patch
    0038-fix-sorting-by-latest-version-when-called-with-an-at.patch
    0039-Prevent-metadata-download-when-getting-installed-pro.patch
    0040-Check-if-EOL-is-available-in-a-particular-product-bs.patch
    0041-Bugfix-salt-key-crashes-if-tries-to-generate-keys-to.patch
    0042-align-OS-grains-from-older-SLES-with-current-one-bsc.patch
    0043-Prevent-crash-if-pygit2-package-is-requesting-re-com.patch
    0044-Unblock-Zypper.-Modify-environment.patch
    0045-Bugfix-Restore-boolean-values-from-the-repo-configur.patch
    0047-Old-style-proxymodules-need-to-be-setup-earlier-in-m.patch
    0049-Prevent-several-minion-processes-on-the-same-machine.patch
    0050-checksum-validation-when-zypper-pkg.download.patch
    0051-unit-tests-for-rpm.checksum-and-zypper.download.patch
    0052-jobs.exit_success-allow-to-check-if-a-job-has-execut.patch
    0054-fix-groupadd-module-for-sles11-systems.patch
    0055-Backport-31164-and-31364-32474.patch
    0056-Move-log-message-from-INFO-to-DEBUG.patch
    0057-fix-salt-summary-to-count-not-responding-minions-cor.patch
    0058-Getting-the-os-grain-from-CPE_NAME-inside-etc-os-rel.patch
    0060-Bugfix-return-boolean-only-for-isbase-and-installed-.patch
    0062-Add-realpath-to-lvm.pvdisplay-and-use-it-in-vg_prese.patch
    0065-fix-beacon-list-to-include-all-beacons-being-process.patch
    0066-Fix-continuous-minion-restart-if-a-dependency-wasn-t.patch
    0068-Add-ignore_repo_failure-option-to-suppress-zypper-s-.patch
    0069-Remove-zypper-s-raise-exception-if-mod_repo-has-no-a.patch
* Mon Nov 28 2016 kkaempf@suse.com
- Splitted non-Linux and other external platform modules
  to 'salt-other' sub-package.
* Mon Nov 28 2016 kkaempf@suse.com
- Switch package group from System/Monitoring to System/Management
* Sun Nov  6 2016 mc@suse.com
- fix exist codes of sysv init script (bsc#999852)
  Add:
  * 0082-fix-status-handling-in-sysv-init-scripts.patch
* Mon Oct 31 2016 pablo.suarezhernandez@suse.com
- Including resolution parameters in the Zypper debug-solver call
  during a dry-run dist-upgrade.
  Add:
  * 0081-Including-resolver-params-for-Zypper-debug-solver.patch
* Tue Oct 25 2016 bmaryniuk@suse.com
- Fix Salt API crash via salt-ssh on empty roster (bsc#1004723)
  Add:
  * 0080-Fix-open-ssh-bsc-1004723-upstream-issue-36966.patch
* Wed Oct 19 2016 pablo.suarezhernandez@suse.com
- Adding 'dist-upgrade' support to zypper module (FATE#320559)
  Add:
  * 0079-Adding-dist-upgrade-support-to-zypper-module.patch
* Mon Oct 17 2016 mihai.dinca@suse.com
- Copy .travis.yml from git commit ea63e793567ba777e47dc766a4f88edfb037a02f
  Add:
  * travis.yml
- Change travis configuration file to use salt-toaster
  Add:
  * travis.yml
  * 0078-Change-travis-configuration-file-to-use-salt-toaster.patch
* Thu Oct 13 2016 mihai.dinca@suse.com
- acl.delfacl: fix position of -X option to setfacl (bsc#1004260)
  Add:
  * 0077-acl.delfacl-fix-position-of-X-option-to-setfacl.patch
* Tue Oct 11 2016 mc@suse.com
- fix generated shebang in scripts on SLES-ES 7 (bsc#1004047)
* Thu Oct  6 2016 mc@suse.de
- add update-documentation.sh to specfile
* Wed Oct  5 2016 mihai.dinca@suse.com
- Setting up OS grains for SLES-ES (SLES Expanded Support platform)
  Add:
  * 0076-Setting-up-OS-grains-for-SLES-Expanded-Support-SUSE-.patch
* Tue Oct  4 2016 Michele.Bologna@suse.com
- Move salt home directory to /var/lib/salt (bsc#1002529)
- Adjust permissions on home directory
- Adjust pre-install script to correctly move existing salt users' home directory
  salt user cannot write in his own home directory (/srv/salt) because
  it is owned by user `root`.
  This prevents salt from correctly save ssh known hosts in ~/.ssh/
  and breaks salt-ssh bootstrapping.
* Tue Sep 27 2016 bmaryniuk@suse.com
- Updated html.tar.bz2 documentation tarball.
- Generate Salt Thin with configured extra modules (bsc#990439)
  Add:
  * 0075-Generate-Salt-Thin-with-configured-extra-modules.patch
* Tue Sep 13 2016 pablo.suarezhernandez@suse.com
- Unit and integration tests fixes for 2015.8.7
  Add:
  * 0072-Unit-test-fixes-for-2015.8.7.patch
  * 0073-Fix-snapper_test-for-python26.patch
  * 0074-Integration-tests-fixes-for-2015.8.7.patch
* Fri Sep  2 2016 pablo.suarezhernandez@suse.com
- Prevent pkg.install failure for expired keys (bsc#996455)
  Add:
  * 0071-Check-for-single-quote-before-splitting-on-single-qu.patch
* Mon Aug 29 2016 bmaryniuk@suse.com
- Required D-Bus and generating machine ID
* Fri Aug 26 2016 mc@suse.de
- add a macro to check if the docs should be build or the static
  tarball should be used
* Wed Aug 24 2016 mihai.dinca@suse.com
- Fix a couple of failing unittests
  * 0070-Fix-some-unittests.patch
* Tue Aug 23 2016 bmaryniuk@suse.com
- Helper script for updating documentation tarball.
  Added:
  * update-documentation.sh
* Tue Aug 16 2016 mihai.dinca@suse.com
- Fix python-jinja2 requirements in rhel
* Tue Aug 16 2016 bmaryniuk@suse.com
- Fix pkg.installed refresh repo failure (bsc#993549)
  Fix salt.states.pkgrepo.management no change failure (bsc#990440)
  Add:
  * 0068-Add-ignore_repo_failure-option-to-suppress-zypper-s-.patch
  * 0069-Remove-zypper-s-raise-exception-if-mod_repo-has-no-a.patch
* Thu Aug 11 2016 bmaryniuk@suse.com
- Prevent snapper module crash on load if no DBus is
  available in the system (bsc#993039)
  Add:
  * 0067-Bugfix-prevent-crash-if-python-dbus-module-is-instal.patch
* Thu Aug 11 2016 bmaryniuk@suse.com
- Prevent continuous restart, if a dependency wasn't installed
  (bsc#991048)
  Add:
  * 0066-Fix-continuous-minion-restart-if-a-dependency-wasn-t.patch
* Wed Aug  3 2016 pablo.suarezhernandez@suse.com
- Fix beacon list to include all beacons being process
  Add:
  * 0065-fix-beacon-list-to-include-all-beacons-being-process.patch
* Fri Jul 29 2016 mc@suse.de
- Run salt-api as user salt like the master (bsc#990029)
  Add:
  * 0064-Run-salt-api-as-user-salt-bsc-990029.patch
* Fri Jul 22 2016 dmacvicar@suse.de
- Revert patch Minion ID generation (bsc#967803)
  Removes:
  * 0059-Rewrite-minion-ID-generator-bsc-967803.patch
* Wed Jul 20 2016 bmaryniuk@suse.com
- Fix broken inspector due to accidentally
  missed commit (bsc#989798)
  Add:
  * 0063-Fix-module-import-being-Py3-and-P2.6-compatible.patch
* Wed Jul 20 2016 bmaryniuk@suse.com
- Set always build salt-doc package.
* Tue Jul 19 2016 pablo.suarezhernandez@suse.com
- Bugfix: lvm.vg_present does not recognize PV with certain LVM
    filter settings (bsc#988506)
  Add:
  * 0062-Add-realpath-to-lvm.pvdisplay-and-use-it-in-vg_prese.patch
* Mon Jul 18 2016 pablo.suarezhernandez@suse.com
- Backport: Snapper module for Salt.
  Add:
  * 0061-snapper-execution-module.patch
* Fri Jul 15 2016 bmaryniuk@suse.com
- Bugfix: pkg.list_products on "registerrelease" and "productline"
    returns boolean.False if empty (bsc#989193, bsc#986019)
  Add:
  * 0060-Bugfix-return-boolean-only-for-isbase-and-installed-.patch
* Fri Jun 24 2016 bmaryniuk@suse.com
- Rewrite Minion ID generation (bsc#967803)
  Add:
  * 0059-Rewrite-minion-ID-generator-bsc-967803.patch
* Wed Jun 22 2016 pablo.suarezhernandez@suse.com
- Bugfix: Fixed behavior for SUSE OS grains (bsc#970669)
  Bugfix: Salt os_family does not detect SLES for SAP (bsc#983017)
  Add:
  * 0058-Getting-the-os-grain-from-CPE_NAME-inside-etc-os-rel.patch
* Tue Jun 21 2016 mc@suse.de
- Move log message from INFO to DEBUG (bsc#985661)
  Add:
  0056-Move-log-message-from-INFO-to-DEBUG.patch
- fix salt --summary to count not responding minions correctly
  (bsc#972311)
  Add:
  * 0057-fix-salt-summary-to-count-not-responding-minions-cor.patch
* Tue Jun 14 2016 tserong@suse.com
- Fix memory leak on custom execution module sheduled jobs (bsc#983512)
  Add:
  * 0055-Backport-31164-and-31364-32474.patch
* Thu Jun  9 2016 pablo.suarezhernandez@suse.com
- fix groupadd module for sles11 systems (bsc#978150)
  Add:
  * 0054-fix-groupadd-module-for-sles11-systems.patch
* Wed Jun  1 2016 mihai.dinca@suse.com
- Fix pkgrepo.managed gpgkey argument doesn't work (bsc#979448)
  Add:
  * 0053-Fix-pkgrepo.managed-gpgkey-argument-bsc-979448.patch
* Fri May 27 2016 pablo.suarezhernandez@suse.com
- Package checksum validation for zypper pkg.download
  Add:
  * 0050-checksum-validation-when-zypper-pkg.download.patch
  * 0051-unit-tests-for-rpm.checksum-and-zypper.download.patch
- Check if a job has executed and returned successfully
  Add:
  * 0052-jobs.exit_success-allow-to-check-if-a-job-has-execut.patch
* Mon May 23 2016 bmaryniuk@suse.com
- Remove option -f from startproc (bsc#975733)
  Add:
  * 0049-Prevent-several-minion-processes-on-the-same-machine.patch
* Mon May 23 2016 bmaryniuk@suse.com
- Changed Zypper's plugin. Added Unit test and related to that
  data (bsc#980313).
  Update:
  * 0046-Add-SUSE-Manager-plugin.patch
  Delete (not needed anymore):
  * 0049-Alter-the-event-name.patch
* Tue May 17 2016 bmaryniuk@suse.com
- Zypper plugin: alter the generated event name on package set
  change.
  Add:
  * 0049-Alter-the-event-name.patch
* Thu May 12 2016 tserong@suse.com
- Fix file ownership on master keys and cache directories during upgrade
  (handles upgrading from salt 2014, where the daemon ran as root, to 2015
  where it runs as the salt user, bsc#979676).
* Wed May 11 2016 pablo.suarezhernandez@suse.com
- salt-proxy .service file created (bsc#975306)
  Add:
  * 0048-Create-salt-proxy-instantiated-service-file.patch
* Wed May 11 2016 pablo.suarezhernandez@suse.com
- Prevent salt-proxy test.ping crash (bsc#975303)
  Add:
  * 0047-Old-style-proxymodules-need-to-be-setup-earlier-in-m.patch
* Wed May 11 2016 bmaryniuk@suse.com
- Fix shared directories ownership issues.
* Mon May  9 2016 bmaryniuk@suse.com
- Add Zypper plugin to generate an event,
  once Zypper is used outside the Salt infrastructure
  demand (bsc#971372).
  Add:
  * 0046-Add-SUSE-Manager-plugin.patch
* Fri May  6 2016 bmaryniuk@suse.com
- Restore boolean values from the repo configuration
  Fix priority attribute (bsc#978833)
  Add:
  * 0045-Bugfix-Restore-boolean-values-from-the-repo-configur.patch
* Wed May  4 2016 bmaryniuk@suse.com
- Unblock-Zypper. (bsc#976148)
  Modify-environment. (bsc#971372)
  Add:
  * 0044-Unblock-Zypper.-Modify-environment.patch
* Wed Apr 20 2016 bmaryniuk@suse.com
- Prevent crash if pygit2 package is requesting re-compilation.
  Add:
  * 0043-Prevent-crash-if-pygit2-package-is-requesting-re-com.patch
* Mon Apr 18 2016 mc@suse.de
- align OS grains from older SLES with current one (bsc#975757)
  Add:
  * 0042-align-OS-grains-from-older-SLES-with-current-one-bsc.patch
* Thu Apr 14 2016 bmaryniuk@suse.com
- Bugfix: salt-key crashes if tries to generate keys
  to the directory w/o write access (bsc#969320)
  Add:
  * 0041-Bugfix-salt-key-crashes-if-tries-to-generate-keys-to.patch
* Tue Apr 12 2016 bmaryniuk@suse.com
- Check if EOL is available in a particular product (bsc#975093)
  Add:
  * 0040-Check-if-EOL-is-available-in-a-particular-product-bs.patch
* Tue Apr  5 2016 mc@suse.com
- fix building with docs on SLE11
* Tue Apr  5 2016 mc@suse.com
- Prevent metadata download when getting installed products
  Add:
  * 0039-Prevent-metadata-download-when-getting-installed-pro.patch
* Tue Apr  5 2016 kkaempf@suse.com
- Add statically built docs.
* Mon Apr  4 2016 mc@suse.com
- fix sorting by latest package
  Add:
  * 0038-fix-sorting-by-latest-version-when-called-with-an-at.patch
* Sat Apr  2 2016 mc@suse.com
- ensure pkg.info_installed report latest package version
  (bsc#972490)
  Add:
  * 0037-Force-sort-the-RPM-output-to-ensure-latest-version-o.patch
* Thu Mar 17 2016 bmaryniuk@suse.com
- Use SHA256 by default in master, minion and proxy (bsc#955373)
  Add:
  * 0036-Use-SHA256-hash-type-by-default.patch
* Wed Mar 16 2016 bmaryniuk@suse.com
- Fix state structure compilation
  Add:
  * 0035-Fix-the-always-false-behavior-on-checking-state.patch
- Fix git_pillar race condition
  Add:
  * 0034-Fix-git_pillar-race-condition.patch
* Sat Mar 12 2016 mc@suse.com
- fix detection of base products in SLE11
  * 0030-Bugfix-on-SLE11-series-base-product-reported-as-addi.patch
- fix rpm info for SLE11
  * 0031-Only-use-LONGSIZE-in-rpm.info-if-available.-Otherwis.patch
  * 0032-Add-error-check-when-retcode-is-0-but-stderr-is-pres.patch
- fix init system detection for SLE11
  * 0033-fixing-init-system-dectection-on-sles-11-refs-31617.patch
* Fri Mar 11 2016 bmaryniuk@suse.com
- Re-add corrected patch:
  0029-Make-use-of-checksum-configurable-defaults-to-MD5-SH.patch
* Wed Mar  9 2016 kkaempf@suse.com
- Make checksum configurable (upstream still wants md5, we
  suggest sha256). bsc#955373
  Add:
  0029-Make-use-of-checksum-configurable-defaults-to-MD5-SH.patch
* Fri Mar  4 2016 tampakrap@opensuse.org
- Fix the service state / module on SLE11.
  Add:
  * 0027-make-suse-check-consistent-with-rh_service.patch
  * 0028-fix-numerical-check-of-osrelease.patch
* Fri Mar  4 2016 mc@suse.de
- Prevent rebuilds in OBS by not generating a date as a comment in
  a source file
  Add: 0026-do-not-generate-a-date-in-a-comment-to-prevent-rebui.patch
* Fri Feb 26 2016 mc@suse.de
- Add better checking for zypper exit codes and simplify evaluation
  of the zypper error messages.
  Add: 0024-proper-checking-if-zypper-exit-codes-and-handling-of.patch
- Adapt unit tests
  Add: 0025-adapt-tests-to-new-zypper_check_result-output.patch
* Fri Feb 26 2016 bmaryniuk@suse.com
- Add initial pack of Zypper's Unit tests.
  Use XML output in list_upgrades.
  Bugfix: upgrade_available crashes when only one package specified
  Purge is not using "-u" anymore
  Add:
  * 0023-Initial-Zypper-Unit-Tests-and-bugfixes.patch
* Tue Feb 23 2016 mc@suse.de
- fix argument handling of pkg.download
  Add: 0022-fix-argument-handling-for-pkg.download.patch
* Mon Feb 22 2016 mc@suse.de
- unify behavior of zypper refresh in salt
  Add: 0018-unify-behavior-of-refresh.patch
    0019-add-refresh-option-to-more-functions.patch
    0020-simplify-checking-the-refresh-paramater.patch
    0021-do-not-change-kwargs-in-refresh-while-checking-a-val.patch
* Sat Feb 20 2016 mc@suse.de
- Fix crash with scheduler and runners
  Add: 0017-Fix-crash-with-scheduler-and-runners-31106.patch
* Fri Feb 19 2016 mc@suse.de
- Call zypper always with --non-interactive
  Add:
  * 0015-call-zypper-with-option-non-interactive-everywhere.patch
  * 0016-write-a-zypper-command-builder-function.patch
* Fri Feb 19 2016 mc@suse.de
- require rpm-python on SUSE for zypper support
* Thu Feb 18 2016 mc@suse.de
- fix state return code
  Add: 0009-The-functions-in-the-state-module-that-return-a-retc.patch
- add handling of OEM products to pkg.list_products
  Add: 0010-add-handling-for-OEM-products.patch
- improve doc for list_pkgs
  Add: 0011-improve-doc-for-list_pkgs.patch
- implement pkg.version_cmp in zypper.py
  Add:
  * 0012-implement-version_cmp-for-zypper.patch
  * 0013-pylint-changes.patch
  * 0014-Check-if-rpm-python-can-be-imported.patch
* Wed Feb 17 2016 aboe76@gmail.com
- Update to 2015.8.7
  this is a small update to fix some regressions
  see https://docs.saltstack.com/en/latest/topics/releases/2015.8.7.html
* Thu Feb 11 2016 bmaryniuk@suse.com
- Booleans should not be strings from XML, add Unix ticks time and
  format result in a list of maps.
  Add:
  * 0008-Fix-types-in-the-output-data-and-return-just-a-list-.patch
* Thu Feb 11 2016 bmaryniuk@suse.com
- Stop salt-api daemon faster (bsc#963322)
  Add:
  * 0007-Force-kill-websocket-s-child-processes-faster-than-d.patch
* Wed Feb 10 2016 dmacvicar@suse.de
- Do not crash on salt-key reject/delete consecutive calls.
  Add:
  * 0006-add_key-reject_key-do-not-crash-w-Permission-denied-.patch
* Mon Feb  8 2016 kkaempf@suse.com
- Update to 2015.8.5
  Security fixes:
  * CVE-2016-1866: Improper handling of clear messages on the
    minion remote code execution (boo#965403)
  See https://docs.saltstack.com/en/latest/topics/releases/2015.8.5.html
  Dropped patches (all upstream):
  * 0003-List-products-consistently-across-all-SLES-systems.patch
  * 0004-Add-missing-return-data-to-scheduled-jobs.patch
  * 0005-Fix-RPM-issues-with-the-date-time-and-add-package-at.patch
  * 0006-Bugfix-info_available-does-not-work-correctly-on-SLE.patch
  Renamed patches:
  * 0007-Check-if-byte-strings-are-properly-encoded-in-UTF-8.patch
  - > 0003-Check-if-byte-strings-are-properly-encoded-in-UTF-8.patch
  * 0008-Fix-pkg.latest-prevent-crash-on-multiple-package-ins.patch
  - > 0004-Fix-pkg.latest-prevent-crash-on-multiple-package-ins.patch
  * 0009-Fix-package-status-filtering-on-latest-version-and-i.patch
  - > 0005-Fix-package-status-filtering-on-latest-version-and-i.patch
- Update to 2015.8.4
  See https://docs.saltstack.com/en/latest/topics/releases/2015.8.4.html
* Wed Jan 27 2016 bmaryniuk@suse.com
- Fix latest version available comparison and implement epoch
  support in Zypper module.
  Add:
  * 0009-Fix-package-status-filtering-on-latest-version-and-i.patch
* Wed Jan 27 2016 bmaryniuk@suse.com
- Update patch from opensuse to upstream version.
  Update:
  * 0008-Fix-pkg.latest-prevent-crash-on-multiple-package-ins.patch
* Tue Jan 26 2016 bmaryniuk@suse.com
- Fix dependencies to Salt subpackages requiring release along the
  version.
* Mon Jan 25 2016 bmaryniuk@suse.com
- Fix pkg.latest crash.
- Fix pkg.latest SLS ID bug, when pkgs empty list is passed,
  but SLS ID still treated as a package name.
  Add:
  * 0008-Fix-pkg.latest-prevent-crash-on-multiple-package-ins.patch
* Wed Jan 20 2016 bmaryniuk@suse.com
- Drop:
  * -0004-zypper-check-package-header-content-for-valid-utf-8.patch
- Rename:
  * -0004-zypper-check-package-header-content-for-valid-utf-8.patch
    +0004-Add-missing-return-data-to-scheduled-jobs.patch
  * -0005-Add-missing-return-data-to-scheduled-jobs.patch
    +0004-Add-missing-return-data-to-scheduled-jobs.patch
  * -0006-Fix-RPM-issues-with-the-date-time-and-add-package-at.patch
    +0005-Fix-RPM-issues-with-the-date-time-and-add-package-at.patch
  * -0007-Bugfix-info_available-does-not-work-correctly-on-SLE.patch
    +0006-Bugfix-info_available-does-not-work-correctly-on-SLE.patch
- Add:
  * 0007-Check-if-byte-strings-are-properly-encoded-in-UTF-8.patch
* Wed Jan 20 2016 kkaempf@suse.com
- Rename use-forking-daemon.patch to
  0001-tserong-suse.com-We-don-t-have-python-systemd-so-not.patch
- Rename use-salt-user-for-master.patch to
  0002-Run-salt-master-as-dedicated-salt-user.patch
- Rename 1efe484309a5c776974e723f3da0f5181f4bdb86.patch to
  0003-List-products-consistently-across-all-SLES-systems.patch
- Rename zypper-utf-8.patch to
  0004-zypper-check-package-header-content-for-valid-utf-8.patch
- Rename salt-2015.8-schedule-ret.patch to
  0005-Add-missing-return-data-to-scheduled-jobs.patch
- Rename salt-2015.8-pkg-zypper-attr-filtering.patch to
  0006-Fix-RPM-issues-with-the-date-time-and-add-package-at.patch
- Rename salt-2015.8-zypper-info.patch to
  0007-Bugfix-info_available-does-not-work-correctly-on-SLE.patch
* Fri Jan 15 2016 dmacvicar@suse.de
- Fix zypper module info_available on SLE-11
  * add salt-2015.8-zypper-info.patch
  * https://github.com/saltstack/salt/pull/30384
- zypper/pkg: add package attributes filtering
  * add salt-2015.8-pkg-zypper-attr-filtering.patch
  * https://github.com/saltstack/salt/pull/30267
- Remove obsoleted patches and fixes:
  * 0001-Add-rpm.minimal_info-fix-rpm.info.patch
  * 0002-Reduce-information-returned-from-pkg.info_installed.patch
  * Remove require on glibc-locale (bsc#959572)
* Wed Jan 13 2016 dmacvicar@suse.de
- Add missing return data to scheduled jobs
  * add salt-2015.8-schedule-ret.patch for
  * https://github.com/saltstack/salt/pull/30246
* Mon Dec 21 2015 kkaempf@suse.com
- Update zypper-utf-8.patch for Python 2.6
* Thu Dec 17 2015 kkaempf@suse.com
- require glibc-locale (bsc#959572)
* Tue Dec 15 2015 kkaempf@suse.com
- Report epoch and architecture of installed packages
  0001-Add-rpm.minimal_info-fix-rpm.info.patch
- pkg.info_installed exceeds the maximum event size, reduce the
  information to what's actually needed
  0002-Reduce-information-returned-from-pkg.info_installed.patch
* Wed Dec  9 2015 kkaempf@suse.com
- Filter out bad UTF-8 strings in package data (bsc#958350)
  zypper-utf-8.patch
* Tue Dec  1 2015 aboe76@gmail.com
- Updated to salt 2015.8.3 bugfix release
- remove the following patches because upstream merged them:
  - 4b9302d79455d6a586b7cad1d7990cb22e7bc62e.patch
  - os_grain.patch
  - zypper_pkgrepo.patch
- more details at: https://docs.saltstack.com/en/latest/topics/releases/2015.8.3.html
* Tue Dec  1 2015 bmaryniuk@suse.com
- added 1efe484309a5c776974e723f3da0f5181f4bdb86.patch:
  reimplements pkg.list_products that potentially may be broken in
  a future releases of SLES.
* Mon Nov 30 2015 mrueckert@suse.de
- added 4b9302d79455d6a586b7cad1d7990cb22e7bc62e.patch:
  fixes a regression introduced in 2015.8.2, which was actually
  holding back the release. Downgrade is not an option as we need
  the leap fixes.
* Thu Nov 26 2015 mrueckert@suse.de
- it shouldnt be >= 1110 but just > 1110
* Wed Nov 25 2015 mrueckert@suse.de
- require pmtools on sle11 to get dmidecode
* Fri Nov 20 2015 mrueckert@suse.de
- update use-salt-user-for-master.patch:
  First step to make the syndic also run as salt user.
* Fri Nov 13 2015 aboe76@gmail.com
- Updated to bugfix release 2015.8.2
- os_grain.patch fix the "os" grain on SLES11SP4
- zypper_pkgrepo.patch fix the priority and humanname pkgrepo args for the
  zypper backend
  for more details:
  https://docs.saltstack.com/en/2015.8/topics/releases/2015.8.2.html
* Thu Oct 15 2015 mrueckert@suse.de
- update to 2015.8.1
  - Add support for ``spm.d/*.conf`` configuration of SPM
    (:issue:`27010`)
  - Fix ``proxy`` grains breakage for non-proxy minions
    (:issue:`27039`)
  - Fix global key management for git state
  - Fix passing http auth to ``util.http`` from ``state.file``
    (:issue:`21917`)
  - Fix ``multiprocessing: True`` in windows (on by default`)
  - Add ``pkg.info`` to pkg modules
  - Fix name of ``serial`` grain (this was accidentally renamed in
    2015.8.0`)
  - Merge config values from ``master.d``/``minion.d`` conf files
    (rather than flat update`)
  - Clean grains cache on grains sync (:issue:`19853`)
  - Remove streamed response for fileclient to avoid HTTP
    redirection problems (:issue:`27093`)
  - Fixed incorrect warning about ``osrelease`` grain
    (:issue:`27065`)
  - Fix authentication via Salt-API with tokens (:issue:`27270`)
  - Fix winrepo downloads from https locations (:issue:`27081`)
  - Fix potential error with salt-call as non-root user
    (:issue:`26889`)
  - Fix global minion provider overrides (:issue:`27209`)
  - Fix backward compatibility issues for pecl modules
  - Fix Windows uninstaller to only remove ``./bin``, ``salt*``,
    ``nssm.exe``, ``uninst.exe`` (:issue:`27383`)
  - Fix misc issues with mongo returner.
  - Add sudo option to cloud config files (:issue:`27398`)
  - Fix regression in RunnerClient argument handling
    (:issue:`25107`)
  - Fix ``dockerng.running`` replacing creation hostconfig with
    runtime hostconfig (:issue:`27265`)
  - Fix dockerng.running replacing creation hostconfig with runtime
    hostconfig (:issue:`27265`)
  - Increased performance on boto asg/elb states due to
    ``__states__`` integration
  - Windows minion no longer requires powershell to restart
    (:issue:`26629`)
  - Fix x509 module to support recent versions of OpenSSL
    (:issue:`27326`)
  - Some issues with proxy minions were corrected.
- drop salt-2015.8-backports-susemanager.diff: included in update
- guard raet buildrequires with bcond_with raet and comment out the
  recommends for salt-raet.
* Mon Oct 12 2015 tampakrap@opensuse.org
- remove pygit2 global recommends, it is only needed in the master
- remove git-core, pygit2 should pull it as a dependency
- add a (currently disabled) %%check
* Mon Oct 12 2015 toddrme2178@gmail.com
- Add salt-2015.8-backports-susemanager.diff
  Returns detailed information about a package
* Mon Oct 12 2015 dmacvicar@suse.de
- ifdef Recommends to build on RHEL based distros
- use _initddir instead of _sysconfdir/init.d as
  it works on both platforms.
* Mon Oct 12 2015 dmacvicar@suse.de
- allow to disable docs in preparation for building
  on other platforms without all dependencies.
* Mon Oct 12 2015 dmacvicar@suse.de
- python-libnacl, python-ioflo are _not_ required to build the
  package. They are anyways requires of python-raet, which is
  also not required to build the package.
* Sat Oct 10 2015 mrueckert@suse.de
- merge (build)requires/recommends with requirements/*txt and
  setup.py
* Fri Oct  9 2015 mrueckert@suse.de
- add raet subpackage which will pull all requires for it and
  provides config snippets to enable it for the minion and master.
* Fri Oct  9 2015 mrueckert@suse.de
- add tmpfiles.d file
* Fri Oct  9 2015 dmacvicar@suse.de
- Remove requires on python-ioflo and python-libnacl
  they will be pulled by python-raet,
  which is optional.
* Fri Oct  9 2015 dmacvicar@suse.de
- python-raet is optional, so make it a Recommends
* Fri Oct  9 2015 dmacvicar@suse.de
- update backports patch from 2015.8 branch
* Wed Oct  7 2015 mrueckert@suse.de
- update use-forking-daemon.patch:
  the original intention was to get rid of the python systemd
  dependency. for this we do not have daemonize the whole process.
  just switching to simple mode is enough.
* Wed Oct  7 2015 mrueckert@suse.de
- drop fdupes:
  1. it broke python byte code handling
  2. the only part of the package which would really benefit from
    it would be the doc package. but given we only install the
    files via %%doc, we can not use it for that either.
- reenable completions on distros newer than sle11
- do not use _datarootdir, use _datadir instead.
* Wed Oct  7 2015 mrueckert@suse.de
- package all directories in /var/cache/salt and /etc/salt and
  have permissions set for non root salt master
- update use-salt-user-for-master.patch:
  - also patch the logrotate file to include the su option
* Tue Oct  6 2015 mrueckert@suse.de
- remove duplicated recommends
- never require pygit2 and git. the master can run fine without.
  always use recommends
* Tue Oct  6 2015 tampakrap@opensuse.org
- cleanup dependencies:
  - remove a lot of unneeded buildrequires
  - fdupes not present on SLE10
  - python-certifi needed on SLE11
  - python-zypp not needed any more
  - python-pygit2 is not a global requirement
  - convert python-pysqlite to recommends as it is not available on python <=2.7
- sles_version -> suse_version
- %%exclude the cloud/deploy/*.sh scripts to fix build issue on SLE11
* Mon Oct  5 2015 tampakrap@opensuse.org
- Remove python-PyYAML from the dependencies list, as python-yaml is the same
- Build the -completion subpackages in SLE11 as well
- Add salt-proxy (by dmacvicar@suse.de)
- Create salt user/group only in the -master subpkg
* Sat Oct  3 2015 infroma@gmail.com
- Fix typo in use-forking-daemon.patch, that prevented daemon loading
* Thu Oct  1 2015 toddrme2178@gmail.com
- Fix typo in Requires
* Tue Sep 29 2015 toddrme2178@gmail.com
- Cleanup requirements
* Wed Sep 23 2015 aboe76@gmail.com
- New Major release 2015.8.0
  for more details:
  http://docs.saltstack.com/en/latest/topics/releases/2015.8.0.html
- Cleaned the spec file with spec-cleaner
- Added the use-salt-user-for-master.patch see README.SUSE
- Updated the files ownership with salt user
- removed m2crypto depency
* Tue Sep 22 2015 infroma@gmail.com
- Removed fish dependency for fish completions.
* Tue Sep 22 2015 infroma@gmail.com
- Added fish completions.
* Mon Sep 21 2015 tampakrap@opensuse.org
- Support SLE11SP{3,4}, where the M2Crypto package is named python-m2crypto
* Tue Aug 18 2015 aboe76@gmail.com
- Updated to Bugfix release 2015.5
  for more details:
  https://github.com/saltstack/salt/blob/develop/doc/topics/releases/2015.5.5.rst
- Add prereq, for user creation.
- Add creation of salt user in preparation of running the salt-master daemon
  as non-root user salt.
  https://bugzilla.opensuse.org/show_bug.cgi?id=939831
- Add README.SUSE with explanation and how to.
* Mon Jul 20 2015 bwiedemann@suse.com
- only require git-core to not pull in git-web and gitk
* Wed Jul  8 2015 aboe76@gmail.com
- New Bugfix release 2015.5.3
  for more details:
  http://docs.saltstack.com/en/latest/topics/releases/2015.5.3.html
* Thu Jun  4 2015 aboe76@gmail.com
- New Bugfix release 2015.5.2
  for more details:
  http://docs.saltstack.com/en/latest/topics/releases/2015.5.2.html
* Sat May 23 2015 aboe76@gmail.com
- New Bugfix release 2015.5.1
  salt.runners.cloud.action() has changed the fun keyword argument to func.
  Please update any calls to this function in the cloud runner.
  for more details:
  http://docs.saltstack.com/en/latest/topics/releases/2015.5.1.html
* Fri May 15 2015 aboe76@gmail.com
- Removed python-pssh depency not needed anymore.
* Wed May  6 2015 aboe76@gmail.com
- Major release 2015.5.0 Lithium
- update to 2015.5.0
  The 2015.5.0 feature release of Salt is focused on hardening Salt
  and mostly on improving existing systems. A few major additions
  are present, primarily the new Beacon system. Most enhancements
  have been focused around improving existing features and
  interfaces.
  As usual the release notes are not exhaustive and primarily
  include the most notable additions and improvements. Hundreds of
  bugs have been fixed and many modules have been substantially
  updated and added.
  See especially the warning right on the top regarding
  python_shell=False.
  For all details see
  http://docs.saltstack.com/en/latest/topics/releases/2015.5.0.html
- RPM Package changes:
- add some versions to the buildrequires to match the 2
  requirements files from the tarball
- Moved the depencencies to main salt package
  except where they are specific for the package
- Changed python-request dependency,only needed on salt-cloud
- Added python-tornado dependency for http.py
- Fixed zsh_completion in tarball.
- Fixed salt-api requirements to require python-cherrypy
- Fixed salt-cloud requiments to require salt-master
* Sun Apr 19 2015 aboe76@gmail.com
- New Bugfix release 2014.7.5
  Changes:
  + Fixed a key error bug in salt-cloud
  + Updated man pages to better match documentation
  + Fixed bug concerning high CPU usage with salt-ssh
  + Fixed bugs with remounting cvfs and fuse filesystems
  + Fixed bug with alowing requisite tracking of entire sls files
  + Fixed bug with aptpkg.mod_repo returning OK even if apt-add-repository fails
  + Increased frequency of ssh terminal output checking
  + Fixed malformed locale string in localmod module
  + Fixed checking of available version of package when accept_keywords were changed
  + Fixed bug to make git.latest work with empty repositories
  + Added **kwargs to service.mod_watch which removes warnings about enable and __reqs__ not being supported by the function
  + Improved state comments to not grow so quickly on failed requisites
  + Added force argument to service to trigger force_reload
  + Fixed bug to andle pkgrepo keyids that have been converted to int
  + Fixed module.portage_config bug with appending accept_keywords
  + Fixed bug to correctly report disk usage on windows minion
  + Added the ability to specify key prefix for S3 ext_pillar
  + Fixed issues with batch mode operating on the incorrect number of minions
  + Fixed a bug with the proxmox cloud provider stacktracing on disk definition
  + Fixed a bug with the changes dictionary in the file state
  + Fixed the TCP keep alive settings to work better with SREQ caching
  + Fixed many bugs within the iptables state and module
  + Fixed bug with states by adding fun, state, and unless to the state runtime internal keywords listing
  + Added ability to eAuth against Active Directory
  + Fixed some salt-ssh issues when running on Fedora 21
  + Fixed grains.get_or_set_hash to work with multiple entries under same key
  + Added better explanations and more examples of how the Reactor calls functions to docs
  + Fixed bug to not pass ex_config_drive to libcloud unless it's explicitly enabled
  + Fixed bug with pip.install on windows
  + Fixed bug where puppet.run always returns a 0 retcode
  + Fixed race condition bug with minion scheduling via pillar
  + Made efficiency improvements and bug fixes to the windows installer
  + Updated environment variables to fix bug with pygit2 when running salt as non-root user
  + Fixed cas behavior on data module -- data.cas was not saving changes
  + Fixed GPG rendering error
  + Fixed strace error in virt.query
  + Fixed stacktrace when running chef-solo command
  + Fixed possible bug wherein uncaught exceptions seem to make zmq3 tip over when threading is involved
  + Fixed argument passing to the reactor
  + Fixed glibc caching to prevent bug where salt-minion getaddrinfo in dns_check() never got updated nameservers
  Known Issues:
  + In multimaster mode, a minion may become temporarily unresponsive if modules or pillars are refreshed at the
  same time that one or more masters are down. This can be worked around by setting 'auth_timeout' and 'auth_tries'
  down to shorter periods.
* Mon Mar 30 2015 aboe76@gmail.com
- New Bugfix Release 2014.7.4
- Updated patch use-forking-daemon.patch
- fix salt-zsh-completion conflicts
  + Multi-master minions mode no longer route fileclient operations asymetrically.
  This fixes the source of many multi-master bugs where the minion would
  become unrepsonsive from one or more masters.
  + Fix bug wherein network.iface could produce stack traces.
  + net.arp will no longer be made available unless arp is installed on the
  system.
  + Major performance improvements to Saltnado
  + Allow KVM module to operate under KVM itself or VMWare Fusion
  + Various fixes to the Windows installation scripts
  + Fix issue where the syndic would not correctly propogate loads to the master
  job cache.
  + Improve error handling on invalid /etc/network/interfaces file in salt
  networking modules
  + Fix bug where a reponse status was not checked for in fileclient.get_url
  + Enable eauth when running salt in batch mode
  + Increase timeout in Boto Route53 module
  + Fix bugs with Salt's 'tar' module option parsing
  + Fix parsing of NTP servers on Windows
  + Fix issue with blockdev tuning not reporting changes correctly
  + Update to the latest Salt bootstrap script
  + Update Linode salt-cloud driver to use either linode-python or
  apache-libcloud
  + Fix for s3.query function to return correct headers
  + Fix for s3.head returning None for files that exist
  + Fix the disable function in win_service module so that the service is
  disabled correctly
  + Fix race condition between master and minion when making a directory when
  both daemons are on the same host
  + Fix an issue where file.recurse would fail at the root of an svn repo
  when the repo has a mountpoint
  + Fix an issue where file.recurse would fail at the root of an hgfs repo
  when the repo has a mountpoint
  + Fix an issue where file.recurse would fail at the root of an gitfs repo
  when the repo has a mountpoint
  + Add status.master capability for Windows.
  + Various fixes to ssh_known_hosts
  + Various fixes to states.network bonding for Debian
  + The debian_ip.get_interfaces module no longer removes nameservers.
  + Better integration between grains.virtual and systemd-detect-virt and
  virt-what
  + Fix traceback in sysctl.present state output
  + Fix for issue where mount.mounted would fail when superopts were not a part
  of mount.active (extended=True). Also mount.mounted various fixes for Solaris
  and FreeBSD.
  + Fix error where datetimes were not correctly safeguarded before being passed
  into msgpack.
  + Fix file.replace regressions.  If the pattern is not found, and if dry run is False,
  and if `backup` is False, and if a pre-existing file exists with extension `.bak`,
  then that backup file will be overwritten. This backup behavior is a result of how `fileinput`
  works. Fixing it requires either passing through the file twice (the
  first time only to search for content and set a flag), or rewriting
  `file.replace` so it doesn't use `fileinput`
  + VCS filreserver fixes/optimizations
  + Catch fileserver configuration errors on master start
  + Raise errors on invalid gitfs configurations
  + set_locale when locale file does not exist (Redhat family)
  + Fix to correctly count active devices when created mdadm array with spares
  + Fix to correctly target minions in batch mode
  + Support ssh:// urls using the gitfs dulwhich backend
  + New fileserver runner
  + Fix various bugs with argument parsing to the publish module.
  + Fix disk.usage for Synology OS
  + Fix issue with tags occurring twice with docker.pulled
  + Fix incorrect key error in SMTP returner
  + Fix condition which would remount loopback filesystems on every state run
  + Remove requsites from listens after they are called in the state system
  + Make system implementation of service.running aware of legacy service calls
  + Fix issue where publish.publish would not handle duplicate responses gracefully.
  + Accept Kali Linux for aptpkg salt execution module
  + Fix bug where cmd.which could not handle a dirname as an argument
  + Fix issue in ps.pgrep where exceptions were thrown on Windows.
- Known Issues:
  + In multimaster mode, a minion may become temporarily unresponsive
  if modules or pillars are refreshed at the same time that one
  or more masters are down. This can be worked around by setting
  'auth_timeout' and 'auth_tries' down to shorter periods.
* Thu Feb 12 2015 aboe76@gmail.com
- New Bugfix release 2014.7.2:
- fix package bug with fdupes.
- keep sle 11 sp3 support.
  + Fix erroneous warnings for systemd service enabled check (issue 19606)
  + Fix FreeBSD kernel module loading, listing, and persistence kmod (issue 197151, issue 19682)
  + Allow case-sensitive npm package names in the npm state. This may break behavior
  for people expecting the state to lowercase their npm package names for them.
  The npm module was never affected by mandatory lowercasing. (issue 20329)
  + Deprecate the activate parameter for pip.install for both the module and the state.
  If bin_env is given and points to a virtualenv, there is no need to activate that virtualenv
  in a shell for pip to install to the virtualenv.
  + Fix a file-locking bug in gitfs (issue 18839)
* Thu Jan 15 2015 aboe76@gmail.com
- New Bugfix release 2014.7.1:
  + Fixed gitfs serving symlinks in file.recurse states (issue 17700)
  + Fixed holding of multiple packages (YUM) when combined with version pinning (issue 18468)
  + Fixed use of Jinja templates in masterless mode with non-roots fileserver backend (issue 17963)
  + Re-enabled pillar and compound matching for mine and publish calls. Note that pillar globbing is still disabled for those modes, for security reasons. (issue 17194)
  + Fix for tty: True in salt-ssh (issue 16847)
- Needed to provide zsh completion because of the tarball missing the zsh completion script.
- Removed man salt.1.gz file from salt-master because upstream removed it.
- Added man salt.7.gz to salt-master package
* Mon Nov  3 2014 aboe76@gmail.com
- Updated to Major Release 2014.7.0
- added python-zipp as depency
- added recommend python-pygit2, this is the preferred gitfs backend of saltstack
- added zsh-completion package
- Removed Patch fix-service-py-version-parsing-sles.patch already fixed in this package
- Removed Patch pass-all-systemd-list-units.patch already fixed in this package
- Removed Patch disable-service-py-for-suse-family.patch already fixed in this package
- Removed Patch allow-systemd-units-no-unit-files.patch already fixed in this package
- Removed Patch allow-systemd-parameterized-services.patch already fixed in this package
- More information at: http://docs.saltstack.com/en/latest/topics/releases/2014.7.0.html
- SALT SSH ENHANCEMENTS:
  + Support for Fileserver Backends
  + Support for Saltfile
  + Ext Pillar
  + No more sshpass needed
  + Pure Python Shim
  + Custom Module Delivery
  + CP module Support
  + More Thin Directory Options
  - Salt State System enhancements:
  + New Imperative State Keyword "Listen"
  + New Mod Aggregate Runtime Manipulator
  + New Requisites: onchanges and onfail
  + New Global onlyif and unless
  + Use names to expand and override values
  - Salt Major Features:
  + Improved Scheduler Additions
  + Red Hat 7 Support
  + Fileserver Backends in Salt-call
  + Amazon Execution Modules in salt-cloud
  + LXC Runner Enhancements
  + Next Gen Docker Management
  + Peer System Performance Improvements
  + SDB Encryption at rest for configs
  + GPG Renderer encrypted pillar at rest
  + OpenStack Expansions
  + Queues System external queue systems into Salt events
  + Multi Master Failover Additions
  + Chef Execution Module
  - salt-api Project Merge
  + Synchronous and Asynchronous Execution of Runner and Wheel Modules
  + rest_cherrypy Additions
  + Web Hooks
  - Fileserver Backend Enhancements:
  + New gitfs Features
  + Pygit2 and Dulwich support
  + Mountpoints support
  + New hgfs Features
  + mountpoints support
  + New svnfs Features:
    + mountpoints
  + minionfs Featuressupport
    + mountpoints
  - New Salt Modules:
  + Oracle
  + Random
  + Redis
  + Amazon Simple Queue Service
  + Block Device Management
  + CoreOS etcd
  + Genesis
  + InfluxDB
  + Server Density
  + Twilio Notifications
  + Varnish
  + ZNC IRC Bouncer
  + SMTP
  - NEW RUNNERS:
  + Map/Reduce Style
  + Queue
  - NEW EXTERNAL PILLARS:
  + CoreOS etcd
  - NEW SALT-CLOUD PROVIDERS:
  + Aliyun ECS Cloud
  + LXC Containers
  + Proxmox (OpenVZ containers & KVM)
- DEPRECATIONS:
  + Salt.modules.virtualenv_mod
* Thu Oct 16 2014 aboe76@gmail.com
- Updated to 2014.1.13 a bugfix release on 2014.1.12
  + fix module run exit code (issue 16420)
  + salt cloud Check the exit status code of scp before assuming it has failed. (issue 16599)
* Fri Oct 10 2014 aboe76@gmail.com
  ff
- Updated to 2014.1.12 a bugfix release on 2014.1.11
  + Fix scp_file always failing (which broke salt-cloud) (issue 16437)
  + Fix regression in pillar in masterless (issue 16210, issue 16416, issue 16428)
* Wed Sep 10 2014 aboe76@gmail.com
- Updated to 2014.1.11 is another bugfix release for 2014.1.0. Changes include:
  + Fix for minion_id with byte-order mark (BOM) (issue 12296)
  + Fix runas deprecation in at module
  + Fix trailing slash befhavior for file.makedirs_ (issue 14019)
  + Fix chocolatey path (issue 13870)
  + Fix git_pillar infinite loop issues (issue 14671)
  + Fix json outputter null case
  + Fix for minion error if one of multiple masters are down (issue 14099)
  + Updated the use-forking-daemon.patch with the right version
* Mon Aug 18 2014 tserong@suse.com
- Fix service.py version parsing for SLE 11
  + Added fix-service-py-version-parsing-sles.patch
* Tue Aug 12 2014 tserong@suse.com
- Remove salt-master's hard requirement for git and python-GitPython on SLE 12
* Wed Aug  6 2014 tserong@suse.com
- Ensure salt uses systemd for services on SLES
  + Added disable-service-py-for-suse-family.patch
* Mon Aug  4 2014 aboe76@gmail.com
- RPM spec update
  + added service_add_pre function
* Fri Aug  1 2014 aboe76@gmail.com
- Updated to 2014.1.10:
  + Version 2014.1.9 contained a regression which caused inaccurate Salt version
  detection, and thus was never packaged for general release.  This version
  contains the version detection fix, but is otherwise identical to 2014.1.9.
  + Version 2014.1.8 contained a regression which caused inaccurate Salt version
  detection, and thus was never packaged for general release.  This version
  contains the version detection fix, but is otherwise identical to 2014.1.8.
* Wed Jul 30 2014 aboe76@gmail.com
- Updated to 2014.1.8:
  + Ensure salt-ssh will not continue if permissions on a temporary directory are not correct.
  + Use the bootstrap script distributed with Salt instead of relying on an external resource
  + Remove unused testing code
  + Ensure salt states are placed into the .salt directory in salt-ssh
  + Use a randomized path for temporary files in a salt-cloud deployment
  + Clean any stale directories to ensure a fresh copy of salt-ssh during a deployment
* Thu Jul 24 2014 tserong@suse.com
- Allow salt to correctly detect services provided by init scripts
  + Added allow-systemd-units-no-unit-files.patch
  + Added allow-systemd-parameterized-services.patch
  + Added pass-all-systemd-list-units.patch
- Move systemd service file fix to patch, add PIDFile parameter (this
  fix is applicable for all SUSE versions, not just 12.3)
  + Added use-forking-daemon.patch
* Wed Jul 23 2014 aboe76@gmail.com
- Improve systemd service file fix for 12.3
  Use forking instead of Simple and daemonize salt-master process
* Sat Jul 19 2014 aboe76@gmail.com
- Fixed bug in opensuse 12.3 systemd file
  systemd 198 doesn't have python-systemd binding.
- Disabled testing on SLES
* Thu Jul 10 2014 aboe76@gmail.com
- Update to 2014.7
  This release was a hotfix release for the regression listed above which was present in the 2014.1.6
- Fix batch mode regression (issue 14046)
* Wed Jul  9 2014 aboe76@gmail.com
- Updated to 2014.1.6
- Fix extra iptables --help output (Sorry!) (issue 13648, issue 13507, issue 13527, issue 13607)
- Fix mount.active for Solaris
- Fix support for allow-hotplug statement in debian_ip network module
- Add sqlite3 to esky builds
- Fix jobs.active output (issue 9526)
- Fix the virtual grain for Xen (issue 13534)
- Fix eauth for batch mode (issue 9605)
- Fix force-related issues with tomcat support (issue 12889)
- Fix KeyError when cloud mapping
- Fix salt-minion restart loop in Windows (issue 12086)
- Fix detection of service virtual module on Fedora minions
- Fix traceback with missing ipv4 grain (issue 13838)
- Fix issue in roots backend with invalid data in mtime_map (issue 13836)
- Fix traceback in jobs.active (issue 11151)
* Wed Jun 11 2014 aboe76@gmail.com
- Updated to 2014.1.5
- Add function for finding cached job on the minion
- Fix for minion caching jobs when master is down
- Bump default `syndic_wait` to 5 to fix syndic-related problems
  (issue 12262)
- Fix false positive error in logs for `makeconf` state (issue 9762)
- Fix for extra blank lines in `file.blockreplace` (issue 12422)
- Use system locale for ports package installations
- Fix for `cmd_iter`/`cmd_iter_no_block` blocking issues (issue 12617)
- Fix traceback when syncing custom types (issue 12883)
- Fix cleaning directory symlinks in `file.directory`
- Add performance optimizations for `saltutil.sync_all` and
  `state.highstate`
- Fix possible error in `saltutil.running`
- Fix for kmod modules with dashes (issue 13239)
- Fix possible race condition for Windows minions in state module reloading
  (issue 12370)
- Fix bug with roster for `passwd`s that are loaded as non-string objects
  (issue 13249)
- Keep duplicate version numbers from showing up in `pkg.list_pkgs` output
- Fixes for Jinja renderer, timezone mod`module
  <salt.modules.timezone>`/mod`state <salt.states.timezone>` (issue 12724)
- Fix timedatectl parsing for systemd>=210 (issue 12728)
- Removed the deprecated external nodes classifier (originally accessible by
  setting a value for external_nodes in the master configuration file).  Note
  that this functionality has been marked deprecated for some time and was
  replaced by the more general doc`master tops <topics/master_tops>` system.
- More robust escaping of ldap filter strings.
- Fix trailing slash in conf_master`gitfs_root` causing files not to be
  available (issue 13185)
* Tue Jun 10 2014 aboe76@gmail.com
- added bash completion package
* Mon May  5 2014 aboe76@gmail.com
- Updated to 2014.1.4
  - Fix setup.py dependency issue (issue 12031)
  - Fix handling for IOErrors under certain circumstances (issue 11783 and issue 11853)
  - Fix fatal exception when `/proc/1/cgroup` is not readable (issue 11619)
  - Fix os grains for OpenSolaris (issue 11907)
  - Fix `lvs.zero` module argument pass-through (issue 9001)
  - Fix bug in `debian_ip` interaction with `network.system` state (issue 11164)
  - Remove bad binary package verification code (issue 12177)
  - Fix traceback in solaris package installation (issue 12237)
  - Fix `file.directory` state symlink handling (issue 12209)
  - Remove `external_ip` grain
  - Fix `file.managed` makedirs issues (issue 10446)
  - Fix hang on non-existent Windows drive letter for `file` module (issue 9880)
  - Fix salt minion caching all users on the server (issue 9743)
* Thu Apr 17 2014 aboe76@gmail.com
- Updated to 2014.1.3
  - Fix username detection when su'ed to root on FreeBSD (issue 11628)
  - Fix minionfs backend for file.recurse states
  - Fix 32-bit packages of different arches than the CPU arch, on 32-bit RHEL/CentOS (issue 11822)
  - Fix bug with specifying alternate home dir on user creation (FreeBSD) (issue 11790)
  - Don’t reload site module on module refresh for MacOS
  - Fix regression with running execution functions in Pillar SLS (issue 11453)
  - Fix some modules missing from Windows installer
  - Don’t log an error for yum commands that return nonzero exit status on non-failure (issue 11645)
  - Fix bug in rabbitmq state (issue 8703)
  - Fix missing ssh config options (issue 10604)
  - Fix top.sls ordering (issue 10810 and issue 11691)
  - Fix salt-key --list all (issue 10982)
  - Fix win_servermanager install/remove function (issue 11038)
  - Fix interaction with tokens when running commands as root (issue 11223)
  - Fix overstate bug with find_job and **kwargs (issue 10503)
  - Fix saltenv for aptpkg.mod_repo from pkgrepo state
  - Fix environment issue causing file caching problems (issue 11189)
  - Fix bug in __parse_key in registry state (issue 11408)
  - Add minion auth retry on rejection (issue 10763)
  - Fix publish_session updating the encryption key (issue 11493)
  - Fix for bad AssertionError raised by GitPython (issue 11473)
  - Fix debian_ip to allow disabling and enabling networking on Ubuntu (issue 11164)
  - Fix potential memory leak caused by saved (and unused) events (issue 11582)
  - Fix exception handling in the MySQL module (issue 11616)
  - Fix environment-related error (issue 11534)
  - Include psutil on Windows
  - Add file.replace and file.search to Windows (issue 11471)
  - Add additional file module helpers to Windows (issue 11235)
  - Add pid to netstat output on Windows (issue 10782)
  - Fix Windows not caching new versions of installers in winrepo (issue 10597)
  - Fix hardcoded md5 hashing
  - Fix kwargs in salt-ssh (issue 11609)
  - Fix file backup timestamps (issue 11745)
  - Fix stacktrace on sys.doc with invalid eauth (issue 11293)
  - Fix git.latest with test=True (issue 11595)
  - Fix file.check_perms hardcoded follow_symlinks (issue 11387)
  - Fix certain pkg states for RHEL5/Cent5 machines (issue 11719)
- Packaging:
  - python-psutil depencies (more functional modules out of the box)
  - python-yaml depencies (more functional modules out of the box)
  - python-requests depencies (salt-cloud)
* Wed Mar 19 2014 aboe76@gmail.com
- Updated to 2014.1.1 Bug Fix release
- temporarily disabled integration check after consult with Upstream
* Thu Feb 20 2014 aboe76@gmail.com
- Updated to 2014.1.0 Major Release
- features:
  - 2014.1.0 is the first release to follow the new date-based release naming system.
  - Salt Cloud Merged into Salt
  - Google Compute Engine support is added to salt-cloud.
  - Salt Virt released
  - Docker Integration
  - IPv6 Support for iptables State/Module
  - GitFS Improvements
  - MinionFS
  - saltenv
  - Grains Caching
  - Improved Command Logging Control
  - PagerDuty Support
  - Virtual Terminal
  - Proxy Minions
- bugfixes:
  - Fix mount.mounted leaving conflicting entries in fstab (:issue:`7079`)
  - Fix mysql returner serialization to use json (:issue:`9590`)
  - Fix ZMQError: Operation cannot be accomplished in current state errors (:issue:`6306`)
  - Rbenv and ruby improvements
  - Fix quoting issues with mysql port (:issue:`9568`)
  - Update mount module/state to support multiple swap partitions (:issue:`9520`)
  - Fix archive state to work with bsdtar
  - Clarify logs for minion ID caching
  - Add numeric revision support to git state (:issue:`9718`)
  - Update master_uri with master_ip (:issue:`9694`)
  - Add comment to Debian mod_repo (:issue:`9923`)
  - Fix potential undefined loop variable in rabbitmq state (:issue:`8703`)
  - Fix for salt-virt runner to delete key on VM deletion
  - Fix for salt-run -d to limit results to specific runner or function (:issue:`9975`)
  - Add tracebacks to jinja renderer when applicable (:issue:`10010`)
  - Fix parsing in monit module (:issue:`10041`)
  - Fix highstate output from syndic minions (:issue:`9732`)
  - Quiet logging when dealing with passwords/hashes (:issue:`10000`)
  - Fix for multiple remotes in git_pillar (:issue:`9932`)
  - Fix npm installed command (:issue:`10109`)
  - Add safeguards for utf8 errors in zcbuildout module
  - Fix compound commands (:issue:`9746`)
  - Add systemd notification when master is started
  - Many doc improvements
- packaging:
  - source tarball includes all packaging files in pkg folder.
  - fixed rpmlint errors about duplicates.
  - fixed rpmlint errors about non executables scripts.
* Sat Jan 25 2014 aboe76@gmail.com
- Updated to 0.17.5 a bugfix release for 0.17.0:
* Thu Dec 12 2013 aboe76@gmail.com
- Updated to  0.17.4 which is another bugfix release for 0.17.0:
  - Fix some jinja render errors (issue 8418)
  - Fix file.replace state changing file ownership (issue 8399)
  - Fix state ordering with the PyDSL renderer (issue 8446)
  - Fix for new npm version (issue 8517)
  - Fix for pip state requiring name even with requirements file (issue 8519)
  - Add sane maxrunning defaults for scheduler (issue 8563)
  - Fix states duplicate key detection (issue 8053)
  - Fix SUSE patch level reporting (issue 8428)
  - Fix managed file creation umask (issue 8590)
  - Fix logstash exception (issue 8635)
  - Improve argument exception handling for salt command (issue 8016)
  - Fix pecl success reporting (issue 8750)
  - Fix launchctl module exceptions (issue 8759)
  - Fix argument order in pw_user module
  - Add warnings for failing grains (issue 8690)
  - Fix hgfs problems caused by connections left open (issue 8811 and issue 8810)
  - Fix installation of packages with dots in pkg name (issue 8614)
  - Fix noarch package installation on CentOS 6 (issue 8945)
  - Fix portage_config.enforce_nice_config (issue 8252)
  - Fix salt.util.copyfile umask usage (issue 8590)
  - Fix rescheduling of failed jobs (issue 8941)
  - Fix conflicting options in postgres module (issue 8717)
  - Fix ps modules for psutil >= 0.3.0 (issue 7432)
  - Fix postgres module to return False on failure (issue 8778)
  - Fix argument passing for args with pound signs (issue 8585)
  - Fix pid of salt CLi command showing in status.pid output (issue 8720)
  - Fix rvm to run gem as the correct user (issue 8951)
  - Fix namespace issue in win_file module (issue 9060)
  - Fix masterless state paths on windows (issue 9021)
  - Fix timeout option in master config (issue 9040)
* Thu Nov 21 2013 speilicke@suse.com
- Add bugzilla for solved issues
* Fri Nov 15 2013 aboe76@gmail.com
- dropped python-urllib3 depency not in factory yet.
  only needed with saltstack helium and higher
* Thu Nov 14 2013 aboe76@gmail.com
- Updated to salt 0.17.2 Bugfix Release:
  - Add ability to delete key with grains.delval (issue 7872)
  - Fix possible state compiler stack trace (issue 5767)
  - Fix grains targeting for new grains (issue 5737)
  - Fix bug with merging in git_pillar (issue 6992)
  - Fix print_jobs duplicate results
  - Fix possible KeyError from ext_job_cache missing option
  - Fix auto_order for - names states (issue 7649)
  - Fix regression in new gitfs installs (directory not found error)
  - Fix fileclient in case of master restart (issue 7987)
  - Try to output warning if CLI command malformed (issue 6538)
  - Fix --out=quiet to actually be quiet (issue 8000)
  - Fix for state.sls in salt-ssh (issue 7991)
  - Fix for MySQL grants ordering issue (issue 5817)
  - Fix traceback for certain missing CLI args (issue 8016)
  - Add ability to disable lspci queries on master (issue 4906)
  - Fail if sls defined in topfile does not exist (issue 5998)
  - Add ability to downgrade MySQL grants (issue 6606)
  - Fix ssh_auth.absent traceback (issue 8043)
  - Fix ID-related issues (issue 8052, issue 8050, and others)
  - Fix for jinja rendering issues (issue 8066 and issue 8079)
  - Fix argument parsing in salt-ssh (issue 7928)
  - Fix some GPU detection instances (issue 6945)
  - Fix bug preventing includes from other environments in SLS files
  - Fix for kwargs with dashes (issue 8102)
  - Fix apache.adduser without apachectl (issue 8123)
  - Fix issue with evaluating test kwarg in states (issue 7788)
  - Fix regression in salt.client.Caller() (issue 8078)
  - Fix bug where cmd.script would try to run even if caching failed (issue 7601)
  - Fix for mine data not being updated (issue 8144)
  - Fix a Xen detection edge case (issue 7839)
  - Fix version generation for when it's part of another git repo (issue 8090)
  - Fix _handle_iorder stacktrace so that the real syntax error is shown (issue 8114 and issue 7905)
  - Fix git.latest state when a commit SHA is used (issue 8163)
  - Fix for specifying identify file in git.latest (issue 8094)
  - Fix for --output-file CLI arg (issue 8205)
  - Add ability to specify shutdown time for system.shutdown (issue 7833)
  - Fix for salt version using non-salt git repo info (issue 8266)
  - Add additional hints at impact of pkgrepo states when test=True (issue 8247)
  - Fix for salt-ssh files not being owned by root (issue 8216)
  - Fix retry logic and error handling in fileserver (related to issue 7755)
  - Fix file.replace with test=True (issue 8279)
  - Add flag for limiting file traversal in fileserver (issue 6928)
  - Fix for extra mine processes (issue 5729)
  - Fix for unloading custom modules (issue 7691)
  - Fix for salt-ssh opts (issue 8005 and issue 8271)
  - Fix compound matcher for grains (issue 7944)
  - Add dir_mode to file.managed (issue 7860)
  - Improve traceroute support for FreeBSD and OS X (issue 4927)
  - Fix for matching minions under syndics (issue 7671)
  - Improve exception handling for missing ID (issue 8259)
  - Add configuration option for minion_id_caching
  - Fix open mode auth errors (issue 8402)
* Sun Nov 10 2013 aboe76@gmail.com
- In preparation of salt Helium all requirements of salt-cloud
  absorbed in salt
* Fri Nov  1 2013 aboe76@gmail.com
- Added salt-doc package with html documentation of salt
* Thu Oct 31 2013 aboe76@gmail.com
- Disabled salt unit test, new test assert value not in 0.17.1
* Mon Oct 21 2013 aboe76@gmail.com
- Updated requirements python-markupsafe required for salt-ssh
* Fri Oct 18 2013 p.drouand@gmail.com
- Don't support sysvinit and systemd for the same system; add conditionnal
  macros to use systemd only on systems which support it and sysvinit
  on other systems
* Thu Oct 17 2013 aboe76@gmail.com
- Updated to salt 0.17.1 bugfix release (bnc#849205, bnc#849204, bnc#849184):
  - Fix symbolic links in thin.tgz (:issue:`7482`)
  - Pass env through to file.patch state (:issue:`7452`)
  - Service provider fixes and reporting improvements (:issue:`7361`)
  - Add --priv option for specifying salt-ssh private key
  - Fix salt-thin's salt-call on setuptools installations (:issue:`7516`)
  - Fix salt-ssh to support passwords with spaces (:issue:`7480`)
  - Fix regression in wildcard includes (:issue:`7455`)
  - Fix salt-call outputter regression (:issue:`7456`)
  - Fix custom returner support for startup states (:issue:`7540`)
  - Fix value handling in augeas (:issue:`7605`)
  - Fix regression in apt (:issue:`7624`)
  - Fix minion ID guessing to use socket.getfqdn() first (:issue:`7558`)
  - Add minion ID caching (:issue:`7558`)
  - Fix salt-key race condition (:issue:`7304`)
  - Add --include-all flag to salt-key (:issue:`7399`)
  - Fix custom grains in pillar (part of :issue:`5716`, :issue:`6083`)
  - Fix race condition in salt-key (:issue:`7304`)
  - Fix regression in minion ID guessing, prioritize socket.getfqdn() (:issue:`7558`)
  - Cache minion ID on first guess (:issue:`7558`)
  - Allow trailing slash in file.directory state
  - Fix reporting of file_roots in pillar return (:issue:`5449` and :issue:`5951`)
  - Remove pillar matching for mine.get (:issue:`7197`)
  - Sanitize args for multiple execution modules
  - Fix yumpkag mod_repo functions to filter hidden args (:issue:`7656`)
  - Fix conflicting IDs in state includes (:issue:`7526`)
  - Fix mysql_grants.absent string formatting issue (:issue:`7827`)
  - Fix postgres.version so it won't return None (:issue:`7695`)
  - Fix for trailing slashes in mount.mounted state
  - Fix rogue AttributErrors in the outputter system (:issue:`7845`)
  - Fix for incorrect ssh key encodings resulting in incorrect key added (:issue:`7718`)
  - Fix for pillar/grains naming regression in python renderer (:issue:`7693`)
  - Fix args/kwargs handling in the scheduler (:issue:`7422`)
  - Fix logfile handling for file://, tcp:// and udp:// (:issue:`7754`)
  - Fix error handling in config file parsing (:issue:`6714`)
  - Fix RVM using sudo when running as non-root user (:issue:`2193`)
  - Fix client ACL and underlying logging bugs (:issue:`7706`)
  - Fix scheduler bug with returner (:issue:`7367`)
  - Fix user management bug related to default groups (:issue:`7690`)
  - Fix various salt-ssh bugs (:issue:`7528`)
  - Many various documentation fixes
* Thu Oct  3 2013 aboe76@gmail.com
- Updated init files to be inline with fedora/rhel packaging upstream
* Mon Sep 30 2013 aboe76@gmail.com
- Cleaned up spec file:
- Unit testing can be done on all distributions
* Sat Sep 28 2013 aboe76@gmail.com
- Updated package following salt package guidelins:
  https://github.com/saltstack/salt/blob/develop/doc/topics/conventions/packaging.rst
- activated salt-testing for unit testing salt before releasing rpm
- updated docs
- added python-xml as dependency
* Thu Sep 19 2013 aboe76@gmail.com
- Updated 0.17.0 Feature Release
  Major features:
  - halite (web Gui)
  - salt ssh (remote execution/states over ssh) with its own package
  - Rosters (list system targets not know to master)
  - State Auto Order (state evaluation and execute in order of define)
  - state.sls Runner (system orchestration from within states via master)
  - Mercurial Fileserver Backend
  - External Logging Handlers (sentry and logstash support)
  - Jenkins Testing
  - Salt Testing Project (testing libraries for salt)
  - StormPath External Authentication support
  - LXC Support (lxc support for salt-virt)
  - Package dependencies reordering:
  * salt-master requires python-pyzmq, and recommends python-halite
  * salt-minion requires python-pyzmq
  * salt-ssh requires sshpass
  * salt-syndic requires salt-master
  Minor features:
  - 0.17.0 release wil be last release for 0.XX.X numbering system
    Next release will be <Year>.<Month>.<Minor>
* Sat Sep  7 2013 aboe76@gmail.com
- Update 0.16.4 bugfix release:
  - Multiple documentation improvements/additions
  - Added the osfinger and osarch grains
  - Fix bug in :mod:`hg.latest <salt.states.hg.latest>` state
  that would erroneously delete directories (:issue:`6661`)
  - Fix bug related to pid not existing for
  :mod:`ps.top <salt.modules.ps.top>` (:issue:`6679`)
  - Fix regression in :mod:`MySQL returner <salt.returners.mysql>`
  (:issue:`6695`)
  - Fix IP addresses grains (ipv4 and ipv6) to include all addresses
  (:issue:`6656`)
  - Fix regression preventing authenticated FTP (:issue:`6733`)
  - Fix :mod:`file.contains <salt.modules.file.contains>` on values
  YAML parses as non-string (:issue:`6817`)
  - Fix :mod:`file.get_gid <salt.modules.file.get_gid>`,
  :mod:`file.get_uid <salt.modules.file.get_uid>`, and
  :mod:`file.chown <salt.modules.file.chown>` for broken symlinks
  (:issue:`6826`)
  - Fix comment for service reloads in service state (:issue:`6851`)
* Fri Aug  9 2013 aboe76@gmail.com
- Update 0.16.3 bugfix release:
  - Fixed scheduler config in pillar
  - Fixed default value for file_recv master config option
  - Fixed missing master configuration file parameters
  - Fixed regression in binary package installation on 64-bit systems
  - Fixed stackgrace when commenting a section in top.sls
  - Fixed state declarations not formed as a list message.
  - Fixed infinite loop on minion
  - Fixed stacktrace in watch when state is 'prereq'
  - Feature: function filter_by to grains module
  - Feature: add new "osfinger" grain
* Sat Aug  3 2013 aboe76@gmail.com
- Fixed regression bug in salt 0.16.2
  - Newly installed salt-minion doesn't create
    /var/cache/salt/minion/proc
  - fix let package create this directory
    next version of Salt doesn't need this.
* Fri Aug  2 2013 aboe76@gmail.com
- Updated to salt 0.16.2
  - gracefully handle lsb_release data when it is enclosed in quotes
  - fixed pillar load from master config
  - pillar function pillar.item and pillar.items instead of pillar.data
  - fixed traceback when pillar sls is malformed
  - gracefully handle quoted publish commands
  - publich function publish.item and publish.items instead of publish.data
  - salt-key usage in minionswarm script fixed
  - minion random reauth_delay added to stagger re-auth attempts.
  - improved user and group management
  - improved file management
  - improved package management
  - service management custom initscripts support
  - module networking hwaddr renamed to be in line with other modules
  - fixed traceback in bridge.show
  - fixed ssh know_hosts and auth.present output.
  for more information: http://docs.saltstack.com/topics/releases/0.16.2.html
* Mon Jul 29 2013 aboe76@gmail.com
- removed not needed requirements:
  Requires(pre): /usr/sbin/groupadd
  Requires(pre): /usr/sbin/useradd
  Requires(pre): /usr/sbin/userdel
* Mon Jul 29 2013 aboe76@gmail.com
- Updated to salt 0.16.1
  - Bugfix release
  - postgresql module Fixes #6352.
  - returner fixes Fixes issue #5518
  - http authentication issues fixed  #6356
  - warning of deprecation runas in favor of user
- more information at https://github.com/saltstack/salt/commits/v0.16.1
* Fri Jul  5 2013 aboe76@gmail.com
- Updated init files, rc_status instead of rc status.
* Tue Jul  2 2013 aboe76@gmail.com
- Update to salt 0.16.0 final
  - Multi-Master capability
  - Prereq, the new requisite
  - Peer system improvement
  - Relative Includes
  - More state Output Options
  - Improved Windows Support
  - Multi Targets for pkg.removed, pgk.purged States
  - Random Times in cron states
  - Confirmation Prompt on Key acceptance on master
- full changelog details: http://docs.saltstack.com/topics/releases/0.16.0.html
* Sat Jun 22 2013 aboe76@gmail.com
- Updated to salt 0.16.0RC
- New Features in 0.16.0:
  - Multi-Master capability
  - Prereq, the new requisite
  - Peer system improvement
  - Relative Includes
  - More state Output Options
  - Improved Windows Support
  - Multi Targets for pkg.removed, pgk.purged States
  - Random Times in cron states
  - Confirmation Prompt on Key acceptance on master
- full changelog details: http://docs.saltstack.com/topics/releases/0.16.0.html
* Wed Jun 12 2013 aboe76@gmail.com
- Updated init files from upstream, so init files are the same for
  fedora/redhat/centos/debian/suse
- Removed salt user and daemon.conf file, so package is in line
  with upstream packages fedora/centos/debian.
* Sun Jun  2 2013 aboe76@gmail.com
- minor permission fix on salt config files to fix external auth
* Sat Jun  1 2013 aboe76@gmail.com
- Service release 0.15.3
  showstoppers from 0.15.2:
  - mine fix cross validity.
  - redhat package issue
  - pillar refresh fix
* Wed May 29 2013 aboe76@gmail.com
- Service release 0.15.2
  xinetd service name not appended
  virt-module uses qemu-img
  publish.publish returns same info as salt-master
  updated gitfs module
* Mon May 27 2013 aboe76@gmail.com
- Fixed salt-master config file not readable by user 'salt'
* Mon May 27 2013 aboe76@gmail.com
- Updated package spec: security enhancement.
  added system user salt to run salt-master under privileged user 'salt'
  added config dirs, master.d/minion.d/syndic.d to add config files.
  added salt-daemon.conf were salt user is specified under salt-master.
* Sun May 12 2013 aboe76@gmail.com
- Updated package spec, for systemd unit files
  according to how systemd files needs to be packaged
- added logrotate on salt log files
- fixed rpmlint complain about reload function in init files
* Wed May  8 2013 aboe76@gmail.com
- Updated to salt 0.15.1
- bugfix release.
- fixes suse service check
* Sat May  4 2013 aboe76@gmail.com
- Updated to salt 0.15.0
  Major update:
  - salt mine function
  - ipv6 support
  - copy files from minions to master
  - better template debugging
  - state event firing
  - major syndic updates
  - peer system updates
  - minion key revokation
  - function return codes
  - functions in overstate
  - Pillar error reporting
  - Cached State Data
  - Monitoring states
- Read http://docs.saltstack.com/topics/releases/0.15.0.html for more information
- improved init files overwrite with /etc/default/salt
* Tue Apr 23 2013 aboe76@gmail.com
- Updated init files:
- removed probe/reload/force reload
  this isn't supported
* Sun Apr 14 2013 aboe76@gmail.com
- Updated init files
* Sun Apr 14 2013 aboe76@gmail.com
- Updated to 0.14.1 bugfix release:
- some major fixes for the syndic system,
- fixes to file.recurse and external auth and
- fixes for windows
* Thu Apr 11 2013 aboe76@gmail.com
- Updated salt init files with option -d to really daemonize it
* Sat Mar 23 2013 aboe76@gmail.com
- Updated to 0.14.0
  MAJOR FEATURES:
  - Salt - As a Cloud Controller
  - Libvirt State
  - New get Functions
* Tue Mar 19 2013 aboe76@gmail.com
- Updated to 0.13.3
  Last Bugfixes release before 0.14.0
* Wed Mar 13 2013 aboe76@gmail.com
- Updated 0.13.2
  Bugfixes release (not specified)
* Mon Feb 25 2013 aboe76@gmail.com
- Updated spec file, postun removal of init.d files
* Sat Feb 16 2013 aboe76@gmail.com
- Updated to Salt 0.13.1 bugfixes:
- Fix #3693 (variable ref'ed before assignment)
- Fix stack trace introduced with
- Updated limit to be escaped like before and after.
- Import install command from setuptools if we use them.
- Fix user info not displayed correctly when group doesn't map cleanly
- fix bug: Client.cache_dir()
- Fix #3717
- Fix #3716
- Fix cmdmod.py daemon error
- Updated test to properly determine homebrew user
- Fixed whitespace issue
* Thu Feb 14 2013 aboe76@gmail.com
- Updated to salt 0.13.0
* Wed Jan 30 2013 aboe76@gmail.com
- Updated Suse Copyright in Spec-file
* Mon Jan 28 2013 toddrme2178@gmail.com
- Cleanup spec file
* Sat Jan 26 2013 aboe76@gmail.com
- split syndic from master in separate package
* Tue Jan 22 2013 aboe76@gmail.com
- updated to salt 0.12.1 bugfix release
* Wed Jan 16 2013 aboe76@gmail.com
- uploaded to salt 1.12.0
